@@ -1,11 +1,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
+#include <ctype.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "../include/fio.h"
-
 #include "guiutils.h"
 #include "cdialog.h"
 #include "config.h"
@@ -460,30 +460,31 @@ gint CDialogInit(void)
 	GtkAccelGroup *accelgrp;
 	GtkRcStyle *rcstyle;
 	GtkStyle *style;
-	GtkWidget *w, *parent, *parent2, *parent3, *parent4, *parent5;
+	GtkWidget	*w,
+			*parent, *parent2, *parent3, *parent4,
+			*parent5,
+			*toplevel;
 	CDlg *d;
 
 	/* Already initialized? */
 	if(cdlg != NULL)
 	    return(0);
 
-	/* Create new Dialog */
+	/* Create the new Dialog */
 	cdlg = d = CDLG(g_malloc0(sizeof(CDlg)));
 	if(d == NULL)
 	    return(-3);
 
-	/* Reset globals */
+	d->toplevel = toplevel = gtk_window_new(GTK_WINDOW_DIALOG);
+	d->accelgrp = accelgrp = gtk_accel_group_new();
 	d->last_transient_for = NULL;
 	d->last_icon_code = CDIALOG_ICON_INFO;
 	d->response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
 	d->block_loop_level = 0;
 
-	/* Keyboard accelerator group */
-	d->accelgrp = accelgrp = gtk_accel_group_new();
-
-
-	/* Toplevel */
-	d->toplevel = w = gtk_window_new(GTK_WINDOW_DIALOG);
+	/* Toplevel GtkWindow */
+	w = toplevel;
+        gtk_window_set_policy(GTK_WINDOW(w), TRUE, TRUE, TRUE);
 	gtk_window_set_title(GTK_WINDOW(w), CDIALOG_DEF_TITLE);
 #ifdef PROG_NAME
 	gtk_window_set_wmclass(
@@ -500,12 +501,11 @@ gint CDialogInit(void)
 
 	    gdk_window_set_decorations(
 		window,
-		GDK_DECOR_BORDER | GDK_DECOR_TITLE | GDK_DECOR_MENU |
-		GDK_DECOR_MINIMIZE
+		GDK_DECOR_BORDER | GDK_DECOR_TITLE
 	    );
 	    gdk_window_set_functions(
 		window,
-		GDK_FUNC_MOVE | GDK_FUNC_MINIMIZE | GDK_FUNC_CLOSE
+		GDK_FUNC_MOVE | GDK_FUNC_CLOSE
 	    );
 
 	    geo.min_width = 100;
@@ -1530,22 +1530,9 @@ gint CDialogGetResponseFile(
 {
 	gint response;
 	gchar *buf;
-	FILE *fp = !STRISEMPTY(filename) ?
-	    FOpen((const char *)filename, "rb") : NULL;
-	if(fp == NULL)
-	{
-	    /* Failed to open file */
-	    if(!STRISEMPTY(filename))
-		buf = g_strdup_printf(
-"Unable to open the file:\n\
-\n\
-    %s\n",
-		    filename
-		);
-	    else
-		buf = STRDUP("No file specified");
-	}
-	else
+	FILE *fp = (filename != NULL) ?
+	    fopen((const char *)filename, "rb") : NULL;
+	if(fp != NULL)
 	{
 	    gint	buf_len = 2048,
 			bytes_read;
@@ -1561,7 +1548,35 @@ gint CDialogGetResponseFile(
 		bytes_read = buf_len - 1;
 	    buf[bytes_read] = '\0';
 
-	    FClose(fp);
+	    fclose(fp);
+	}
+	else
+	{
+	    const gint error_code = errno;
+	    if(filename != NULL)
+	    {
+		gchar *error_msg = STRDUP(g_strerror(error_code));
+		if(error_msg != NULL)
+		{
+		    *error_msg = (gchar)toupper((int)(*error_msg));
+		    buf = g_strdup_printf(
+"%s:\n\
+\n\
+    %s",
+			error_msg,
+			filename
+		    );
+		    g_free(error_msg);
+		}
+		else
+		{
+		    buf = STRDUP("Unable to open the file for reading");
+		}
+	    }
+	    else
+	    {
+		buf = STRDUP("No file specified");
+	    }
 	}
 
 	/* Map the CDialog using the message loaded from the file
@@ -1626,33 +1641,12 @@ void CDialogShutdown(void)
 	}
 	d->block_loop_level = 0;
 
-	/* Unmap Dialog */
+	/* Unmap the dialog */
 	CDialogUnmap();
 
-	/* Begin destroying widgets */
-	GTK_WIDGET_DESTROY(d->icon_pm)
-	GTK_WIDGET_DESTROY(d->label)
-	GTK_WIDGET_DESTROY(d->label_hbox)
-	GTK_WIDGET_DESTROY(d->help_icon_pm)
-	GTK_WIDGET_DESTROY(d->help_label)
-	GTK_WIDGET_DESTROY(d->help_vbox)
-
-	GTK_WIDGET_DESTROY(d->ok_btn)
-	GTK_WIDGET_DESTROY(d->yes_btn)
-	GTK_WIDGET_DESTROY(d->yes_to_all_btn)
-	GTK_WIDGET_DESTROY(d->no_btn)
-	GTK_WIDGET_DESTROY(d->cancel_btn)
-	GTK_WIDGET_DESTROY(d->ignore_btn)
-	GTK_WIDGET_DESTROY(d->retry_btn)
-	GTK_WIDGET_DESTROY(d->abort_btn)
-	GTK_WIDGET_DESTROY(d->help_btn)
-
-	GTK_WIDGET_DESTROY(d->button_hbox)
-	GTK_WIDGET_DESTROY(d->main_vbox)
-	GTK_WIDGET_DESTROY(d->toplevel)
-
-	GTK_ACCEL_GROUP_UNREF(d->accelgrp)
-
+	/* Delete the dialog */
 	cdlg = NULL;
+	gtk_widget_destroy(d->toplevel);
+	gtk_accel_group_unref(d->accelgrp);
 	g_free(d);
 }
