@@ -25,19 +25,19 @@
 /*
  *	Program Name & Version:
  */
-#define PROG_NAME		"ManEdit"
-#define PROG_NAME_FULL		"ManEdit"
-#define PROG_VERSION		"0.7.1"
+#define PROG_NAME			"ManEdit"
+#define PROG_NAME_FULL			"ManEdit"
+#define PROG_VERSION			"0.8.1"
 
-#define PROG_VERSION_MAJOR	0
-#define PROG_VERSION_MINOR	7
-#define PROG_VERSION_RELEASE	1
+#define PROG_VERSION_MAJOR		0
+#define PROG_VERSION_MINOR		8
+#define PROG_VERSION_RELEASE		1
 
 /*
  *	Program Copyright:
  */
 #define PROG_COPYRIGHT	"\
-Copyright (C) 2000-2006 WolfPack Entertainment.\n\
+Copyright (C) 2000-2007 WolfPack Entertainment.\n\
 This program is protected by international copyright laws and treaties,\n\
 distribution and/or modification of this software in violation of the\n\
 GNU Public License is strictly prohibited. Violators will be prosecuted\n\
@@ -74,20 +74,20 @@ Usage: manedit [manual_page] [options] [GUI_options]\n\
 /*
  *	Default editor size in pixels:
  */
-#define MEDIT_DEF_WIDTH		800
-#define MEDIT_DEF_HEIGHT	600
+#define MEDIT_DEF_WIDTH			800
+#define MEDIT_DEF_HEIGHT		600
 
 /*
  *	Default viewer size in pixels.
  */
-#define MEDIT_VIEWER_DEF_WIDTH	640
-#define MEDIT_VIEWER_DEF_HEIGHT	512
+#define MEDIT_VIEWER_DEF_WIDTH		640
+#define MEDIT_VIEWER_DEF_HEIGHT		512
 
 /*
  *	Default Preferences & Options window size in pixels:
  */
-#define MEDIT_PREF_DEF_WIDTH	640
-#define MEDIT_PREF_DEF_HEIGHT	480
+#define MEDIT_PREF_DEF_WIDTH		640
+#define MEDIT_PREF_DEF_HEIGHT		480
 
 /*
  *	Default paned widget size in pixels:
@@ -104,12 +104,12 @@ Usage: manedit [manual_page] [options] [GUI_options]\n\
 /*
  *	Viewer window title:
  */
-#define MEDIT_VIEWER_TITLE	"Manual Page Viewer"
+#define MEDIT_VIEWER_TITLE		"ManView"
 
 /*
  *	Preferences & Options window title:
  */
-#define MEDIT_PREF_TITLE	"Manual Page Editor: Preferences"
+#define MEDIT_PREF_TITLE		"ManEdit: Preferences"
 
 
 /*
@@ -214,9 +214,9 @@ Usage: manedit [manual_page] [options] [GUI_options]\n\
 #define MEDIT_DND_TYPE_INFO_STRING		2	/* "STRING" */
 
 #define MEDIT_DND_TYPE_INFO_EDITOR_BRANCH_CMD	3
-#define MEDIT_DND_TYPE_NAME_EDITOR_BRANCH_CMD	"manedit/editor/branch"
+#define MEDIT_DND_TARGET_EDITOR_BRANCH	"manedit/editor/branch"
 #define MEDIT_DND_TYPE_INFO_VIEWER_BRANCH_CMD	4
-#define MEDIT_DND_TYPE_NAME_VIEWER_BRANCH_CMD	"manedit/viewer/branch"
+#define MEDIT_DND_TARGET_VIEWER_BRANCH	"manedit/viewer/branch"
 
 
 /*
