@@ -237,12 +237,11 @@ gint CSDInit(void)
 	{
 	    gdk_window_set_decorations(
 		window,
-                GDK_DECOR_BORDER | GDK_DECOR_TITLE | GDK_DECOR_MENU |
-                GDK_DECOR_MINIMIZE
+		GDK_DECOR_BORDER | GDK_DECOR_TITLE
 	    );
 	    gdk_window_set_functions(
 		window,
-		GDK_FUNC_MOVE | GDK_FUNC_MINIMIZE | GDK_FUNC_CLOSE
+		GDK_FUNC_MOVE | GDK_FUNC_CLOSE
 	    );
 	}
 	gtk_signal_connect(
@@ -640,37 +639,29 @@ static void CSDColorButtonSelectCB(GtkWidget *widget, gpointer data)
 	CSDSetTransientFor(gtk_widget_get_toplevel(w));
 	status = CSDGetResponse(
 #if defined(PROG_LANGUAGE_SPANISH)
-"El Color Selecto",
-"Selecto",
-"Cancele",
+	    "Escoja El Color",
+	    "Escoja", "Cancele",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Couleur Privilgie",
-"Privilgi",
-"Annuler",
+	    "Couleur Privilgie",
+	    "Privilgi", "Annuler",
 #elif defined(PROG_LANGUAGE_GERMAN)
-"Erlesene Farbe",
-"Erlesen",
-"Heben",
+	    "Wahlen Sie Farbe Aus",
+	    "Wahlen", "Heben",
 #elif defined(PROG_LANGUAGE_ITALIAN)
-"Scegliere Il Colore",
-"Scegliere",
-"Annullare",
+	    "Scegliere Il Colore",
+	    "Sceglier", "Annullar",
 #elif defined(PROG_LANGUAGE_DUTCH)
-"Uitgezochte Kleur",
-"Uitgezocht",
-"Annuleer",
+	    "Selecteer De Kleur",
+	    "Selecter", "Annuler",
 #elif defined(PROG_LANGUAGE_PORTUGUESE)
-"Selecione Cor",
-"Selecione",
-"Cancelamento",
+	    "Selecione Cor",
+	    "Selecion", "Cancela",
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
-"Utvalgt Farge",
-"Utvalgt",
-"Kanseller",
+	    "Velg Ut Farge",
+	    "Velg", "Kanseler",
 #else
-"Select Color",
-"Select",
-"Cancel",
+	    "Select Color",
+	    "Select", "Cancel",
 #endif
 	    &c, &c_rtn,
 	    w, color_changed_cb
