@@ -1,5 +1,5 @@
 /*
-                   Manual Page Editor: Editor Callbacks
+		   Manual Page Editor: Editor Callbacks
  */
 
 #ifndef EDITORCB_H
@@ -12,7 +12,9 @@
 extern void EditorItemDestroyCB(gpointer data);
 
 extern gint EditorKeyEventCB(GtkWidget *widget, GdkEventKey *key, gpointer data);
-extern void EditorDestroyCB(GtkObject *object, gpointer data);
+extern gint EditorTextButtonEventCB(
+	GtkWidget *widget, GdkEventButton *button, gpointer data
+);
 extern gint EditorCloseCB(GtkWidget *widget, GdkEvent *event, gpointer data);
 extern void EditorCloseMCB(GtkWidget *widget, gpointer data);
 extern void EditorCloseAllMCB(GtkWidget *widget, gpointer data);
@@ -41,7 +43,6 @@ extern void EditorCutCB(GtkWidget *widget, gpointer data);
 extern void EditorCopyCB(GtkWidget *widget, gpointer data);
 extern void EditorPasteCB(GtkWidget *widget, gpointer data);
 extern void EditorDeleteCB(GtkWidget *widget, gpointer data);
-extern void EditorClipboardBrowserCB(GtkWidget *widget, gpointer data);
 extern void EditorSelectAllCB(GtkWidget *widget, gpointer data);
 extern void EditorUnselectAllCB(GtkWidget *widget, gpointer data);
 extern void EditorPreferencesCB(GtkWidget *widget, gpointer data);
@@ -74,27 +75,27 @@ extern void EditorMenuHideCB(GtkWidget *widget, gpointer data);
 
 extern void EditorLayoutCTreeDoExpandCB(GtkWidget *widget, gpointer data);
 extern void EditorLayoutCTreeSelectCB(
-        GtkCTree *ctree, GtkCTreeNode *branch, gint column, gpointer data
+	GtkCTree *ctree, GtkCTreeNode *branch, gint column, gpointer data
 );
 extern void EditorLayoutCTreeUnselectCB(
-        GtkCTree *ctree, GtkCTreeNode *branch, gint column, gpointer data
+	GtkCTree *ctree, GtkCTreeNode *branch, gint column, gpointer data
 );
 extern void EditorLayoutCTreeExpandCB(
-        GtkCTree *ctree, GtkCTreeNode *node, gpointer data
+	GtkCTree *ctree, GtkCTreeNode *node, gpointer data
 );
 
 extern gint EditorSyntaxHighlightTimeoutCB(gpointer data);
 
 extern gint EditorTextKeyEventCB(
-        GtkEditable *editable, GdkEventKey *key, gpointer data
+	GtkEditable *editable, GdkEventKey *key, gpointer data
 );
 extern void EditorTextChangeCB(GtkEditable *editable, gpointer data);
 extern void EditorTextInsertCB(
-        GtkEditable *editable, const gchar *text, gint length,
-        gint *position, gpointer data
+	GtkEditable *editable, const gchar *text, gint length,
+	gint *position, gpointer data
 );
 extern void EditorTextDeleteCB(
-        GtkEditable *editable, gint start_pos, gint end_pos, gpointer data
+	GtkEditable *editable, gint start_pos, gint end_pos, gpointer data
 );
 
 
