@@ -2,9 +2,6 @@
 #include <string.h>
 #include <gtk/gtk.h>
 
-#include "../include/string.h"
-#include "../include/strexp.h"
-
 #include "guiutils.h"
 #include "cdialog.h"
 
@@ -22,11 +19,11 @@
 /* Recieved data command string parsing */
 void EditorDNDParseCmd(
 	const gchar *string,
-	editor_struct **editor_ptr,
+	editor_struct **editor_rtn,
 	GtkCTreeNode ***branch, gint *total_branches
 );
 gchar *EditorDNDParseURL(
-	const gchar *string, gint len
+	const gchar *s, const gint len
 );
 
 /* Inserting to target editor routines */
@@ -100,17 +97,16 @@ void EditorDNDDataDeleteCB(
  */
 void EditorDNDParseCmd(
 	const gchar *string,
-	editor_struct **editor_ptr,
+	editor_struct **editor_rtn,
 	GtkCTreeNode ***branch, gint *total_branches
 )
 {
+	gint i;
 	guint32 addr_val;
-	gint i, n, strc;
 	gchar **strv;
 
-	/* Reset returns */
-	if(editor_ptr != NULL)
-	    *editor_ptr = NULL;
+	if(editor_rtn != NULL)
+	    *editor_rtn = NULL;
 	if(branch != NULL)
 	    *branch = NULL;
 	if(total_branches != NULL)
@@ -119,85 +115,88 @@ void EditorDNDParseCmd(
 	if(string == NULL)
 	    return;
 
-	if(strcasepfx(string, "error"))
+	if(g_strcasepfx(string, "error"))
 	    return;
 
 	/* Parse command, format is as follows:
 	 * <editor_ptr> <branch_ptr...>
 	 */
-	strv = strexp(string, &strc);
+	strv = g_strsplit(string, " ", -1);
 	if(strv == NULL)
 	    return;
 
-	/* Get editor_ptr (format in hex with no "0x" prefix) */
-	if(strc > 0)
-	    i = sscanf(strv[0], "%x", (guint32 *)&addr_val);
-	else
-	    i = 0;
-	if((i > 0) && (editor_ptr != NULL))
-	    *editor_ptr = EDITOR(addr_val);
+	i = 0;
 
-	/* Get list of branch pointers which should be branches
+	/* Get the editor pointer
+	 *
+	 * Format is in hex with no "0x" prefix
+	 */
+	if(strv[i] != NULL)
+	{
+	    const gint status = sscanf(
+		strv[i], "%x", (guint32 *)&addr_val
+	    );
+	    if((status > 0) && (editor_rtn != NULL))
+		*editor_rtn = EDITOR(addr_val);
+
+	    i++;
+	}
+
+	/* Get the list of branch pointers which should be branches
 	 * on the parsed editor's layout ctree
 	 */
-	if((branch != NULL) && (total_branches != NULL))
+	for(; strv[i] != NULL; i++)
 	{
-	    const gchar *cs;
-
-	    /* Start at parsed argument number 1 */
-	    for(i = 1; i < strc; i++)
+	    if((branch != NULL) && (total_branches != NULL))
 	    {
-		cs = (const gchar *)strv[i];
-		if(cs == NULL)
-		    continue;
-
-		n = (*total_branches);
+		const gint n = (*total_branches);
 		(*total_branches) = n + 1;
-		(*branch) = (GtkCTreeNode **)realloc(
+		(*branch) = (GtkCTreeNode **)g_realloc(
 		    *branch,
 		    (*total_branches) * sizeof(GtkCTreeNode *)
 		);
-		if((*branch) == NULL)
+		if((*branch) != NULL)
 		{
-		    (*total_branches) = 0;
-		    break;
-		}
-		else
-		{
-		    i = sscanf(cs, "%x", (guint32 *)&addr_val);
-		    if(i > 0)
+		    const gint status = sscanf(
+			strv[i], "%x", (guint32 *)&addr_val
+		    );
+		    if(status > 0)
 			(*branch)[n] = (GtkCTreeNode *)addr_val;
 		    else
 			(*branch)[n] = NULL;
 		}
+		else
+		{
+		    (*total_branches) = 0;
+		}
 	    }
 	}
 
-	/* Free exploded string */
-	strlistfree(strv, strc);
+	g_strfreev(strv);
 }
 
 /*
- *	Returns a dynamically allocated string containing the
- *	file name portion of the given url string.
+ *	Parses the URL.
+ *
+ *	Returns a dynamically allocated string describing the path
+ *	portion of the URL.
  */
 gchar *EditorDNDParseURL(
-	const gchar *string, gint len
+	const gchar *s, const gint len
 )
 {
 	const gchar *cs, *cs2;
 
-
-	if(string == NULL)
+	if(s == NULL)
 	    return(NULL);
 
-	cs = strstr(string, "://");
-	if(cs == NULL)
-	    cs = string;
-	else
+	cs = (const gchar *)strstr((const char *)s, "://");
+	if(cs != NULL)
 	    cs += strlen("://");
+	else
+	    cs = s;
 
-	cs2 = strchr(cs, '/');
+	cs2 = (const gchar *)strchr((const char *)cs, '/');
 	if(cs2 == NULL)
 	    cs2 = cs;
 
@@ -224,26 +223,19 @@ static GtkCTreeNode *EditorDNDItemAdd(
 {
 	gchar *text[1]; 
 	GtkCTreeNode *branch;
-	medit_pixmaps_list_struct *pixmaps_list;
 	GdkPixmap *closed_p = NULL, *opened_p = NULL;
 	GdkBitmap *closed_m = NULL, *opened_m = NULL;
-	medit_core_struct *core_ptr = MEDIT_CORE(editor->core_ptr);
-	GtkCTree *ctree = (GtkCTree *)editor->layout_ctree;
-	if((core_ptr == NULL) || (ctree == NULL))
-	{
-	    EditorItemDelete(item);
-	    return(NULL);
-	}
+	medit_core_struct *core = editor->core;
+	medit_pixmaps_list_struct *pixmaps_list = &core->pixmaps_list;
+	GtkCTree *ctree = GTK_CTREE(editor->layout_ctree);
 
-	pixmaps_list = &core_ptr->pixmaps_list;
-
-	/* Reset name for new branch, it'll be picked below */
+	/* Reset the name for the new branch */
 	text[0] = NULL;
 
 	/* Item data valid? */
 	if(item != NULL)
 	{
-	    /* Handle by item data type */
+	    /* Handle by the item data type */
 	    switch(item->type)
 	    {
 	      case EditorItemTypeFile:
@@ -301,12 +293,6 @@ static GtkCTreeNode *EditorDNDItemAdd(
 	    if(item->type == EditorItemTypeFile)
 	    {
 		/* Need to add this to the editor's layout_trunk list */
-
-/* Need to work on this, currently we can't copy items of type
- * EditorItemTypeFile. They will just be swaped.
- */
-g_printerr("Cannot copy item of type EditorItemTypeFile yet.\n");
-
 	    }
 	}
 
@@ -314,7 +300,7 @@ g_printerr("Cannot copy item of type EditorItemTypeFile yet.\n");
 	EditorBranchSetData(
 	    ctree, branch,
 	    item, EditorItemDestroyCB
-	);   
+	);
 	item = NULL;
 
 	/* Mark new branch's item data as having changes */
@@ -355,26 +341,16 @@ static void EditorDNDItemListAdd(
 	    return;
 	}
 
-	/* Get pointer to layout ctree */
-	ctree = (GtkCTree *)editor->layout_ctree;
-	clist = (GtkCList *)ctree;
-	if(ctree == NULL)
-	{
-	    for(i = 0; i < total_items; i++)
-		EditorItemDelete(item[i]);
-	    g_free(item);
-	    return;
-	}
+	ctree = GTK_CTREE(editor->layout_ctree);
+	clist = GTK_CLIST(ctree);
 
-
-	/* Clip insert row */
+	/* Clip the insert row */
 	if(insert_row < 0)
 	    insert_row = 0;
 
 	/* Begin inserting */
-	if(1)
+	if(TRUE)
 	{
-	    /* Insert at start or in the middle */
 	    GtkCTreeNode *insert_node;
 	    GtkCTreeRow *insert_node_row;
 
@@ -392,16 +368,14 @@ static void EditorDNDItemListAdd(
 		g_free(item);
 		return;
 	    }
-	    else
+
+	    insert_node_row = GTK_CTREE_ROW(insert_node);
+	    if(insert_node_row == NULL)
 	    {
-		insert_node_row = GTK_CTREE_ROW(insert_node);
-		if(insert_node_row == NULL)
-		{
-		    for(i = 0; i < total_items; i++)
-			EditorItemDelete(item[i]);
-		    g_free(item);
-		    return;
-		}
+		for(i = 0; i < total_items; i++)
+		    EditorItemDelete(item[i]);
+		g_free(item);
+		return;
 	    }
 
 	    gtk_clist_freeze(clist);
@@ -409,12 +383,10 @@ static void EditorDNDItemListAdd(
 	    /* Is the insert node a leaf (not a trunk)? */
 	    if(insert_node_row->is_leaf)
 	    {
-		/* Insert after this node, so we pick this node's
-		 * sibling. The sibling may be NULL in which we
-		 * insert at the end.
-		 */
+		/* Insert at this node */
 		parent_node = insert_node_row->parent;
-		insert_node = insert_node_row->sibling;	/* New insert node */
+/*		insert_node = insert_node_row->sibling; */
+
 		/* Insert last to first */
 		for(i = total_items - 1; i >= 0; i--)
 		{
@@ -432,6 +404,7 @@ static void EditorDNDItemListAdd(
 		 */
 		parent_node = insert_node;
 		insert_node = insert_node_row->children;
+
 		/* Insert last to first */
 		for(i = total_items - 1; i >= 0; i--)
 		{
@@ -446,10 +419,8 @@ static void EditorDNDItemListAdd(
 	    gtk_clist_thaw(clist);
 	}
 
-	/* Delete the item list */
+	/* Delete the items list */
 	g_free(item);
-	item = NULL;
-	total_items = 0;
 }
 
 
@@ -508,7 +479,7 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 	      case EditorItemTypeHeader:
 		closed_p = pixmaps_list->manpage_heading_20x20;
 		closed_m = pixmaps_list->manpage_heading_20x20_mask;
-		opened_p = closed_p;   
+		opened_p = closed_p;
 		opened_m = closed_m;
 		text[0] = "Header";
 		break;
@@ -564,7 +535,7 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 
 	/* Does the given source branch have children? */
 	branch_row = GTK_CTREE_ROW(src_branch);
-	if((branch_row == NULL) ? 0 : (branch_row->children != NULL))
+	if((branch_row != NULL) ? (branch_row->children != NULL) : FALSE)
 	{
 	    /* Update parent branch to be the newly added branch on the
 	     * target editor.
@@ -622,40 +593,29 @@ static void EditorDNDTrunkListAdd(
 	GtkCTreeNode *sibling_branch;
 	GtkCList *clist, *src_clist;
 	GtkCTree *ctree, *src_ctree;
-	medit_core_struct *core_ptr;
+	medit_core_struct *core;
 	medit_pixmaps_list_struct *pixmaps_list;
 
-
 	if((editor == NULL) || (src_editor == NULL) ||
 	   (branch == NULL) || (total_branches <= 0)
 	)
 	    return;
 
-	/* Get pointer to layout ctree on target editor */
-	ctree = (GtkCTree *)editor->layout_ctree;
-	clist = (GtkCList *)ctree;
-	if(ctree == NULL)
-	    return;
+	ctree = GTK_CTREE(editor->layout_ctree);
+	clist = GTK_CLIST(ctree);
 
-	/* Get pointer to layout ctree on source editor */
-	src_ctree = (GtkCTree *)src_editor->layout_ctree;
-	src_clist = (GtkCList *)src_ctree;
-	if(src_ctree == NULL)
-	    return;
+	src_ctree = GTK_CTREE(src_editor->layout_ctree);
+	src_clist = GTK_CLIST(src_ctree);
 
-	/* Get pointer to core structure on target editor */
-	core_ptr = MEDIT_CORE(editor->core_ptr);
-	if(core_ptr != NULL)
-	    pixmaps_list = &core_ptr->pixmaps_list;
-	else
-	    return;
+	core = editor->core;
+	pixmaps_list = &core->pixmaps_list;
 
-	/* Clip insert row */
+	/* Clip the insert row */
 	if(insert_row < 0)
 	    insert_row = 0;
 
 	/* Begin inserting */
-	if(1)
+	if(TRUE)
 	{               
 	    /* Insert at start or in the middle */
 	    GtkCTreeNode *insert_node;
@@ -688,9 +648,8 @@ static void EditorDNDTrunkListAdd(
 	    /* Begin copying and inserting the branch on the source
 	     * editor to the target editor's layout_ctree.
 	     */
-	    sibling_branch = ((insert_node_row == NULL) ?
-		NULL : insert_node_row->sibling
-	    );
+	    sibling_branch = (insert_node_row != NULL) ?
+		insert_node_row->sibling : NULL;
 	    for(i = total_branches - 1; i >= 0; i--)
 	    {
 		sibling_branch = EditorDNDTrunkListAddIterate(
@@ -707,7 +666,7 @@ static void EditorDNDTrunkListAdd(
 		    editor->total_layout_trunks = 0;
 		n = editor->total_layout_trunks;
 		editor->total_layout_trunks = n + 1;
-		editor->layout_trunk = (GtkCTreeNode **)realloc(
+		editor->layout_trunk = (GtkCTreeNode **)g_realloc(
 		    editor->layout_trunk,
 		    editor->total_layout_trunks * sizeof(GtkCTreeNode *)
 		);
@@ -803,7 +762,7 @@ static void EditorDNDViewerIndexItemLoad(
 		switch(item->type)
 		{
 		  case ViewerIndexItemTypeManualPage:
-		    EditorFileLoad(
+		    EditorFileOpen(
 			editor, item->full_path,
 			insert_node, FALSE
 		    );
@@ -827,17 +786,17 @@ void EditorDNDSetIcon(
 	editor_struct *editor, editor_item_struct *item
 )
 {
-	medit_core_struct *core_ptr;
+	medit_core_struct *core;
 	medit_pixmaps_list_struct *pixmaps_list;
 
 	if(editor == NULL)
 	    return;
 
-	core_ptr = MEDIT_CORE(editor->core_ptr);
-	if(core_ptr == NULL)
+	core = editor->core;
+	if(core == NULL)
 	    return;
 
-	pixmaps_list = &core_ptr->pixmaps_list;
+	pixmaps_list = &core->pixmaps_list;
 
 	if(item == NULL)
 	{
@@ -906,41 +865,29 @@ void EditorDNDDataRequestCB(
 	gpointer data 
 )
 {
-	gboolean data_sent = FALSE;
 	gchar *buf;
-	GtkCTreeNode *branch_ptr;
+	GtkCTreeNode *branch;
 	editor_struct *editor = EDITOR(data);
 	if((widget == NULL) || (editor == NULL) || (dc == NULL))
 	    return;
 
-	if(!editor->initialized)
-	    return;
-
-	if(widget != editor->layout_ctree)
-	{
-	    g_printerr(
-		"EditorDNDDataRequestCB(): widget != editor->layout_ctree\n"
-	    );
-	    return;
-	}
-
 	/* Get selected branch on editor's layout ctree.
 	 * Note currently we only allow one selected branch at
 	 * a time
 	 */
-	branch_ptr = editor->selected_branch;
+	branch = editor->selected_branch;
 
 	/* Need to apply values if this is the selected branch to ensure
 	 * we send out a command with a branch pointer who's data is up
 	 * to date
 	 */
-	if(branch_ptr == editor->selected_branch)
+	if(branch == editor->selected_branch)
 	{
 	    /* Fetch values from the editor's widgets and place them to
 	     * the branch data depending on its type. Menus will be
 	     * updated
 	     */
-	    EditorDoApplyValues(editor, branch_ptr);
+	    EditorDoApplyValues(editor, branch);
 	}
 
 	/* Allocate buffer that we will be sending out, containing
@@ -948,51 +895,31 @@ void EditorDNDDataRequestCB(
 	 *
 	 * <editor_ptr> <branch_ptr...>
 	 */
-	if(branch_ptr != NULL)
+	if(branch != NULL)
 	    buf = g_strdup_printf(
 		"%.8x %.8x",
 		(guint32)editor,
-		(guint32)branch_ptr
+		(guint32)branch
 	    );
 	else
 	    buf = g_strdup_printf(
-                "%.8x",
+		"%.8x",
 		(guint32)editor
 	    );
 
-	/* Send out data */
+	/* Send out the requested data */
 	gtk_selection_data_set(
 	    selection_data,
 	    GDK_SELECTION_TYPE_STRING,
 	    8,			/* 8 bits per character */
 	    buf, strlen(buf)
 	);
-	data_sent = TRUE;
 
 	g_free(buf);
-
-
-	/* Failed to send out data? */
-	if(!data_sent)
-	{
-	    const gchar *s = "Error";
-
-	    gtk_selection_data_set(
-		selection_data,
-		GDK_SELECTION_TYPE_STRING,
-		8,      /* 8 bits per character */
-		s, strlen(s)
-	    );
-	    data_sent = TRUE;
-	}
 }
 
 /*
- *	Editor DND data recieve callback.
- *
- *	Parses the command recieved for item move or copy.
- *
- *	Note that data deletion will be handled here.
+ *	Editor DND "drag_data_received" signal callback.
  */
 void EditorDNDDataRecievedCB(
 	GtkWidget *widget,
@@ -1012,10 +939,6 @@ void EditorDNDDataRecievedCB(
 	if((widget == NULL) || (editor == NULL) || (dc == NULL))
 	    return;
 
-	if(!editor->initialized)
-	    return;
-
-	/* Important, check if we got data */
 	if(selection_data == NULL)
 	    return;
 	if(selection_data->length < 0)
@@ -1023,7 +946,7 @@ void EditorDNDDataRecievedCB(
 
 	/* Source and target same? */
 	source_widget = gtk_drag_get_source_widget(dc);
-	same = ((source_widget == widget) ? TRUE : FALSE);
+	same = (source_widget == widget) ? TRUE : FALSE;
 
 	/* Check if data needs to be deleted by testing if this
 	 * drag operation is not a copy
@@ -1042,7 +965,7 @@ void EditorDNDDataRecievedCB(
 	     * coordinates.
 	     */
 	    if(gtk_clist_get_selection_info(
-		    clist, x, y, &row, &column
+		clist, x, y, &row, &column
 	    ))
 	    {
 /*		row -= 1;	*/	/* Need to offset */
@@ -1055,7 +978,7 @@ void EditorDNDDataRecievedCB(
 	    if(row < 0)
 		row = 0;
 	    /* Row is now (or atleast should be) positioned where  
-	     * we want to insert.
+	     * we want to insert
 	     */
 
 	    /* Editor layout ctree branch node transfer command? */
@@ -1068,7 +991,6 @@ void EditorDNDDataRecievedCB(
 				is_branch_header = FALSE,
 				is_branch_section = FALSE;
 
-
 		/* Parse command string, src_editor points to the source
 		 * editor and branch and total_branches are the selected
 		 * branch(es) on the source editor's layout GtkCTree
@@ -1079,23 +1001,24 @@ void EditorDNDDataRecievedCB(
 		    &branch, &total_branches
 		);
 
-		/* Is source editor valid? */
+		/* Is the source editor valid? */
 		if(src_editor != NULL)
 		{
 		    editor_item_struct *item;
 
 		    /* Check what types of branch item data types we
-		     * just got.
+		     * just got
 		     */
 		    for(i = 0; i < total_branches; i++)
 		    {
 			item = EditorBranchGetData(
-			    (GtkCTree *)src_editor->layout_ctree, branch[i]
+			    GTK_CTREE(src_editor->layout_ctree),
+			    branch[i]
 			);
 			if(item == NULL)
 			    continue;
 
-			/* Check item type */
+			/* Check the item's type */
 			switch(item->type)
 			{
 			  case EditorItemTypeFile:
@@ -1117,22 +1040,17 @@ void EditorDNDDataRecievedCB(
 		    )
 		    {
 			CDialogGetResponse(
-			    "Invalid operation!",
-"Cannot drag and drop both file reference and sectional\n\
+			    "Invalid Operation",
+"Unable to drag and drop both file reference and sections\n\
 data types at once.",
-"You cannot drag and drop items of type file reference\n\
-and sectional data (ie header and section types) at once.\n\
-You need to select only one or a group of source items of\n\
-the same type to drag and drop.",
-			    CDIALOG_ICON_ERROR,
-			    CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
+			    NULL,
+			    CDIALOG_ICON_WARNING,
+			    CDIALOG_BTNFLAG_OK,
 			    CDIALOG_BTNFLAG_OK
 			);
 
-			/* Free only list of branches from source editor */
+			/* Delete the branches list */
 			g_free(branch);
-			branch = NULL;
-			total_branches = 0;
 
 			return;
 		    }
@@ -1146,16 +1064,11 @@ the same type to drag and drop.",
 			/* Drag and drop on same? */
 			if(branch[0] == insert_row_node)
 			{
-			    /* Free only list of branches from source editor */
 			    g_free(branch);
-			    branch = NULL;
-			    total_branches = 0;
-
 			    return;
 			}
 		    }
 
-
 		    /* ************************************************ */
 		    /* Handle by branch item data type */
 		    /* File (which implies toplevel trunk branch)? */
@@ -1181,17 +1094,17 @@ the same type to drag and drop.",
 			     */
 			    EditorDNDDoDeleteItems(
 				src_editor, branch, total_branches
-			    );   
+			    );
 			    branch = NULL;
 			    total_branches = 0;
 			}
 
 			/* Update column widths and menus */
 			gtk_clist_set_column_width(
-			    (GtkCList *)ctree,
+			    GTK_CLIST(ctree),
 			    0,			/* Column */
 			    gtk_clist_optimal_column_width(
-				(GtkCList *)ctree, 0
+				GTK_CLIST(ctree), 0
 			    )
 			);
 			EditorUpdateMenus(editor);
@@ -1202,10 +1115,10 @@ the same type to drag and drop.",
 			if(!same)
 			{
 			    gtk_clist_set_column_width(
-				(GtkCList *)src_editor->layout_ctree,
+				GTK_CLIST(src_editor->layout_ctree),
 				0,		/* Column */
 				gtk_clist_optimal_column_width(
-				    (GtkCList *)src_editor->layout_ctree, 0
+				    GTK_CLIST(src_editor->layout_ctree), 0
 				)
 			    );
 			    EditorUpdateMenus(src_editor);
@@ -1216,10 +1129,9 @@ the same type to drag and drop.",
 		    else if(is_branch_header || is_branch_section)
 		    {
 			editor_item_struct **new_item;
-			gint total_new_items;
 
 			/* Copy new items from source editor */
-			total_new_items = total_branches;
+			gint total_new_items = total_branches;
 			if(total_new_items > 0)
 			    new_item = (editor_item_struct **)g_malloc0(
 				total_new_items * sizeof(editor_item_struct *)
@@ -1278,10 +1190,10 @@ the same type to drag and drop.",
 
 			/* Update column widths and menus */
 			gtk_clist_set_column_width(
-			    (GtkCList *)ctree,
+			    GTK_CLIST(ctree),
 			    0,			/* Column */
 			    gtk_clist_optimal_column_width(
-				(GtkCList *)ctree, 0
+				GTK_CLIST(ctree), 0
 			    )
 			);
 			EditorUpdateMenus(editor);
@@ -1292,10 +1204,10 @@ the same type to drag and drop.",
 			if(!same)
 			{
 			    gtk_clist_set_column_width(
-				(GtkCList *)src_editor->layout_ctree,
+				GTK_CLIST(src_editor->layout_ctree),
 				0,			/* Column */
 				gtk_clist_optimal_column_width(
-				    (GtkCList *)src_editor->layout_ctree, 0
+				    GTK_CLIST(src_editor->layout_ctree), 0
 				)
 			    );
 			    EditorUpdateMenus(src_editor);
@@ -1303,20 +1215,17 @@ the same type to drag and drop.",
 		    }
 		}
 
-		/* Free only list of branches from source editor */
+		/* Delete the branches list from the source editor */
 		g_free(branch);
-		branch = NULL;
-		total_branches = 0;
 	    }
 	    /* ******************************************************** */
 	    /* Viewer index ctree branch node transfer command? */
 	    else if(info == MEDIT_DND_TYPE_INFO_VIEWER_BRANCH_CMD)
 	    {
 		viewer_struct *src_viewer = NULL;
-		GtkCTreeNode **branch = NULL;   
+		GtkCTreeNode **branch = NULL;
 		gint total_branches = 0;
 
-
 		/* Parse command string. Value of src_viewer points to
 		 * the source viewer and branch and total_branches are
 		 * the selected branch(es) on the source viewer's index
@@ -1353,12 +1262,8 @@ the same type to drag and drop.",
 		    }
 		}
 
-		/* Free only list of branches from source viewer's
-		 * index ctree.
-		 */
+		/* Delete the branches list from the source viewer */
 		g_free(branch);
-		branch = NULL;
-		total_branches = 0;
 	    }
 	    /* Other standard DND target types? */
 	    else if((info == MEDIT_DND_TYPE_INFO_TEXT_PLAIN) ||
@@ -1369,7 +1274,7 @@ the same type to drag and drop.",
 		gchar *path = EditorDNDParseURL(
 		    selection_data->data, selection_data->length
 		);
-		EditorFileLoad(editor, path, editor->selected_branch, FALSE);
+		EditorFileOpen(editor, path, editor->selected_branch, FALSE);
 		g_free(path);
 	    }
  
