@@ -15,7 +15,7 @@ extern void EditorDNDParseCmd(
         GtkCTreeNode ***branch, int *total_branches
 );
 extern gchar *EditorDNDParseURL(
-        const gchar *string, gint len
+        const gchar *s, const gint len
 );
 
 extern void EditorDNDSetIcon(
