@@ -18,18 +18,18 @@
 #include "config.h"
 
 
-static gint EditorFileLoadProgressCB(
+static gint EditorFileOpenProgressCB(
 	glong cur, glong max, gpointer data
 );
 static gint EditorFileSaveProgressCB(
 	glong cur, glong max, gpointer data
 );
 
-static void EditorFileLoadParseTitleHeading(
+static void EditorFileOpenParseTitleHeading(
 	editor_struct *editor, const gchar *line_ptr,
 	editor_item_struct *item
 );
-static void EditorFileLoadParseHeader(
+static void EditorFileOpenParseHeader(
 	editor_struct *editor, editor_item_struct *item
 );
 
@@ -43,7 +43,7 @@ static void EditorFileSaveFormatSection(
 );
 
 
-gint EditorFileLoad(
+gint EditorFileOpen(
 	editor_struct *editor, const gchar *filename,
 	GtkCTreeNode *branch,	/* Insert after this toplevel trunk */
 	gboolean as_template
@@ -75,7 +75,7 @@ gint EditorFileSaveAs(
  *
  *	Updates the progress bar.
  */
-static gint EditorFileLoadProgressCB(
+static gint EditorFileOpenProgressCB(
 	glong cur, glong max, gpointer data
 )
 {
@@ -124,7 +124,7 @@ static gint EditorFileSaveProgressCB(
  *	Fetched values will be stored on the item structure which
  *	is assumed to be of type EditorItemTypeHeader.
  */
-static void EditorFileLoadParseTitleHeading(
+static void EditorFileOpenParseTitleHeading(
 	editor_struct *editor, const gchar *line_ptr,
 	editor_item_struct *item
 )
@@ -365,22 +365,19 @@ static void EditorFileLoadParseTitleHeading(
  *	Post processing for loading of header item. Parses each line
  *	on the given item assumed to be of type EditorItemTypeHeader.
  */
-static void EditorFileLoadParseHeader(
+static void EditorFileOpenParseHeader(
 	editor_struct *editor, editor_item_struct *item
 )
 {
 	gchar ***line, *line_ptr;
 	gint i, line_num, *total_lines;
 
-
 	if((editor == NULL) || (item == NULL))
 	    return;
 
-	/* Get pointer to lines array on item data */
+	/* Iterate through the lines list */
 	line = &item->line;
 	total_lines = &item->total_lines;
-
-	/* Go through each line */
 	for(line_num = 0; line_num < (*total_lines); line_num++)
 	{
 	    line_ptr = (*line)[line_num];
@@ -404,11 +401,11 @@ static void EditorFileLoadParseHeader(
 		 * arguments pointed to by line_ptr and updates the
 		 * values on the item.
 		 */
-		EditorFileLoadParseTitleHeading(
+		EditorFileOpenParseTitleHeading(
 		    editor, line_ptr, item
 		);
 
-		/* Remove this line from the lines array */
+		/* Remove this line from the lines list */
 		g_free((*line)[line_num]);
 		(*line)[line_num] = line_ptr = NULL;
 
@@ -416,6 +413,8 @@ static void EditorFileLoadParseHeader(
 		for(i = line_num; i < (*total_lines); i++)
 		    (*line)[i] = (*line)[i + 1];
 
+		(*line)[(*total_lines)] = NULL;	/* for g_strfreev() */
+
 		line_num--;	/* Go back one line */
 		continue;
 	    }
@@ -438,7 +437,7 @@ static void EditorFileLoadParseHeader(
 		 */
 		new_line_ptr = STRDUP(line_ptr);
 
-		/* Free old line */
+		/* Delete the old line */
 		g_free((*line)[line_num]);
 		line_ptr = NULL;
 
@@ -451,7 +450,6 @@ static void EditorFileLoadParseHeader(
 
 		continue;
 	    }
-
 	}
 }
 
@@ -471,8 +469,6 @@ static void EditorFileSaveFormatHeader(
 )
 {
 	gint i;
-	const gchar *line;
-	gchar *new_line;
 
 	if((editor == NULL) || (item == NULL) || (mp_header == NULL))
 	    return;
@@ -482,13 +478,11 @@ static void EditorFileSaveFormatHeader(
 	mp_header->line = NULL;
 	mp_header->total_lines = 0;
 
-	/* Allocate lines pointer array on manual page header structure
-	 * to match all lines on item data
-	 */
+	/* Copy the lines list */
 	mp_header->total_lines = item->total_lines;
 	if(mp_header->total_lines > 0)
 	{
-	    mp_header->line = (gchar **)g_malloc0(
+	    mp_header->line = (gchar **)g_malloc(
 		mp_header->total_lines * sizeof(gchar *)
 	    );
 	    if(mp_header->line == NULL)
@@ -496,55 +490,39 @@ static void EditorFileSaveFormatHeader(
 		mp_header->total_lines = 0;
 		return;
 	    }
+
+	    /* Copy each line, prefixing a comment prefix to each line */
+	    for(i = 0; i < item->total_lines; i++)
+		mp_header->line[i] = g_strconcat(
+		    ".\\\" ",
+		    item->line[i],
+		    NULL
+		);
 	}
 
-	/* First copy each line on the item data structure to the manual
-	 * page header structure. Prefixing a comment prefix to each
-	 * line
-	 */
-	for(i = 0; i < item->total_lines; i++)
-	{
-	    line = item->line[i];
-	    if(line == NULL)
-		continue;
-
-	    /* Create new line with a groff comment prefix */
-	    new_line = STRDUP("");
-	    new_line = strcatalloc(new_line, ".\\\" ");
-	    new_line = strcatalloc(new_line, line);
-
-	    /* Set new line to manual page header structure line array */
-	    mp_header->line[i] = new_line;
-	    new_line = NULL;
-	}
-
-
 	/* Append title heading line to manual page header */
-	new_line = g_strdup_printf(
-	    ".TH \"%s\" \"%s\" \"%s\" \"%s\" \"%s\"",
-	    item->header_name,
-	    item->header_section_number,
-	    item->header_version,
-	    item->header_author,
-	    item->header_catagory
-	);
-
 	i = mp_header->total_lines;
 	mp_header->total_lines = i + 1;
 	mp_header->line = (gchar **)g_realloc(
 	    mp_header->line,
 	    mp_header->total_lines * sizeof(gchar *)
 	);
-	if(mp_header->line == NULL)
+	if(mp_header->line != NULL)
 	{
-	    mp_header->total_lines = 0;
-	    g_free(new_line);
+	    mp_header->line[i] = g_strdup_printf(
+		".TH \"%s\" \"%s\" \"%s\" \"%s\" \"%s\"",
+		item->header_name,
+		item->header_section_number,
+		item->header_version,
+		item->header_author,
+		item->header_catagory
+	    );
 	}
 	else
 	{
-	    mp_header->line[i] = new_line;
+	    mp_header->total_lines = 0;
 	}
-	new_line = NULL;
+
 }
 
 /*
@@ -559,11 +537,6 @@ static void EditorFileSaveFormatSection(
 	mp_section_struct *mp_section
 )
 {
-	const gchar *line_ptr;
-	gchar *new_line_ptr;
-	gint i;
-
-
 	if((editor == NULL) || (item == NULL) || (mp_section == NULL))
 	    return;
 
@@ -573,15 +546,14 @@ static void EditorFileSaveFormatSection(
 	strlistfree(mp_section->line, mp_section->total_lines);
 	mp_section->line = NULL;
 	mp_section->total_lines = 0;
-	
-	 
-	/* Allocate lines pointer array on manual page section structure
-	 * to match all lines on item data structure
-	 */
+
+	/* Copy the lines list */
 	mp_section->total_lines = item->total_lines;
 	if(mp_section->total_lines > 0)
 	{
-	    mp_section->line = (gchar **)g_malloc0(
+	    gint i;
+
+	    mp_section->line = (gchar **)g_malloc(
 		mp_section->total_lines * sizeof(gchar *)
 	    );
 	    if(mp_section->line == NULL)
@@ -589,25 +561,11 @@ static void EditorFileSaveFormatSection(
 		mp_section->total_lines = 0;
 		return;
 	    }
+	    for(i = 0; i < item->total_lines; i++)
+		mp_section->line[i] = STRDUP(item->line[i]);
 	}
 
-	/* First copy each line on the item data structure to the manual
-	 * page section structure
-	 */
-	for(i = 0; i < item->total_lines; i++)
-	{
-	    line_ptr = item->line[i];
-	    if(line_ptr == NULL)
-		continue;
-	    
-	    /* Create new line */
-	    new_line_ptr = STRDUP(line_ptr);
-
-	    /* Set new line to manual page section structure line array */
-	    mp_section->line[i] = new_line_ptr;
-	}
-
-	/* Copy section name */
+	/* Copy the section name */
 	g_free(mp_section->section);
 	mp_section->section = STRDUP(item->section_name);
 }
@@ -633,7 +591,7 @@ static void EditorFileSaveFormatSection(
  *	Returns non-zero on error, where -1 is a general error and -2 is
  *	file not found/not allowed to read.
  */
-gint EditorFileLoad(
+gint EditorFileOpen(
 	editor_struct *editor, const gchar *filename,
 	GtkCTreeNode *branch,	/* Insert after this toplevel trunk */
 	gboolean as_template
@@ -649,31 +607,18 @@ gint EditorFileLoad(
 	GtkCList *clist;
 	GtkCTreeNode *trunk, *new_trunk = NULL;
 	editor_item_struct *editor_item;
-	medit_core_struct *core_ptr;
+	medit_core_struct *core;
 	medit_pixmaps_list_struct *pixmaps_list;
 
-
 	if((editor == NULL) || (filename == NULL))
-	    return(-1);
+	    return(-2);
 
-	if(!editor->initialized)
-	    return(-1);
-
-	/* Already processing? */
-	if(editor->processing)
-	    return(-1);
-
-	ctree = (GtkCTree *)editor->layout_ctree;
-	clist = (GtkCList *)ctree;
-	if(ctree == NULL)
-	    return(-1);
-
-	core_ptr = MEDIT_CORE(editor->core_ptr);
-	if(core_ptr == NULL)
-	    return(-1);
+	ctree = GTK_CTREE(editor->layout_ctree);
+	clist = GTK_CLIST(ctree);
+	core = editor->core;
 
 	/* Get pointer to pixmaps list on core structure */
-	pixmaps_list = &core_ptr->pixmaps_list;
+	pixmaps_list = &core->pixmaps_list;
 
 
 	/* Be sure to apply values of currently selected branch (not
@@ -717,7 +662,7 @@ gint EditorFileLoad(
 	 */
 
 	/* Mark editor as processing */
-	editor->processing = TRUE;
+	editor->freeze_count++;
 	EditorSetBusy(editor);
 	EditorSetStatusMessage(editor, "Loading manual page...");
 
@@ -730,7 +675,7 @@ gint EditorFileLoad(
 	    filename, NULL,
 	    &mp_header,
 	    &mp_section, &total_mp_sections,
-	    editor, EditorFileLoadProgressCB
+	    editor, EditorFileOpenProgressCB
 	);
 	if(status)
 	{
@@ -751,7 +696,7 @@ gint EditorFileLoad(
 	    /* Update menus */
 	    EditorUpdateMenus(editor);
 
-	    editor->processing = FALSE;
+	    editor->freeze_count--;
 	    EditorSetReady(editor);   
 
 	    return(status);
@@ -817,7 +762,7 @@ gint EditorFileLoad(
 		    NULL,		/* Parent */
 		    branch,		/* This branch */
 		    FALSE,		/* Is leaf */
-		    NULL, 0
+		    NULL, 0		/* Lines list */
 		);
 		if(editor_item != NULL)
 		{
@@ -827,11 +772,11 @@ gint EditorFileLoad(
 			/* Loading as a template, give it an untitled
 			 * name and increment untitled count on core
 			 */
-			core_ptr->untitled_count++;
+			core->untitled_count++;
 			g_free(editor_item->name);
 			editor_item->name = g_strdup_printf(
 			    "Untitled%i.1",
-			    core_ptr->untitled_count
+			    core->untitled_count
 			);
 
 			/* Mark as having changes */
@@ -894,8 +839,7 @@ gint EditorFileLoad(
 			trunk,		/* Parent */
 			branch,		/* This branch */
 			TRUE,		/* Is leaf */
-			mp_header->line,
-			mp_header->total_lines
+			mp_header->line, mp_header->total_lines
 		    );
 
 		    /* Header's lines are transfered, so mark them
@@ -913,7 +857,7 @@ gint EditorFileLoad(
 		    /* Do post processing on header item data, need
 		     * to fetch the header item's title heading.
 		     */
-		    EditorFileLoadParseHeader(
+		    EditorFileOpenParseHeader(
 			editor, editor_item
 		    );
 		}
@@ -972,8 +916,7 @@ gint EditorFileLoad(
 			trunk,		/* Parent */
 			branch,		/* This branch */
 			TRUE,		/* Is leaf */
-			mp_section_ptr->line,
-			mp_section_ptr->total_lines
+			mp_section_ptr->line, mp_section_ptr->total_lines
 		    );
 
 		    /* Section's lines are transfered, so mark them
@@ -1041,8 +984,7 @@ gint EditorFileLoad(
 	/* Update menus */
 	EditorUpdateMenus(editor);
 
-	/* Mark processing done */
-	editor->processing = FALSE;
+	editor->freeze_count--;
 
 	/* Force select new trunk, new_trunk is the toplevel trunk
 	 * node for this newly loaded file (do this after processing
@@ -1088,24 +1030,14 @@ gint EditorFileSave(
 	GtkCTree *ctree;
 	GtkCTreeNode *trunk;
 	editor_item_struct *item;
-	medit_core_struct *core_ptr;
-
+	medit_core_struct *core;
 
 	if((editor == NULL) || (branch == NULL))
-	    return(-1);
-
-	if(!editor->initialized)
-	    return(-1);
-
-	/* Already processing? */
-	if(editor->processing)
-	    return(-1);
+	    return(-2);
 
 	toplevel = editor->toplevel;
-	ctree = (GtkCTree *)editor->layout_ctree;
-	core_ptr = MEDIT_CORE(editor->core_ptr);
-	if((ctree == NULL) || (core_ptr == NULL))
-	    return(-1);
+	ctree = GTK_CTREE(editor->layout_ctree);
+	core = editor->core;
 
 	/* Be sure to apply values of currently selected branch (not
 	 * the given branch) before saving. This ensures we save the most
@@ -1167,7 +1099,7 @@ different path.",
 
 
 	/* Mark editor as processing */
-	editor->processing = TRUE;
+	editor->freeze_count++;
 	EditorSetBusy(editor);
 
 	EditorSetStatusMessage(editor, "Formatting data...");
@@ -1301,7 +1233,8 @@ different path.",
 	/* Update menus */
 	EditorUpdateMenus(editor);
 
-	editor->processing = FALSE;
+	editor->freeze_count--;
+
 	EditorSetReady(editor);
 
 	return(status);
@@ -1331,22 +1264,16 @@ gint EditorFileSaveAs(
 	GtkCTreeRow *branch_row;
 	GtkCTreeNode *trunk;
 	editor_item_struct *item;
-	medit_core_struct *core_ptr;
+	medit_core_struct *core;
 	medit_pixmaps_list_struct *pixmaps_list;
 
 	if((editor == NULL) || (branch == NULL) || (filename == NULL))
-	    return(-1);
-
-	if(!editor->initialized)
-	    return(-1);
+	    return(-2);
 
 	toplevel = editor->toplevel;
-	ctree = (GtkCTree *)editor->layout_ctree;
-	core_ptr = MEDIT_CORE(editor->core_ptr);
-	if((ctree == NULL) || (core_ptr == NULL))
-	    return(-1);
-
-	pixmaps_list = &core_ptr->pixmaps_list;
+	ctree = GTK_CTREE(editor->layout_ctree);
+	core = editor->core;
+	pixmaps_list = &core->pixmaps_list;
 
 	/* Find toplevel trunk branch of the given branch which will
 	 * be the one to save data from.
@@ -1394,7 +1321,7 @@ gint EditorFileSaveAs(
 	    );
 	    CDialogSetTransientFor(toplevel);
 	    status = CDialogGetResponse(
-"Confirm overwrite?",
+"Confirm Overwrite",
 		s,
 "You are being asked if you want to overwrite an existing\n\
 file. If you say yes then any existing data on the file\n\
@@ -1482,7 +1409,10 @@ file, if you are unsure say cancel.",
 	editor->last_save_as_path = STRDUP(filename);
 	if(editor->last_save_as_path != NULL)
 	{
-	    s = strrchr(editor->last_save_as_path, G_DIR_SEPARATOR);
+	    s = (gchar *)strrchr(
+		(char *)editor->last_save_as_path,
+		G_DIR_SEPARATOR
+	    );
 	    if(s != NULL)
 		*s = '\0';
 	}
