@@ -9,7 +9,7 @@
 #include "editor.h"   
 
 
-extern gint EditorFileLoad(
+extern gint EditorFileOpen(
 	editor_struct *editor, const gchar *filename,
 	GtkCTreeNode *branch,		/* Insert after this toplevel trunk */
 	gboolean as_template
