@@ -7,7 +7,6 @@
 #include "editor.h"
 #include "editorfip.h"
 #include "editorfipcb.h"
-
 #include "manedit.h"
 #include "maneditcb.h"
 #include "messages.h"
@@ -33,7 +32,7 @@ gint EditorFIPAddItem(
 	gpointer branch_data,
 	gint text_sel_start, gint text_sel_end
 );
-void EditorFIPItemDelete(editor_fip_item_struct *item_ptr);
+void EditorFIPItemDelete(editor_fip_item_struct *item);
 
 void EditorFIPSetBusy(editor_fip_struct *fip);
 void EditorFIPSetReady(editor_fip_struct *fip);
@@ -59,6 +58,18 @@ void EditorFIPUnmap(editor_fip_struct *fip);
 void EditorFIPDelete(editor_fip_struct *fip);
 
 
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
+
+
 #define FIP_DEF_WIDTH	640
 #define FIP_DEF_HEIGHT	480
 
@@ -80,11 +91,10 @@ gint EditorFIPAddItem(
 	gint text_sel_start, gint text_sel_end
 )
 {
-	editor_fip_item_struct *item_ptr;
-	GtkCList *clist;
-	gchar **text;
 	gint row = -1;
-
+	gchar **text;   
+	GtkCList *clist;
+	editor_fip_item_struct *item;
 
 	if(fip == NULL)
 	    return(row);
@@ -97,21 +107,19 @@ gint EditorFIPAddItem(
 	    return(row);
 
 	/* Allocate a new item structure */
-	item_ptr = (editor_fip_item_struct *)g_malloc0(
+	item = EDITOR_FIP_ITEM(g_malloc0(
 	    sizeof(editor_fip_item_struct)
-	);
-	if(item_ptr == NULL)
+	));
+	if(item == NULL)
 	    return(row);
 
-	/* Set values on new item structure */
-	item_ptr->editor_fip_ptr = (gpointer )fip;
-	item_ptr->clist = clist;
-
-	item_ptr->found_branch = found_branch;
-	item_ptr->branch_data = branch_data;
-	item_ptr->text_sel_start = text_sel_start;
-	item_ptr->text_sel_end = text_sel_end;
-	item_ptr->line_num = line_num;
+	item->editor_fip = fip;
+	item->clist = clist;
+	item->found_branch = found_branch;
+	item->branch_data = branch_data;
+	item->text_sel_start = text_sel_start;
+	item->text_sel_end = text_sel_end;
+	item->line_num = line_num;
 
 	/* Allocate text for columns on results clist */
 	text = (gchar **)g_malloc0(4 * sizeof(gchar *));
@@ -142,7 +150,7 @@ gint EditorFIPAddItem(
 	    /* Set item structure pointer to new row on results clist
 	     * and also set the destroy notify callback function */
 	    gtk_clist_set_row_data_full(
-		clist, (gint)row, (gpointer)item_ptr,
+		clist, (gint)row, (gpointer)item,
 		EditorFIPItemDestroyCB
 	    );
 	}
@@ -150,7 +158,7 @@ gint EditorFIPAddItem(
 	{
 	    /* Could not add item pointer to row that was not created,
 	     * so delete item structure */
-	    EditorFIPItemDelete(item_ptr);
+	    EditorFIPItemDelete(item);
 	}
 
 	return(row);
@@ -161,12 +169,12 @@ gint EditorFIPAddItem(
  *	Deletes the results item structure and all its allocated
  *	resources.
  */
-void EditorFIPItemDelete(editor_fip_item_struct *item_ptr)
+void EditorFIPItemDelete(editor_fip_item_struct *item)
 {
-	if(item_ptr == NULL)
+	if(item == NULL)
 	    return;
 
-	g_free(item_ptr);
+	g_free(item);
 }
 
 /*
@@ -879,8 +887,8 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 void EditorFIPUpdateMenus(editor_fip_struct *fip)
 {
 	static gboolean reenterant = FALSE;
-	GtkWidget *w, *menu;
 	gboolean sensitivity;
+	GtkWidget *w, *menu;
 
 	if(fip == NULL)
 	    return;
@@ -895,21 +903,14 @@ void EditorFIPUpdateMenus(editor_fip_struct *fip)
 	else
 	    reenterant = TRUE;
 
-#define SET_WIDGET_SENSITIVITY		\
-{ \
- if(w != NULL) \
-  gtk_widget_set_sensitive(w, sensitivity); \
+#define SET_WIDGET_SENSITIVITY		{	\
+ if(w != NULL)					\
+  gtk_widget_set_sensitive(w, sensitivity);	\
 }
-#define SET_CHECK_MENU_ITEM_STATE	\
-{ \
- if(w != NULL) \
-  gtk_check_menu_item_set_active( \
-   GTK_CHECK_MENU_ITEM(w), \
-   state \
-  ); \
+#define SET_CHECK_MENU_ITEM_STATE	{	\
+ GUIMenuItemSetCheck(w, state, TRUE);		\
 }
 
-
 	/* Results clist pop up menu */
 	menu = fip->results_menu;
 	if(menu != NULL)
