@@ -1,10 +1,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gtk/gtk.h>
 #include <unistd.h>
 
 #include "../include/string.h"
-#include "../include/strexp.h"
 
 #include "guiutils.h"
 #include "cdialog.h"
@@ -13,7 +13,6 @@
 #include "editorfip.h"
 #include "editorfipop.h"
 #include "editorop.h"
-
 #include "manedit.h"
 
 
@@ -65,9 +64,16 @@ gint EditorFIPDoFind(
 );
 
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -182,31 +188,30 @@ static gint EditorFIPDoFindAnyBranchIteration(
 	gint i, n, new_matches, match_count = 0;
 	gchar **line;
 	GtkCTreeRow *branch_row;
-	editor_item_struct *item_ptr;
+	editor_item_struct *item;
 	fip_match_struct *match, *match_ptr;
 
-
 	if(branch == NULL)
 	    return(match_count);
 
 	if(fip->stop_find_count > 0)
 	    return(match_count);
 
-	EditorFIPSetStatusProgress(fip, -1.0);
+	EditorFIPSetStatusProgress(fip, -1.0f);
 
 	/* Get item data from branch */
-	item_ptr = EditorBranchGetData(layout_ctree, branch);
-	if(item_ptr != NULL)
+	item = EditorBranchGetData(layout_ctree, branch);
+	if(item != NULL)
 	{
 	    gchar *s;
 
 	    /* Search through item data by its type */
-	    switch(item_ptr->type)
+	    switch(item->type)
 	    {
 	      case EditorItemTypeFile:
 		s = g_strdup_printf(
 		    "Searching: Manual Page \"%s\"",
-		    item_ptr->file_name
+		    item->name
 		);
 		EditorFIPSetStatusMessage(fip, s);
 		g_free(s);
@@ -225,8 +230,8 @@ static gint EditorFIPDoFindAnyBranchIteration(
 		if(line != NULL)
 		{
 		    /* Search through header name */
-		    line[0] = (item_ptr->header_name != NULL) ?
-			g_strdup(item_ptr->header_name) : NULL;
+		    line[0] = (item->header_name != NULL) ?
+			STRDUP(item->header_name) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0, n = 0; i < strc; i++)
@@ -245,20 +250,20 @@ static gint EditorFIPDoFindAnyBranchIteration(
 		    {
 			EditorFIPAddItem(
 			    fip,
-			    item_ptr->header_name,
+			    item->header_name,
 			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
 			    branch,		/* Found branch */
-			    item_ptr,		/* Branch data */
+			    item,		/* Branch data */
 			    -1, -1
 			);
 		    }
 
 		    /* Search through header section number */
 		    g_free(line[0]);
-		    line[0] = (item_ptr->header_section_number != NULL) ?
-			g_strdup(item_ptr->header_section_number) : NULL;
+		    line[0] = (item->header_section_number != NULL) ?
+			STRDUP(item->header_section_number) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0, n = 0; i < strc; i++)
@@ -277,21 +282,20 @@ static gint EditorFIPDoFindAnyBranchIteration(
 		    {
 			EditorFIPAddItem(   
 			    fip,
-			    item_ptr->header_section_number,
+			    item->header_section_number,
 			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
 			    branch,		/* Found branch */
-			    item_ptr,		/* Branch data */
+			    item,		/* Branch data */
 			    -1, -1
 			);
 		    }
 		
-		    /* Search through header version */
+		    /* Search through the header version */
 		    g_free(line[0]);
-		    line[0] = ((item_ptr->header_version == NULL) ?
-			NULL : strdup(item_ptr->header_version)
-		    );
+		    line[0] = (item->header_version != NULL) ?
+			STRDUP(item->header_version) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0, n = 0; i < strc; i++)
@@ -310,21 +314,20 @@ static gint EditorFIPDoFindAnyBranchIteration(
 		    {
 			EditorFIPAddItem(   
 			    fip,
-			    item_ptr->header_version,
+			    item->header_version,
 			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
 			    branch,		/* Found branch */
-			    item_ptr,		/* Branch data */
+			    item,		/* Branch data */
 			    -1, -1
 			);
 		    }
 		
 		    /* Search through header author */ 
 		    g_free(line[0]);
-		    line[0] = ((item_ptr->header_author == NULL) ? 
-			NULL : strdup(item_ptr->header_author) 
-		    );
+		    line[0] = (item->header_author != NULL) ? 
+			STRDUP(item->header_author) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0, n = 0; i < strc; i++)
@@ -343,21 +346,20 @@ static gint EditorFIPDoFindAnyBranchIteration(
 		    {
 			EditorFIPAddItem(   
 			    fip,
-			    item_ptr->header_author, 
+			    item->header_author, 
 			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
 			    branch,		/* Found branch */
-			    item_ptr,		/* Branch data */
+			    item,		/* Branch data */
 			    -1, -1
 			);
 		    }
 		
 		    /* Search through header catagory */
 		    g_free(line[0]);
-		    line[0] = ((item_ptr->header_catagory == NULL) ?
-			NULL : strdup(item_ptr->header_catagory)
-		    );
+		    line[0] = (item->header_catagory != NULL) ?
+			STRDUP(item->header_catagory) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0, n = 0; i < strc; i++)
@@ -376,12 +378,12 @@ static gint EditorFIPDoFindAnyBranchIteration(
 		    {
 			EditorFIPAddItem(   
 			    fip,
-			    item_ptr->header_catagory,
+			    item->header_catagory,
 			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
 			    branch,		/* Found branch */
-			    item_ptr,		/* Branch data */
+			    item,		/* Branch data */
 			    -1, -1
 			);
 		    }
@@ -395,13 +397,16 @@ static gint EditorFIPDoFindAnyBranchIteration(
 
 		/* Begin searching through header comments */
 
-		/* Make a duplicate of each line */
-		line = strlistcopy(
-		    (const gchar **)item_ptr->line, item_ptr->total_lines
+		/* Copy the lines list */
+		line = (gchar **)g_malloc(
+		    (item->total_lines + 1) * sizeof(gchar *)
 		);
+		for(i = 0; i < item->total_lines; i++)
+		    line[i] = STRDUP(item->line[i]);
+		line[item->total_lines] = NULL;
 		if(!case_sensitive && (line != NULL))
 		{
-		    for(i = 0; i < item_ptr->total_lines; i++)
+		    for(i = 0; i < item->total_lines; i++)
 			strtoupper(line[i]);
 		}
 
@@ -410,10 +415,10 @@ static gint EditorFIPDoFindAnyBranchIteration(
 		 */
 		for(i = 0; i < strc; i++)
 		{
-		    EditorFIPSetStatusProgress(fip, -1.0);
+		    EditorFIPSetStatusProgress(fip, -1.0f);
 
 		    match = EditorFIPDoSearchInArray(
-			(const gchar **)line, item_ptr->total_lines,
+			(const gchar **)line, item->total_lines,
 			strv[i], &new_matches
 		    );
 		    match_count += new_matches;
@@ -424,12 +429,12 @@ static gint EditorFIPDoFindAnyBranchIteration(
 			EditorFIPAddItem(
 			    fip,
 			    (match_ptr->line_num > -1) ?
-				item_ptr->line[match_ptr->line_num] : "",
+				item->line[match_ptr->line_num] : "",
 			    match_ptr->line_num,
 			    "Header",
 			    manual_page_name,
 			    branch,		/* Found branch */
-			    item_ptr,		/* Branch data */
+			    item,		/* Branch data */
 			    match_ptr->start_pos, match_ptr->end_pos
 			);
 		    }
@@ -439,27 +444,28 @@ static gint EditorFIPDoFindAnyBranchIteration(
 		    match = NULL;
 		    new_matches = 0;
 		}
-
-		/* Delete coppied lines */
-		strlistfree(line, item_ptr->total_lines);
-		line = NULL;
+		/* Delete the coppied lines list */
+		g_strfreev(line);
 		break;
 
 	      case EditorItemTypeSection:
 		s = g_strdup_printf(
 		    "Searching: \"%s\"",
-		    item_ptr->section_name
+		    item->section_name
 		);
 		EditorFIPSetStatusMessage(fip, s);
 		g_free(s);
 
-		/* Make a duplicate of each line */
-		line = strlistcopy(
-		    (const gchar **)item_ptr->line, item_ptr->total_lines
+		/* Copy the lines list */
+		line = (gchar **)g_malloc(
+		    (item->total_lines + 1) * sizeof(gchar *)
 		);
+		for(i = 0; i < item->total_lines; i++)
+		    line[i] = STRDUP(item->line[i]);
+		line[item->total_lines] = NULL;
 		if(!case_sensitive && (line != NULL))
 		{
-		    for(i = 0; i < item_ptr->total_lines; i++)
+		    for(i = 0; i < item->total_lines; i++)
 			strtoupper(line[i]);
 		}
 
@@ -468,10 +474,10 @@ static gint EditorFIPDoFindAnyBranchIteration(
 		 */
 		for(i = 0; i < strc; i++)
 		{
-		    EditorFIPSetStatusProgress(fip, -1.0);
+		    EditorFIPSetStatusProgress(fip, -1.0f);
 
 		    match = EditorFIPDoSearchInArray(
-			(const gchar **)line, item_ptr->total_lines,
+			(const gchar **)line, item->total_lines,
 			strv[i], &new_matches
 		    );
 		    match_count += new_matches;
@@ -482,13 +488,13 @@ static gint EditorFIPDoFindAnyBranchIteration(
 			EditorFIPAddItem(
 			    fip,
 			    (match_ptr->line_num > -1) ?
-				item_ptr->line[match_ptr->line_num] : "",
+				item->line[match_ptr->line_num] : "",
 			    match_ptr->line_num,
-			    (item_ptr->section_name != NULL) ?
-				item_ptr->section_name : "(null)",
+			    (item->section_name != NULL) ?
+				item->section_name : "(null)",
 			    manual_page_name,
 			    branch,		/* Found branch */
-			    item_ptr,		/* Branch data */
+			    item,		/* Branch data */
 			    match_ptr->start_pos, match_ptr->end_pos
 			);
 		    }
@@ -498,11 +504,8 @@ static gint EditorFIPDoFindAnyBranchIteration(
 		    match = NULL;
 		    new_matches = 0;
 		}
-
-		/* Delete coppied lines */
-		strlistfree(line, item_ptr->total_lines);
-		line = NULL;
-
+		/* Delete the coppied lines list */
+		g_strfreev(line);
 		break;
 	    }
 	}
@@ -553,37 +556,34 @@ static gint EditorFIPDoFindAllBranchIteration(
 	gint i, new_matches, match_count = 0;
 	gchar **line;
 	GtkCTreeRow *branch_row;
-	editor_item_struct *item_ptr;
+	editor_item_struct *item;
 	fip_match_struct *match;
 
-
 	if(branch == NULL)
 	    return(match_count);
 
 	if(fip->stop_find_count > 0)
 	    return(match_count);
 
-	EditorFIPSetStatusProgress(fip, -1.0);
+	EditorFIPSetStatusProgress(fip, -1.0f);
 
 	/* Get item data from branch */
-	item_ptr = EditorBranchGetData(layout_ctree, branch);
-	if(item_ptr != NULL)
+	item = EditorBranchGetData(layout_ctree, branch);
+	if(item != NULL)
 	{
 	    gchar *s;
 
 	    /* Search through item data by its type */
-	    switch(item_ptr->type)
+	    switch(item->type)
 	    {
 	      case EditorItemTypeFile:
 		s = g_strdup_printf(
 		    "Searching: Manual Page \"%s\"",
-		    item_ptr->file_name
+		    item->name
 		);
 		EditorFIPSetStatusMessage(fip, s);
 		g_free(s);
-
 		/* Nothing to search */
-
 		break;
 
 	      case EditorItemTypeHeader:
@@ -598,8 +598,8 @@ static gint EditorFIPDoFindAllBranchIteration(
 		if(line != NULL)
 		{
 		    /* Search through header name */
-		    line[0] = (item_ptr->header_name != NULL) ?
-			g_strdup(item_ptr->header_name) : NULL;
+		    line[0] = (item->header_name != NULL) ?
+			STRDUP(item->header_name) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0; i < strc; i++)
@@ -618,21 +618,20 @@ static gint EditorFIPDoFindAllBranchIteration(
 		    {
 			EditorFIPAddItem(
 			    fip,
-			    item_ptr->header_name,
+			    item->header_name,
 			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
 			    branch,		/* Found branch */
-			    item_ptr,		/* Branch data */
+			    item,		/* Branch data */
 			    -1, -1
 			);
 		    }
 
 		    /* Search through header section number */
 		    g_free(line[0]);
-		    line[0] = ((item_ptr->header_section_number == NULL) ?
-			NULL : strdup(item_ptr->header_section_number)
-		    );
+		    line[0] = (item->header_section_number != NULL) ?
+			STRDUP(item->header_section_number) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0; i < strc; i++)
@@ -651,21 +650,20 @@ static gint EditorFIPDoFindAllBranchIteration(
 		    {
 			EditorFIPAddItem(
 			    fip,
-			    item_ptr->header_section_number,
+			    item->header_section_number,
 			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
 			    branch,		/* Found branch */
-			    item_ptr,		/* Branch data */
+			    item,		/* Branch data */
 			    -1, -1
 			);
 		    }
 
-		    /* Search through header version */
+		    /* Search through header the version */
 		    g_free(line[0]);
-		    line[0] = ((item_ptr->header_version == NULL) ?
-			NULL : strdup(item_ptr->header_version)
-		    );
+		    line[0] = (item->header_version != NULL) ?
+			STRDUP(item->header_version) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0; i < strc; i++)
@@ -684,21 +682,20 @@ static gint EditorFIPDoFindAllBranchIteration(
 		    {
 			EditorFIPAddItem(
 			    fip,
-			    item_ptr->header_version,
+			    item->header_version,
 			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
 			    branch,		/* Found branch */
-			    item_ptr,		/* Branch data */
+			    item,		/* Branch data */
 			    -1, -1
 			);
 		    }
 
 		    /* Search through header author */
 		    g_free(line[0]);
-		    line[0] = ((item_ptr->header_author == NULL) ?
-			NULL : strdup(item_ptr->header_author)
-		    );
+		    line[0] = (item->header_author != NULL) ?
+			STRDUP(item->header_author) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0; i < strc; i++)
@@ -717,21 +714,20 @@ static gint EditorFIPDoFindAllBranchIteration(
 		    {
 			EditorFIPAddItem(
 			    fip,
-			    item_ptr->header_author,
+			    item->header_author,
 			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
 			    branch,		/* Found branch */
-			    item_ptr,		/* Branch data */
+			    item,		/* Branch data */
 			    -1, -1
 			);
 		    }
 
 		    /* Search through header catagory */
 		    g_free(line[0]);
-		    line[0] = ((item_ptr->header_catagory == NULL) ?
-			NULL : strdup(item_ptr->header_catagory)
-		    );
+		    line[0] = (item->header_catagory != NULL) ?
+			STRDUP(item->header_catagory) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0; i < strc; i++)
@@ -750,12 +746,12 @@ static gint EditorFIPDoFindAllBranchIteration(
 		    {
 			EditorFIPAddItem(
 			    fip,
-			    item_ptr->header_catagory,
+			    item->header_catagory,
 			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
 			    branch,		/* Found branch */
-			    item_ptr,		/* Branch data */
+			    item,		/* Branch data */
 			    -1, -1
 			);
 		    }
@@ -769,13 +765,16 @@ static gint EditorFIPDoFindAllBranchIteration(
 
 		/* Begin searching through header comments */
 
-		/* Make a duplicate of each line */
-		line = strlistcopy(
-		    (const gchar **)item_ptr->line, item_ptr->total_lines
+		/* Copy the lines list */
+		line = (gchar **)g_malloc(
+		    (item->total_lines + 1) * sizeof(gchar *)
 		);
+		for(i = 0; i < item->total_lines; i++)
+		    line[i] = STRDUP(item->line[i]);
+		line[item->total_lines] = NULL;
 		if(!case_sensitive && (line != NULL))
 		{
-		    for(i = 0; i < item_ptr->total_lines; i++)
+		    for(i = 0; i < item->total_lines; i++)
 			strtoupper(line[i]);
 		}
 
@@ -784,10 +783,10 @@ static gint EditorFIPDoFindAllBranchIteration(
 		 */
 		for(i = 0; i < strc; i++)
 		{
-		    EditorFIPSetStatusProgress(fip, -1.0);
+		    EditorFIPSetStatusProgress(fip, -1.0f);
 
 		    match = EditorFIPDoSearchInArray(
-			(const gchar **)line, item_ptr->total_lines,
+			(const gchar **)line, item->total_lines,
 			strv[i], &new_matches
 		    );
 		    /* Break if one of the search strings is not in the
@@ -796,7 +795,6 @@ static gint EditorFIPDoFindAllBranchIteration(
 		    if(match == NULL)
 			break;
 
-		    /* Delete match structures list return */
 		    g_free(match);
 		    match = NULL;
 		    new_matches = 0;
@@ -809,48 +807,48 @@ static gint EditorFIPDoFindAllBranchIteration(
 		    /* Consider this as one match */
 		    EditorFIPAddItem(
 			fip,
-			(item_ptr->total_lines > 0) ?
-			    item_ptr->line[0] : "",
+			(item->total_lines > 0) ?
+			    item->line[0] : "",
 			-1,			/* N/a */
 			"Header",
 			manual_page_name,
 			branch,			/* Found branch */
-			item_ptr,		/* Branch data */
+			item,		/* Branch data */
 			-1, -1
 		   );
 		}
-
-		/* Delete coppied lines */
-		strlistfree(line, item_ptr->total_lines);
-		line = NULL;
-
+		/* Delete the coppied lines list */
+		g_strfreev(line);
 		break;
 
 	      case EditorItemTypeSection:
 		s = g_strdup_printf(
 		    "Searching: \"%s\"",
-		    item_ptr->section_name
+		    item->section_name
 		);
 		EditorFIPSetStatusMessage(fip, s);
 		g_free(s);
 
-		/* Make a duplicate of each line */
-		line = strlistcopy(
-		    (const gchar **)item_ptr->line, item_ptr->total_lines
+		/* Copy the lines list */
+		line = (gchar **)g_malloc(
+		    (item->total_lines + 1) * sizeof(gchar *)
 		);
+		for(i = 0; i < item->total_lines; i++)
+		    line[i] = STRDUP(item->line[i]);
+		line[item->total_lines] = NULL;
 		if(!case_sensitive && (line != NULL))
 		{
-		    for(i = 0; i < item_ptr->total_lines; i++)
+		    for(i = 0; i < item->total_lines; i++)
 			strtoupper(line[i]);
 		}
 
 		/* Search through each coppied line */
 		for(i = 0; i < strc; i++)
 		{
-		    EditorFIPSetStatusProgress(fip, -1.0);
+		    EditorFIPSetStatusProgress(fip, -1.0f);
 
 		    match = EditorFIPDoSearchInArray(
-			(const gchar **)line, item_ptr->total_lines,
+			(const gchar **)line, item->total_lines,
 			strv[i], &new_matches
 		    );
 		    /* Break if one of the search strings is not in the
@@ -872,22 +870,19 @@ static gint EditorFIPDoFindAllBranchIteration(
 		    /* Consider this as one match */
 		    EditorFIPAddItem(
 			fip,
-			(item_ptr->total_lines > 0) ?
-			    item_ptr->line[0] : "",
+			(item->total_lines > 0) ?
+			    item->line[0] : "",
 			-1,			/* N/a */
-			(item_ptr->section_name != NULL) ?
-			    item_ptr->section_name : "(null)",
+			(item->section_name != NULL) ?
+			    item->section_name : "(null)",
 			manual_page_name,
 			branch,			/* Found branch */
-			item_ptr,		/* Branch data */
+			item,		/* Branch data */
 			-1, -1
 		    );
 		}
-
-		/* Delete coppied lines */
-		strlistfree(line, item_ptr->total_lines);
-		line = NULL;
-
+		/* Delete the coppied lines list */
+		g_strfreev(line);
 		break;
 	    }
 	}
@@ -931,39 +926,39 @@ static gint EditorFIPDoFindAny(
 	const gchar *string, gboolean case_sensitive, gboolean explode_string
 )
 {
-	gint match_count = 0;
-	GtkCTreeNode *branch;
-	GtkCTreeRow *branch_row;
+	gint strc, match_count = 0;
 	gchar **strv;
-	gint strc;
-	editor_item_struct *item_ptr;
 	const gchar *manual_page_name;
-
+	GtkCTreeRow *branch_row;
+	editor_item_struct *item;
 
 	/* Get first branch on layout ctree */
-	branch = gtk_ctree_node_nth(layout_ctree, 0);
+	GtkCTreeNode *branch = gtk_ctree_node_nth(layout_ctree, 0);
 	if(branch == NULL)
 	    return(match_count);
 
-	/* Explode search string? */
+	/* Explode the search string? */
 	if(explode_string)
 	{
-	    strv = strexp(string, &strc);
+	    strv = g_strsplit(string, " ", -1);
 	    if(strv == NULL)
 		return(match_count);
+
+	    for(strc = 0; strv[strc] != NULL; strc++);
 	}
 	else
 	{
 	    strc = 1;
-	    strv = (gchar **)g_malloc(strc * sizeof(gchar *));
+	    strv = (gchar **)g_malloc((strc + 1) * sizeof(gchar *));
 	    if(strv == NULL)
 		return(match_count);
-	    else
-		strv[0] = strdup(string);
+
+	    strv[0] = STRDUP(string);
+	    strv[1] = NULL;
 	}
 
 	/* Convert each exploded string to upper case if not case
-	 * sensitive.
+	 * sensitive
 	 */
 	if(!case_sensitive)
 	{
@@ -983,13 +978,13 @@ static gint EditorFIPDoFindAny(
 		break;
 
 	    /* Get item data pointer for branch */
-	    item_ptr = EditorBranchGetData(layout_ctree, branch);
+	    item = EditorBranchGetData(layout_ctree, branch);
 
 	    /* Get manual page name from (assumed) toplevel branch
 	     * item data.
 	     */
 	    manual_page_name = (const gchar *)(
-		(item_ptr == NULL) ? NULL : item_ptr->file_name
+		(item == NULL) ? NULL : item->name
 	    );
 
 	    /* Do find any for this branch and all its child branches */
@@ -1008,8 +1003,8 @@ static gint EditorFIPDoFindAny(
 	    branch = ((branch_row == NULL) ? NULL : branch_row->sibling);
 	}
 
-	/* Delete exploded search string */
-	strlistfree(strv, strc);
+	/* Delete the exploded search string */
+	g_strfreev(strv);
 
 	return(match_count);
 }
@@ -1027,35 +1022,35 @@ static gint EditorFIPDoFindAll(
 	const gchar *string, gboolean case_sensitive, gboolean explode_string
 )
 {
-	gint match_count = 0;
-	GtkCTreeNode *branch;
-	GtkCTreeRow *branch_row;
+	gint strc, match_count = 0;
 	gchar **strv;
-	gint strc;
-	editor_item_struct *item_ptr;
 	const gchar *manual_page_name;
-
+	GtkCTreeRow *branch_row;
+	editor_item_struct *item;
 
 	/* Get first branch on layout ctree */
-	branch = gtk_ctree_node_nth(layout_ctree, 0);
+	GtkCTreeNode *branch = gtk_ctree_node_nth(layout_ctree, 0);
 	if(branch == NULL)
 	    return(match_count);
 
-	/* Explode search string? */
+	/* Explode the search string? */
 	if(explode_string)
 	{
-	    strv = strexp(string, &strc);
+	    strv = g_strsplit(string, " ", -1);
 	    if(strv == NULL)
 		return(match_count);
+
+	    for(strc = 0; strv[strc] != NULL; strc++);
 	}
 	else
 	{
 	    strc = 1;
-	    strv = (gchar **)g_malloc(strc * sizeof(gchar *));
+	    strv = (gchar **)g_malloc((strc + 1) * sizeof(gchar *));
 	    if(strv == NULL)
 		return(match_count);
-	    else
-		strv[0] = strdup(string);
+
+	    strv[0] = STRDUP(string);
+	    strv[1] = NULL;
 	}
 
 	/* Convert each exploded string to upper case if not case
@@ -1079,13 +1074,13 @@ static gint EditorFIPDoFindAll(
 		break;              
 
 	    /* Get item data pointer for branch */
-	    item_ptr = EditorBranchGetData(layout_ctree, branch);
+	    item = EditorBranchGetData(layout_ctree, branch);
 	    
 	    /* Get manual page name from (assumed) toplevel branch
 	     * item data.
 	     */
 	    manual_page_name = (const gchar *)(
-		(item_ptr == NULL) ? NULL : item_ptr->file_name
+		(item == NULL) ? NULL : item->name
 	    );
 
 	    /* Do find all for this branch and all its child branches */
@@ -1104,8 +1099,8 @@ static gint EditorFIPDoFindAll(
 	    branch = ((branch_row == NULL) ? NULL : branch_row->sibling);
 	}
 
-	/* Delete exploded search string */
-	strlistfree(strv, strc);
+	/* Delete the exploded search string */
+	g_strfreev(strv);
 
 	return(match_count);
 }
