@@ -5,18 +5,18 @@
 #ifndef EDITORFIPOP_H
 #define EDITORFIPOP_H
 
-#include <sys/types.h>
 #include <gtk/gtk.h>
-
 #include "editor.h"
 #include "editorfip.h"
 
-extern int EditorFIPDoFind(
+
+extern gint EditorFIPDoFind(
 	editor_fip_struct *fip,
-	editor_struct *editor,	/* The editor to search through. */
-	int throughness,	/* 0 = match all, 1 = match any. */
-	const char *string,
-	gbool case_sensitive
+	editor_struct *editor,
+	gint throughness,		/* 0 = match all, 1 = match any */
+	const gchar *string,
+	gboolean case_sensitive
 );
 
+
 #endif	/* EDITORFIPOP_H */
