@@ -4,10 +4,6 @@
 #include <gtk/gtk.h>
 #include <unistd.h>		/* For unlink() */
 
-#include "../include/string.h"
-#include "../include/strexp.h"
-#include "../include/disk.h"
-
 #include "guiutils.h"
 #include "cdialog.h"
 
@@ -92,23 +88,20 @@ void EditorSyntaxHighlight(
 	GtkStyle *style_ptr;
 	GtkText *text = (GtkText *)w;
 	GtkEditable *editable = (GtkEditable *)w;
-	medit_core_struct *core_ptr;
+	medit_core_struct *core;
 	medit_styles_list_struct *styles_list;
 	if((editor == NULL) || (w == NULL))
 	    return;
 
-	if(!editor->initialized)
-	    return;
-
 	/* No syntax highlighting? */
 	if(!editor->syntax_highlighting)
 	    return;
 
-	core_ptr = (medit_core_struct *)editor->core_ptr;
-	if(core_ptr == NULL)
+	core = editor->core;
+	if(core == NULL)
 	    return;
 
-	styles_list = &core_ptr->styles_list;
+	styles_list = &core->styles_list;
 
 	/* Set text bounds */
 	text_start = 0;		/* Duh */
@@ -530,32 +523,20 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	GtkStyle *style;
 	GtkWidget *w;
 	editor_item_struct *item;
-	medit_core_struct *core_ptr;
+	medit_core_struct *core;
 	medit_styles_list_struct *styles_list;
 
 	if((editor == NULL) || (branch == NULL))
 	    return;
 
-	if(!editor->initialized)
-	    return;
+	core = editor->core;
+	styles_list = &core->styles_list;
 
-	/* Check if already processing */
-	if(editor->processing)
-	    return;
-
-	/* Get core pointer and subsequently the styles list */
-	core_ptr = MEDIT_CORE(editor->core_ptr);
-	styles_list = (core_ptr != NULL) ?
-	    &core_ptr->styles_list : NULL;
-
-
-	/* Get pointer to item data from ctree branch node */
 	item = EditorBranchGetData(
 	    GTK_CTREE(editor->layout_ctree), branch
 	);
 
-
-	/* Map and unmap editor panel widgets */
+	/* Map/unmap the editor's panel widgets */
 	if(item != NULL)
 	    map_editor_panel_type = item->type;
 
@@ -586,8 +567,8 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    w = editor->header_name_entry;
 	    if(w != NULL)
 	    {
-		if((item == NULL) ?
-		    0 : (item->header_name != NULL)
+		if((item != NULL) ?
+		    (item->header_name != NULL) : FALSE
 		)
 		    gtk_entry_set_text(
 			GTK_ENTRY(w), item->header_name
@@ -597,8 +578,8 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    w = editor->header_section_number_entry;
 	    if(w != NULL)
 	    {
-		if((item == NULL) ?    
-		    0 : (item->header_section_number != NULL)
+		if((item != NULL) ?    
+		    (item->header_section_number != NULL) : FALSE
 		)
 		    gtk_entry_set_text(
 			GTK_ENTRY(w), item->header_section_number
@@ -608,8 +589,8 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    w = editor->header_version_entry;
 	    if(w != NULL)
 	    {
-		if((item == NULL) ?
-		    0 : (item->header_version != NULL)
+		if((item != NULL) ?
+		    (item->header_version != NULL) : FALSE
 		)
 		    gtk_entry_set_text(
 			GTK_ENTRY(w), item->header_version
@@ -619,8 +600,8 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    w = editor->header_author_entry;
 	    if(w != NULL)
 	    {
-		if((item == NULL) ?
-		    0 : (item->header_author != NULL)
+		if((item != NULL) ?
+		    (item->header_author != NULL) : FALSE
 		)
 		    gtk_entry_set_text(
 			GTK_ENTRY(w), item->header_author
@@ -630,8 +611,8 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    w = editor->header_catagory_entry;
 	    if(w != NULL)
 	    {
-		if((item == NULL) ?
-		    0 : (item->header_catagory != NULL)
+		if((item != NULL) ?
+		    (item->header_catagory != NULL) : FALSE
 		)
 		    gtk_entry_set_text(
 			GTK_ENTRY(w), item->header_catagory
@@ -656,7 +637,6 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 		{
 		    gchar *line_ptr;
 
-
 		    if(styles_list != NULL)
 			style = styles_list->edit_text_standard;
 		    else
@@ -696,24 +676,23 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    break;
 
 	  case EditorItemTypeSection:
-	    /* Section name entry */
+	    /* Section name */
 	    w = editor->section_name_entry;
 	    if(w != NULL)
 	    {
 		gtk_entry_set_text(
 		    GTK_ENTRY(w),
-		    (item == NULL) ?
-			"" : item->section_name
+		    (item != NULL) ? item->section_name : ""
 		);
 	    }
 
-	    /* Get pointer to section text widget */
+	    /* Section text */
 	    w = editor->section_text;
 	    if(w != NULL)
 	    {
 		gint text_len;
 
-		/* Remove all text */
+		/* Remove all the text */
 		text_len = gtk_text_get_length(GTK_TEXT(w));
 		gtk_text_set_point(GTK_TEXT(w), 0);
 		gtk_text_freeze(GTK_TEXT(w));
@@ -725,7 +704,6 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 		{
 		    gchar *line_ptr;
 
-
 		    if(styles_list != NULL)
 			style = styles_list->edit_text_standard;
 		    else  
@@ -785,24 +763,13 @@ void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 	GtkWidget *w;
 	editor_item_struct *item;
 	medit_pixmaps_list_struct *pixmaps_list;
-	medit_core_struct *core_ptr;
+	medit_core_struct *core;
 
 	if((editor == NULL) || (branch == NULL))
 	    return;
 
-	if(!editor->initialized)
-	    return;
-
-	/* Check if already processing */
-	if(editor->processing)   
-	    return;
-
-	core_ptr = MEDIT_CORE(editor->core_ptr);
-	if(core_ptr == NULL)
-	    return;
-
-	pixmaps_list = &core_ptr->pixmaps_list;
-
+	core = editor->core;
+	pixmaps_list = &core->pixmaps_list;
 
 	/* Get pointer to item data from ctree branch node */
 	item = EditorBranchGetData(
@@ -861,19 +828,26 @@ void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 	    w = editor->header_text;
 	    if((w != NULL) && (item != NULL))
 	    {
-		gchar *s;
+		gchar *s, **strv;
 
-		/* Delete existing lines */
-		strlistfree(item->line, item->total_lines);
+		/* Delete the existing lines list */
+		g_strfreev(item->line);
 		item->line = NULL;
 		item->total_lines = 0;
 
-		/* Get new lines */
+		/* Get the new lines list */
 		s = gtk_editable_get_chars(
 		    GTK_EDITABLE(w), 0, -1
 		);
-		item->line = strchrexp(s, '\n', &item->total_lines);
+		strv = g_strsplit(s, "\n", -1);
 		g_free(s);
+		if(strv != NULL)
+		{
+		    gint i;
+		    item->line = strv;
+		    for(i = 0; strv[i] != NULL; i++);
+		    item->total_lines = i;
+		}
 	    }
 	    break;
 
@@ -903,17 +877,24 @@ void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 	    w = editor->section_text;
 	    if(w != NULL)
 	    {
-		gchar *s;
+		gchar *s, **strv;
 
-		/* Delete existing lines */
-		strlistfree(item->line, item->total_lines);
+		/* Delete the existing lines list */
+		g_strfreev(item->line);
 		item->line = NULL;
 		item->total_lines = 0;
 
-		/* Get new lines */
+		/* Get the new lines list */
 		s = gtk_editable_get_chars(GTK_EDITABLE(w), 0, -1);
-		item->line = strchrexp(s, '\n', &item->total_lines);
+		strv = g_strsplit(s, "\n", -1);
 		g_free(s);
+		if(strv != NULL)
+		{
+		    gint i;
+		    item->line = strv;
+		    for(i = 0; strv[i] != NULL; i++);
+		    item->total_lines = i;
+		}
 	    }
 	    break;
 	}
@@ -933,13 +914,6 @@ void EditorDoClearValues(editor_struct *editor)
 	if(editor == NULL)
 	    return;
 
-	if(!editor->initialized)
-	    return;
-
-	/* Check if already processing */
-	if(editor->processing)
-	    return;
-
 	/* Clear file branch item data widgets */
 
 	/* Header entry widgets */
@@ -1008,55 +982,46 @@ void EditorDoPreview(
 	gint viewer_num
 )
 {
-	gint i, status, editor_num;
-	viewer_struct *v;
-	medit_core_struct *core_ptr;
-	GtkCTreeNode *trunk;
-	editor_item_struct *item;
+	gint i, status, fd, editor_num;
+	gchar *orig_path, *tmp_path, *prog_tmp_path;
 	GtkWidget *toplevel;
 	GtkCTree *ctree;
-	gchar *orig_path, *tmp_path, *prog_tmp_path;
+	GtkCTreeNode *trunk;
+	editor_item_struct *item;
+	viewer_struct *v;
+	medit_core_struct *core;
 
 	if(editor == NULL)
 	    return;
 
-	if(!editor->initialized)
-	    return;
-
-	/* Check if processing */
-	if(editor->processing)   
-	    return;
-
 	toplevel = editor->toplevel;
-	ctree = (GtkCTree *)editor->layout_ctree;
-	core_ptr = (medit_core_struct *)editor->core_ptr;
-	if((ctree == NULL) || (core_ptr == NULL))
-	    return;
+	ctree = GTK_CTREE(editor->layout_ctree);
+	core = editor->core;
 
 	/* Find our editor pointer on core */
-	for(i = 0; i < core_ptr->total_editors; i++)
+	for(i = 0; i < core->total_editors; i++)
 	{
-	    if(core_ptr->editor[i] == editor)
+	    if(core->editor[i] == editor)
 		break;
 	}
-	if(i < core_ptr->total_editors)
+	if(i < core->total_editors)
 	    editor_num = i;
 	else
 	    editor_num = -1;
 
 	/* Check if viewer_num is valid on the core structure */
-	v = ((viewer_num >= 0) && (viewer_num < core_ptr->total_viewers)) ?
-	    core_ptr->viewer[viewer_num] : NULL;
+	v = ((viewer_num >= 0) && (viewer_num < core->total_viewers)) ?
+	    core->viewer[viewer_num] : NULL;
 	if(v == NULL)
 	{
-	    gchar *s = g_strdup_printf(
+	    gchar *msg = g_strdup_printf(
 "EditorDoPreview(): Viewer number %i is invalid.",
 		viewer_num
 	    );
 	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-"Non-critical internal error!",
-		s,
+"Preview Failed",
+		msg,
 "The viewer number given to this function is\n\
 invalid. Cannot continue with preview.",
 		CDIALOG_ICON_ERROR,
@@ -1064,16 +1029,10 @@ invalid. Cannot continue with preview.",
 		CDIALOG_BTNFLAG_OK
 	    );
 	    CDialogSetTransientFor(NULL);
-	    g_free(s);
+	    g_free(msg);
 	    return;
 	}
 
-	/* Got viewer pointer, now check if the viewer is mapped and
-	 * initialized
-	 */
-	if(!v->initialized || !v->map_state)
-	    return;
-
 	/* Set up viewer's values */
 	v->editor_num = editor_num;
 
@@ -1083,7 +1042,7 @@ invalid. Cannot continue with preview.",
 	{
 	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-"Non-critical internal error!",
+"Preview Failed",
 "EditorDoPreview(): Given branch has no trunk.\n",
 "The branch pointer given to this function has\n\
 no trunk branch pointer that could be found.\n\
@@ -1102,7 +1061,7 @@ Cannot continue with preview.",
 	{
 	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-"Non-critical internal error!",
+"Preview Failed",
 "EditorDoPreview(): No item data found for given\n\
 branch's trunk branch.\n",
 "The branch pointer given to this function has\n\
@@ -1121,12 +1080,12 @@ continue with preview.",
 	/* Create tempory files directory for this program as needed
 	 * (return string needs to be deallocated).
 	 */
-	prog_tmp_path = MEditCreateTempDir(core_ptr);
+	prog_tmp_path = MEditCreateTempDir(core);
 	if(prog_tmp_path == NULL)
 	{
 	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-"Non-critical internal error!",
+"Preview Failed",
 "EditorDoPreview(): MEditCreateTempDir() did not return a path.",
 "Could not obtain program tempory file directory path,\n\
 and thus unable to generate tempory files for preview.\n\
@@ -1140,10 +1099,16 @@ Cannot continue with preview.",
 	}
 
 	/* Create a tempory file to save trunk to it */
-	tmp_path = g_strdup(PrefixPaths(
-	    prog_tmp_path, "previewXXXXXX"
-	));
-	mkstemp(tmp_path);
+	tmp_path = g_strconcat(
+	    prog_tmp_path,
+	    G_DIR_SEPARATOR_S,
+	    "preview",
+	    "XXXXXX",
+	    NULL
+	);
+	fd = (gint)mkstemp((char *)tmp_path);
+	if(fd > -1)
+	    close((int)fd);
 
 	/* Here we play a trick, first record the full path name
 	 * on the item data and replace it with our tempory file path
@@ -1170,17 +1135,15 @@ Cannot continue with preview.",
 	    unlink(item->full_path);
 
 
-	/* Free tempory path (this was our tmp_path) */
+	/* Delete the tempory path (this was our tmp_path) */
 	g_free(item->full_path);
 
 	/* Set back original full file name on item */
 	item->full_path = orig_path;
 	orig_path = NULL;
 
-
-	/* Free program tempory files directory path */
+	/* Delete the temporary files directory path */
 	g_free(prog_tmp_path);
-	prog_tmp_path = NULL;
 }
 
 
@@ -1383,7 +1346,7 @@ gboolean EditorDoReplace(
 {
 	GtkEditable *editable;
 	gint delete_len, replacement_len;
-	medit_core_struct *core_ptr;
+	medit_core_struct *core;
 	medit_styles_list_struct *styles_list;
 	GtkStyle *style_ptr;
 
@@ -1395,13 +1358,13 @@ gboolean EditorDoReplace(
 	    return(FALSE);
 
 	/* Get core structure pointer */
-	core_ptr = (medit_core_struct *)editor->core_ptr;
-	if(core_ptr == NULL)
+	core = editor->core;
+	if(core == NULL)
 	    return(FALSE);
 
 
 	/* Get pointer to styles list structure on core structure */
-	styles_list = &core_ptr->styles_list;
+	styles_list = &core->styles_list;
 
 
 	editable = GTK_EDITABLE(text);
@@ -1565,7 +1528,7 @@ gint EditorDoReplaceAll(
 {
 	GtkEditable *editable;
 	gint delete_len, replacement_len;
-	medit_core_struct *core_ptr;
+	medit_core_struct *core;
 	medit_styles_list_struct *styles_list;
 	GtkStyle *style_ptr;
 	gint orig_pos;
@@ -1579,12 +1542,12 @@ gint EditorDoReplaceAll(
 	    return(replace_count);
 
 	/* Get core structure pointer */
-	core_ptr = (medit_core_struct *)editor->core_ptr;
-	if(core_ptr == NULL)
+	core = editor->core;
+	if(core == NULL)
 	    return(replace_count);
 
 	/* Get pointer to styles list structure on core structure */
-	styles_list = &core_ptr->styles_list;
+	styles_list = &core->styles_list;
 
 
 	editable = GTK_EDITABLE(text);
