@@ -22,6 +22,20 @@
 #endif	/* End of GTK 2 wrappers */
 
 
+/*
+ *	Standard Target Names:
+ */
+#define GUI_TARGET_NAME_STRING		"STRING"
+#define GUI_TARGET_NAME_TEXT_PLAIN	"text/plain"
+#define GUI_TARGET_NAME_TEXT_URI_LIST	"text/uri-list"
+
+
+/*
+ *	Tandard Type Names:
+ */
+#define GUI_TYPE_NAME_STRING		"STRING"
+
+
 /*
  *	Button Numbers:
  */
@@ -79,10 +93,10 @@
  *	Geometry Flags:
  */
 typedef enum {
-	GDK_GEOMETRY_X				= (1 << 0),
-	GDK_GEOMETRY_Y				= (1 << 1),
-	GDK_GEOMETRY_WIDTH			= (1 << 2),
-	GDK_GEOMETRY_HEIGHT			= (1 << 3)
+	GDK_GEOMETRY_X			= (1 << 0),
+	GDK_GEOMETRY_Y			= (1 << 1),
+	GDK_GEOMETRY_WIDTH		= (1 << 2),
+	GDK_GEOMETRY_HEIGHT		= (1 << 3)
 } GdkGeometryFlags;
 
 /*
@@ -148,7 +162,7 @@ typedef enum {
  *	Colormap & Color Macros:
  */
 #define GDK_COLOR_SET_BYTE(_c_,_r_,_g_,_b_)		\
-{ if((_c_) != NULL) {                                   \
+{ if((_c_) != NULL) {					\
  (_c_)->red	= ((gushort)(_r_) << 8) |		\
 		  ((gushort)(_r_));			\
  (_c_)->green	= ((gushort)(_g_) << 8) |		\
@@ -261,7 +275,7 @@ typedef enum {
 /*
  *      GtkAdjustment Macros:
  */
-#define GTK_ADJUSTMENT_GET_VALUE(_a_)   (((_a_) != NULL) ? \
+#define GTK_ADJUSTMENT_GET_VALUE(_a_)	(((_a_) != NULL) ? \
  ((GtkAdjustment *)(_a_))->value : 0.0f)
 
 /*
@@ -315,7 +329,7 @@ typedef enum {
 #define GTK_ENTRY_GET_VALUEI(_w_)		\
  (((_w_) != NULL) ? atoi(gtk_entry_get_text(GTK_ENTRY(_w_))) : 0)
 #define GTK_ENTRY_GET_VALUEL(_w_)		\
- (((_w_) != NULL) ? atol(gtk_entry_get_text(GTK_ENTRY(_w_))) : 0.0f)
+ (((_w_) != NULL) ? atol(gtk_entry_get_text(GTK_ENTRY(_w_))) : 0l)
 #define GTK_ENTRY_GET_VALUEF(_w_)		\
  (((_w_) != NULL) ? atof(gtk_entry_get_text(GTK_ENTRY(_w_))) : 0.0f)
 
@@ -345,7 +359,7 @@ extern gint GUICTreeNodeRow(GtkCTree *ctree, GtkCTreeNode *node);
 
 extern gint GUICTreeNodeDeltaRows(
 	GtkCTree *ctree,
-	GtkCTreeNode *start,    /* Use NULL for first/toplevel node */
+	GtkCTreeNode *start,	/* Use NULL for first/toplevel node */
 	GtkCTreeNode *end
 );
 #define gdk_window_get_root_position	GUIGetWindowRootPosition
@@ -419,7 +433,7 @@ extern GdkPixmap *GDK_PIXMAP_NEW_FROM_XPM_FILE(
 	GdkBitmap **mask_rtn, const gchar *filename
 );
 extern GtkWidget *gtk_pixmap_new_from_xpm_d(
-	GdkWindow *window, GdkColor *transparent_color,            
+	GdkWindow *window, GdkColor *transparent_color,
 	guint8 **data
 );
 extern GtkWidget *GUICreateMenuItemIcon(guint8 **icon_data);
@@ -440,9 +454,11 @@ extern void GUISetGlobalTipsState(gboolean state);
 
 /* Buttons Modifying */
 extern void GUIButtonChangeLayout(
-	GtkWidget *w, gboolean show_pixmap, gboolean show_label
+	GtkWidget *w,
+	const gboolean show_pixmap,
+	const gboolean show_label
 );
-extern void GUIButtonLabelUnderline(GtkWidget *w, guint c);
+extern void GUIButtonLabelUnderline(GtkWidget *w, const guint c);
 extern void GUIButtonPixmapUpdate(
 	GtkWidget *w, guint8 **icon, const gchar *label
 );
@@ -502,54 +518,99 @@ extern GtkWidget *GUIPromptBar(
 
 
 /* Dynamic Data Exchange */
+extern void GUIDDESetDirect(
+	GtkWidget *w,
+	GdkAtom selection_atom,
+	const gulong t,
+	GdkAtom target_atom,
+	guint8 *data, const gint length
+);
+extern void GUIDDESet(
+	GtkWidget *w,
+	GdkAtom selection_atom,
+	const gulong t,
+	GdkAtom target_atom,
+	const guint8 *data, const gint length
+);
+extern guint8 *GUIDDEGet(
+	GtkWidget *w,
+	GdkAtom selection_atom,
+	const gulong t,
+	GdkAtom target_atom,
+	gint *length
+);
+extern void GUIDDEClear(GtkWidget *w);
 extern void GUIDDESetBinary(
-	GtkWidget *w,			/* Owner widget */
-	GdkAtom selection_atom,		/* Selection */
-	gulong t,			/* Time */
-	const guint8 *data, gint length
+	GtkWidget *w,
+	GdkAtom selection_atom,
+	const gulong t,
+	const guint8 *data, const gint length
 );
 extern guint8 *GUIDDEGetBinary(
-	GtkWidget *w,			/* Widget making request */
-	GdkAtom selection_atom,		/* Can be GDK_NONE */
-	gulong t,			/* Time */
+	GtkWidget *w,
+	GdkAtom selection_atom,
+	const gulong t,
 	gint *length
 );
 extern void GUIDDESetString(
-	GtkWidget *w,			/* Owner widget */
-	GdkAtom selection_atom,		/* Selection */
-	gulong t,			/* Time */
+	GtkWidget *w,
+	GdkAtom selection_atom,
+	const gulong t,
 	const gchar *data
 );
 extern gchar *GUIDDEGetString(
-	GtkWidget *w,			/* Widget making request */
-	GdkAtom selection_atom,		/* Can be GDK_NONE */
-	gulong t			/* Time */
+	GtkWidget *w,
+	GdkAtom selection_atom,
+	const gulong t
 );
 
 
 /* Drag & Drop Utilities */
 extern void GUIDNDSetSrc(
-	void *w, const void *drag_type, int ndrag_types,
-	unsigned int actions, unsigned int buttons,
-	void (*begin_cb)(GtkWidget *, GdkDragContext *, gpointer),
-	void (*request_data_cb)(GtkWidget *, GdkDragContext *,
-		GtkSelectionData *, guint, guint, gpointer),
-	void (*delete_data_cb)(GtkWidget *, GdkDragContext *, gpointer),
-	void (*end_cb)(GtkWidget *, GdkDragContext *, gpointer),
-	gpointer client_data
+	GtkWidget *w,
+	const GtkTargetEntry *target_entry,
+	const gint ntarget_entries,
+	const GdkDragAction actions,
+	const GdkModifierType buttons,
+	void (*drag_begin_cb)(
+		GtkWidget *, GdkDragContext *,
+		gpointer
+	),
+	void (*drag_data_get_cb)(
+		GtkWidget *, GdkDragContext *,
+		GtkSelectionData *,
+		guint, guint,
+		gpointer
+	),
+	void (*drag_data_delete_cb)(
+		GtkWidget *, GdkDragContext *,
+		gpointer
+	),
+	void (*drag_end_cb)(
+		GtkWidget *, GdkDragContext *,
+		gpointer
+	),
+	gpointer data
 );
 extern void GUIDNDSetTar(
-	void *w, const void *drag_type, int ndrag_types,
-	unsigned int actions, unsigned int default_action_same,
-	unsigned int default_action,
-	void (*recieved_data_cb)(GtkWidget *, GdkDragContext *,
-		gint, gint, GtkSelectionData *, guint, guint,
-		gpointer  
+	GtkWidget *w,
+	const GtkTargetEntry *target_entry,
+	const gint ntarget_entries,
+	const GdkDragAction actions,
+	const GdkDragAction default_action_same,
+	const GdkDragAction default_action,
+	void (*drag_data_recieved_cb)(
+		GtkWidget *, GdkDragContext *,
+		gint, gint,
+		GtkSelectionData *,
+		guint, guint,
+		gpointer
 	),
-	gpointer client_data
+	gpointer drag_data_received_data
 );
 extern void GUIDNDSetDragIcon(
-	GdkPixmap *pixmap, GdkBitmap *mask, gint hot_x, gint hot_y
+	GdkPixmap *pixmap, GdkBitmap *mask,
+	const gint hot_x, const gint hot_y
 );
 
 
@@ -612,6 +673,10 @@ extern GtkWidget *GUIMenuAddToMenuBar(
 );
 extern void GUIMenuItemSetLabel(GtkWidget *menu_item, const gchar *label);
 extern void GUIMenuItemSetPixmap(GtkWidget *menu_item, guint8 **icon_data);
+extern void GUIMenuItemSetPixmap2(
+        GtkWidget *menu_item,
+        GdkPixmap *pixmap, GdkBitmap *mask
+);
 extern void GUIMenuItemSetAccelKey(
 	GtkWidget *menu_item, GtkAccelGroup *accelgrp,
 	guint accel_key, guint accel_mods
@@ -633,8 +698,8 @@ extern void GUIMenuItemSetSubMenu(
 /* Pull Out Window */
 extern void *GUIPullOutCreateH(
 	void *parent_box,
-	int homogeneous, int spacing,           /* Of client vbox */
-	int expand, int fill, int padding,      /* Of holder hbox */
+	int homogeneous, int spacing,		/* Of client vbox */
+	int expand, int fill, int padding,	/* Of holder hbox */
 	int toplevel_width, int toplevel_height,
 	void *pull_out_client_data,
 	void (*pull_out_cb)(void *, void *),
