@@ -9,7 +9,6 @@
 #include "guiutils.h"
 #include "cdialog.h"
 #include "fprompt.h"
-#include "clipboard.h"
 #include "csd.h"
 #include "fsd.h"
 #include "fb.h"
@@ -39,17 +38,19 @@ static void MEditSignalCB(int s);
 
 static gboolean load_font_to_style(GtkStyle *style_ptr, const gchar *font_name);
 
-gint MEditInit(medit_core_struct *core_ptr, int argc, char **argv);
-gint MEditManage(gpointer data);
-void MEditShutdown(medit_core_struct *core_ptr);
+medit_core_struct *MEditNew(
+	gint argc, gchar **argv,
+	gint *status_rtn
+);
+static gint MEditTOCB(gpointer data);
+void MEditDelete(medit_core_struct *core);
 
 
-static int segfault_count = 0;
-static guint manage_timeout_cb_id = (guint)(-1);
+static int		segfault_count = 0;
 
-gboolean need_close_all_windows = FALSE;
-medit_core_struct *context_core_ptr = NULL;
-gboolean use_text_delete;
+gboolean		need_close_all_windows = FALSE;
+medit_core_struct	*medit_core_ptr = NULL;
+gboolean		use_text_delete;
 
 
 #define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
@@ -75,7 +76,6 @@ void MEditSignalCB(int s)
 	{
 	  case SIGINT: 
 	  case SIGTERM:
-	  case SIGKILL:
 	    need_close_all_windows = TRUE;
 	    break;
 
@@ -97,7 +97,7 @@ void MEditSignalCB(int s)
 	    {
 		/* Mark and perform emergency save procedure */
 		doing_crash_save = TRUE;
-		MEditDoEmergencySave(context_core_ptr);
+		MEditDoEmergencySave(medit_core_ptr);
 	    }
 	    /* Got 3 or more segfaults? */
 	    if(segfault_count >= 3)
@@ -122,7 +122,7 @@ void MEditSignalCB(int s)
 
 
 /*
- *	Macro used in MEditInit() to load fonts to styles.
+ *	Macro used in MEditNew() to load fonts to styles.
  *
  *	Returns TRUE if the font was not able to be loaded, otherwise
  *	FALSE on success.
@@ -149,46 +149,52 @@ static gboolean load_font_to_style(GtkStyle *style_ptr, const gchar *font_name)
 /*
  *	Initializes all resources for the core structure.
  */
-gint MEditInit(medit_core_struct *core_ptr, gint argc, gchar **argv)
+medit_core_struct *MEditNew(
+	gint argc, gchar **argv, 
+	gint *status_rtn
+)
 {
-	gint i, status;
-	const gchar *s, *arg;
 	gboolean startup_viewer = FALSE;
-	gint editor_num = -1;
-	gint viewer_num = -1;
-	editor_struct *editor = NULL;
-	viewer_struct *viewer = NULL;
-	const gchar *filename = NULL;
-	gchar *rcfile;
-	GtkStyle *style_standard;
+	gint	i,
+		editor_num = -1,
+		viewer_num = -1;
+	gchar *cfg_file;
+	const gchar	*s, *arg,
+			*filename = NULL;
 	GdkColormap *colormap;
 	GdkWindow *window = (GdkWindow *)GDK_ROOT_PARENT();
+	GtkStyle *style_standard;
+	editor_struct *editor = NULL;
+	viewer_struct *viewer = NULL;
 	medit_cursors_list_struct *cursors_list;
 	medit_styles_list_struct *styles_list;
 	medit_pixmaps_list_struct *pixmaps_list;
-	medit_fetype_list_struct *fetype_list;
+	medit_core_struct *core = MEDIT_CORE(g_malloc0(
+	    sizeof(medit_core_struct)
+	));
+	if(core == NULL)
+	{
+	    *status_rtn = 3;
+	    return(NULL);
+	}
 
-
-	if(core_ptr == NULL)
-	    return(-1);
-
-	/* Set path to default rcfile, coppied value */
+	/* Set path to default cfg_file, coppied value */
 	s = g_getenv("HOME");
 	if(s == NULL)
 	    s = "/";
 	s = PrefixPaths(s, MEDIT_RCFILE_LOCAL);
 	if(s == NULL)
 	    s = MEDIT_RCFILE_LOCAL;
-	rcfile = STRDUP(s);
+	cfg_file = STRDUP(s);
 
 
-	/* Reset values on core */
-	core_ptr->untitled_count = 0;
-
-	core_ptr->alt_key_state = FALSE;
-	core_ptr->control_key_state = FALSE;
-	core_ptr->shift_key_state = FALSE;
+	/* Reset the values */
+	core->untitled_count = 0;
 
+	core->string_atom = gdk_atom_intern(
+	    "STRING",
+	    FALSE
+	);
 
 	/* Parse arguments */
 	for(i = 1; i < argc; i++)
@@ -220,8 +226,8 @@ gint MEditInit(medit_core_struct *core_ptr, gint argc, gchar **argv)
 		arg = (i < argc) ? argv[i] : NULL;
 		if(arg != NULL)
 		{
-		    g_free(rcfile);
-		    rcfile = STRDUP(arg);
+		    g_free(cfg_file);
+		    cfg_file = STRDUP(arg);
 		}
 		else
 		{
@@ -232,21 +238,19 @@ gint MEditInit(medit_core_struct *core_ptr, gint argc, gchar **argv)
 		}
 	    }
 	    /* Filename to load on startup? */
-	    else if((*arg != '-') &&
-		    (*arg != '+')
-	    )
+	    else if((*arg != '-') && (*arg != '+'))
 	    {
 		filename = arg;
 	    }
 	}
 
 
-	/* Get default gtk style */
+	/* Get the default GTK style */
 	style_standard = gtk_widget_get_default_style();
 
 
-	/* Load cursors */
-	cursors_list = &core_ptr->cursors_list;
+	/* Load the cursors */
+	cursors_list = &core->cursors_list;
 	if(TRUE)
 	{
 	    cursors_list->busy = gdk_cursor_new(GDK_WATCH);
@@ -254,8 +258,8 @@ gint MEditInit(medit_core_struct *core_ptr, gint argc, gchar **argv)
 	}
 
 
-	/* Load styles */
-	styles_list = &core_ptr->styles_list;
+	/* Load the styles */
+	styles_list = &core->styles_list;
 	colormap = gdk_colormap_get_system();
 	if((window != NULL) && (style_standard != NULL) &&
 	   (colormap != NULL)
@@ -489,187 +493,135 @@ gint MEditInit(medit_core_struct *core_ptr, gint argc, gchar **argv)
 	}
 
 
-	/* Load pixmaps list */
-	pixmaps_list = &core_ptr->pixmaps_list;
+	/* Load the pixmaps list */
+	pixmaps_list = &core->pixmaps_list;
 	if((window != NULL) && (style_standard != NULL))
 	{
 	    GdkPixmap **pixmap;
 	    GdkBitmap **mask;
-	    u_int8_t **data;
+	    guint8 **data;
 
-#define DO_LOAD_PIXMAP	\
-{ \
- (*pixmap) = gdk_pixmap_create_from_xpm_d( \
-  window, mask, \
-  &style_standard->bg[GTK_STATE_NORMAL], \
-  (gchar **)data \
- ); \
+#define DO_LOAD_PIXMAP {				\
+ (*pixmap) = gdk_pixmap_create_from_xpm_d(		\
+  window, mask,						\
+  &style_standard->bg[GTK_STATE_NORMAL],		\
+  (gchar **)data					\
+ );							\
 }
 	    pixmap = &pixmaps_list->folder_closed_20x20;
 	    mask = &pixmaps_list->folder_closed_20x20_mask;
-	    data = (u_int8_t **)icon_folder_closed_20x20_xpm;
+	    data = (guint8 **)icon_folder_closed_20x20_xpm;
 	    DO_LOAD_PIXMAP
 
 	    pixmap = &pixmaps_list->folder_opened_20x20;
 	    mask = &pixmaps_list->folder_opened_20x20_mask;
-	    data = (u_int8_t **)icon_folder_opened_20x20_xpm;
+	    data = (guint8 **)icon_folder_opened_20x20_xpm;
 	    DO_LOAD_PIXMAP
 
 
 	    pixmap = &pixmaps_list->manual_closed_20x20;
 	    mask = &pixmaps_list->manual_closed_20x20_mask;
-	    data = (u_int8_t **)icon_manual_closed_20x20_xpm;
+	    data = (guint8 **)icon_manual_closed_20x20_xpm;
 	    DO_LOAD_PIXMAP
 
 	    pixmap = &pixmaps_list->manual_opened_20x20;
 	    mask = &pixmaps_list->manual_opened_20x20_mask;
-	    data = (u_int8_t **)icon_manual_opened_20x20_xpm;
+	    data = (guint8 **)icon_manual_opened_20x20_xpm;
 	    DO_LOAD_PIXMAP
 
 
 	    pixmap = &pixmaps_list->manpage_heading_20x20;
 	    mask = &pixmaps_list->manpage_heading_20x20_mask;
-	    data = (u_int8_t **)icon_manpage_heading_20x20_xpm;
+	    data = (guint8 **)icon_manpage_heading_20x20_xpm;
 	    DO_LOAD_PIXMAP
 
 	    pixmap = &pixmaps_list->manpage_section_20x20;
 	    mask = &pixmaps_list->manpage_section_20x20_mask;
-	    data = (u_int8_t **)icon_manpage_section_20x20_xpm;
+	    data = (guint8 **)icon_manpage_section_20x20_xpm;
 	    DO_LOAD_PIXMAP
 
 #undef DO_LOAD_PIXMAP
 	}
 
 
-	/* Load file extension types list */
-	fetype_list = &core_ptr->fetype_list;
-	if(TRUE)
-	{
-	    fb_type_struct ***list = &fetype_list->manual_page;
-	    gint *total = &fetype_list->total_manual_pages;
-
-	    *list = NULL;
-	    *total = 0;
-
-	    FileBrowserTypeListNew(
-		list, total,
-		".1 .2 .3 .4 .5 .6 .bz2 .gz",
-		"Manual page"
-	    );
-	    FileBrowserTypeListNew(
-		list, total,
-		".mpt",
-		"Manual page template"
-	    );
-	    FileBrowserTypeListNew(
-		list, total,
-		"*.*",
-		"All files"
-	    );
-	}
-
-
 	/* Create Preferences & Options window */
-	core_ptr->pref = PrefNew(core_ptr);
+	core->pref = PrefNew(core);
 
-	/* Load preferences from file */
-	if(rcfile != NULL)
+	/* Open the configuration */
+	if(cfg_file != NULL)
 	{
-	    status = PrefLoadFromFile(core_ptr->pref, rcfile);
-
-	    /* Load preferences successfully? */
-	    if(!status)
+	    if(PrefLoadFromFile(core->pref, cfg_file) == 0)
 	    {
 		/* Apply preferences to realize newly loaded values
-		 * onto core structure and other resources.
+		 * onto core structure and other resources
 		 */
-		PrefDoApply(core_ptr->pref);
+		PrefDoApply(core->pref);
 	    }
 	}
 
-	/* Check preferences for what kind of window to start up with,
-	 * if we are not starting up with anything then set startup_viewer
-	 * to TRUE because we must start up with *something*.
-	 */
-	if(!PrefParmGetValueB(core_ptr->pref, MEDIT_PREF_PARM_STARTUP_EDITOR) &&
-	   !PrefParmGetValueB(core_ptr->pref, MEDIT_PREF_PARM_STARTUP_VIEWER)
-	)
-	{
-	    g_printerr(
-"%s: Warning: No window defined to start up with, default to viewer.\n",
-		PROG_NAME
-	    );
-	    startup_viewer = TRUE;
-	}
-
-	/* Create a new editor on startup? */
+	/* Startup with an editor? */
 	if(!startup_viewer &&
-	   PrefParmGetValueB(core_ptr->pref, MEDIT_PREF_PARM_STARTUP_EDITOR)
+	   PrefParmGetValueB(core->pref, MEDIT_PREF_PARM_STARTUP_EDITOR)
 	)
-	    editor = EditorNew(core_ptr);
+	    editor = EditorNew(core);
 	else
 	    editor = NULL;
 	if(editor != NULL)
 	{
-	    if(core_ptr->total_editors < 0)
-		core_ptr->total_editors = 0;
+	    if(core->total_editors < 0)
+		core->total_editors = 0;
 
-	    editor_num = core_ptr->total_editors;
-	    core_ptr->total_editors++;
-	    core_ptr->editor = (editor_struct **)g_realloc(
-		core_ptr->editor,
-		core_ptr->total_editors * sizeof(editor_struct *)
+	    editor_num = core->total_editors;
+	    core->total_editors++;
+	    core->editor = (editor_struct **)g_realloc(
+		core->editor,
+		core->total_editors * sizeof(editor_struct *)
 	    );
-	    if(core_ptr->editor == NULL)
+	    if(core->editor == NULL)
 	    {
-		core_ptr->total_editors = 0;
-
+		core->total_editors = 0;
 		EditorDelete(editor);
 		editor = NULL;
 	    }
 	    else
 	    {
-		core_ptr->editor[editor_num] = editor;
+		core->editor[editor_num] = editor;
 		EditorMap(editor);
-
 		if(filename != NULL)
-		{
-		    EditorFileLoad(editor, filename, NULL, FALSE);
-		}
+		    EditorFileOpen(editor, filename, NULL, FALSE);
 	    }
 	}
 
-	/* Create a new viewer on startup? */
+	/* Startup with a viewer? */
 	if((startup_viewer) ||
-	   PrefParmGetValueB(core_ptr->pref, MEDIT_PREF_PARM_STARTUP_VIEWER)
+	   PrefParmGetValueB(core->pref, MEDIT_PREF_PARM_STARTUP_VIEWER)
 	)
 	    viewer = ViewerNew(
-		core_ptr,
-		(core_ptr->total_editors > 0) ? 0 : -1
+		core,
+		(core->total_editors > 0) ? 0 : -1
 	    );
 	else
 	    viewer = NULL;
 	if(viewer != NULL)
 	{
-	    if(core_ptr->total_viewers < 0)
-		core_ptr->total_viewers = 0;
+	    if(core->total_viewers < 0)
+		core->total_viewers = 0;
 	      
-	    viewer_num = core_ptr->total_viewers;
-	    core_ptr->total_viewers++;
-	    core_ptr->viewer = (viewer_struct **)g_realloc(
-		core_ptr->viewer,
-		core_ptr->total_viewers * sizeof(viewer_struct *)
+	    viewer_num = core->total_viewers;
+	    core->total_viewers++;
+	    core->viewer = (viewer_struct **)g_realloc(
+		core->viewer,
+		core->total_viewers * sizeof(viewer_struct *)
 	    );
-	    if(core_ptr->viewer == NULL)
+	    if(core->viewer == NULL)
 	    {
-		core_ptr->total_viewers = 0;
-
+		core->total_viewers = 0;
 		ViewerDelete(viewer);
 		viewer = NULL;
 	    }
 	    else
 	    {
-		core_ptr->viewer[viewer_num] = viewer;
+		core->viewer[viewer_num] = viewer;
 		ViewerMap(viewer);
 
 		if(filename != NULL)
@@ -683,44 +635,72 @@ gint MEditInit(medit_core_struct *core_ptr, gint argc, gchar **argv)
 	    }
 	}
 
+	/* If no windows were created then create a new editor */
+	if((editor == NULL) && (viewer == NULL))
+	{
+	    editor = EditorNew(core);
+	    if(editor != NULL)
+	    {
+		editor_num = MAX(core->total_editors, 0);
+		core->total_editors = editor_num + 1;
+		core->editor = (editor_struct **)g_realloc(
+		    core->editor,
+		    core->total_editors * sizeof(editor_struct *)
+		);
+		if(core->editor == NULL)
+		{
+		    core->total_editors = 0;
+		    EditorDelete(editor);
+		    editor = NULL;
+		}
+		else
+		{
+		    core->editor[editor_num] = editor;
+		    EditorMap(editor);
+		    if(filename != NULL)
+			EditorFileOpen(editor, filename, NULL, FALSE);
+		}
+	    }
+	}
+
 
 	/* Call crash check recovery function to prompt and recover any
 	 * files saved by an emergency save in a previous run of this
 	 * program.
 	 */
-	MEditDoCrashRecovery(core_ptr);
+	MEditDoCrashRecovery(core);
 
 
-	/* Delete coppied rcfile path */
-	g_free(rcfile);
-	rcfile = NULL;
+	/* Set the timeout callback */
+	core->toid = gtk_timeout_add(
+	    250l,
+	    MEditTOCB, core
+	);
 
-	return(0);
+
+	g_free(cfg_file);
+
+	*status_rtn = 0;
+
+	return(core);
 }
 
 /*
- *	Manage (timeout) function.
+ *	Main timeout callback.
  */
-gint MEditManage(gpointer data)
+static gint MEditTOCB(gpointer data)
 {
-	static gboolean reenterant = FALSE;
 	gboolean need_break, still_processing;
 	gint i, status;
-	editor_struct *editor;
-	viewer_struct *viewer;
 	GtkCTreeNode *branch;
 	GtkCTreeRow *branch_row;
+	editor_struct *editor;
+	viewer_struct *viewer;
 	editor_item_struct *item;
-	medit_core_struct *core_ptr = (medit_core_struct *)data;
-	if(core_ptr == NULL)
+	medit_core_struct *core = MEDIT_CORE(data);
+	if(core == NULL)
 	    return(FALSE);
 
-	if(reenterant)
-	    return(TRUE);
-	else
-	    reenterant = TRUE;
-
-
 	/* Need to close all windows? */
 	if(need_close_all_windows) 
 	{
@@ -731,31 +711,26 @@ gint MEditManage(gpointer data)
 	    if(CDialogIsQuery())
 	    {
 		CDialogBreakQuery();
-		reenterant = FALSE;
 		return(TRUE);
 	    }
 	    if(FileBrowserIsQuery())
 	    {
 		FileBrowserBreakQuery();
-		reenterant = FALSE; 
 		return(TRUE);
 	    }
 	    if(CSDIsQuery())
 	    {
 		CSDBreakQuery();
-		reenterant = FALSE; 
 		return(TRUE);
 	    }
 	    if(FSDIsQuery())
 	    {
 		FSDBreakQuery();
-		reenterant = FALSE;
 		return(TRUE);
 	    }
 	    if(PDialogIsQuery())
 	    {
 		PDialogBreakQuery();
-		reenterant = FALSE;
 		return(TRUE);
 	    }
 	    /* All dialogs not in query */
@@ -770,26 +745,26 @@ gint MEditManage(gpointer data)
 	    still_processing = FALSE;
 
 	    /* Check each editor to see if any are still processing */
-	    for(i = 0; i < core_ptr->total_editors; i++)
+	    for(i = 0; i < core->total_editors; i++)
 	    {
-		editor = core_ptr->editor[i];
+		editor = core->editor[i];
 		if(editor == NULL)
 		    continue;
 		
-		if(editor->initialized && editor->processing)
+		if(editor->freeze_count > 0)
 		{
 		    still_processing = TRUE;
 		    break;
 		}
 	    }
 	    /* Check each viewer to see if any are still processing */
-	    for(i = 0; i < core_ptr->total_viewers; i++)
+	    for(i = 0; i < core->total_viewers; i++)
 	    {
-		viewer = core_ptr->viewer[i];
+		viewer = core->viewer[i];
 		if(viewer == NULL)
 		    continue;
 
-		if(viewer->initialized && viewer->processing)
+		if(viewer->processing)
 		{
 		    still_processing = TRUE;
 		    break;
@@ -801,26 +776,25 @@ gint MEditManage(gpointer data)
 		/* Return now, next call to timeout won't request to
 		 * close all windows.
 		 */
-		reenterant = FALSE;
 		return(TRUE);
 	    }
 
 
 	    /* Go through each editor and check for changes */
-	    for(i = 0; i < core_ptr->total_editors; i++)
+	    for(i = 0; i < core->total_editors; i++)
 	    {
-		editor = core_ptr->editor[i];
+		editor = core->editor[i];
 		if(editor == NULL)
 		    continue;
 
-		if(editor->initialized)
+		if(TRUE)
 		{
 		    need_break = FALSE;
 		    branch = EditorItemGetFirstToplevel(editor);
 		    while(branch != NULL)
 		    {
 			item = EditorBranchGetData(
-			    (GtkCTree *)editor->layout_ctree,
+			    GTK_CTREE(editor->layout_ctree),
 			    branch
 			);
 			if(item->has_changes)
@@ -830,31 +804,25 @@ gint MEditManage(gpointer data)
 			}
 
 			branch_row = GTK_CTREE_ROW(branch);
-			branch = ((branch_row == NULL) ?
-			    NULL : branch_row->sibling
-			);
+			branch = (branch_row != NULL) ?
+			    branch_row->sibling : NULL;
 		    }
 
 		    if(need_break)
 			break;
 		}
 	    }
-	    if(i < core_ptr->total_editors)
+	    if(i < core->total_editors)
 	    {
 		/* Found some changed data that was not saved */
 		CDialogSetTransientFor(NULL);
 		status = CDialogGetResponse(
-"Changes detected!",
-"There are changes to one or more of the editors\n\
-that have not been saved. Are you sure you want to\n\
-exit and discard those changes?",
-"The program is about to exit and some changed data have\n\
-not been saved. If you say no then the program will not\n\
-exit and you will have a chance to save those changes, or\n\
-you can say yes to exit and discard those changes.",
+"Save Changes",
+"There are unsaved changes on one or more of the editors,\n\
+are you sure you want to exit and discard those changes?",
+		    NULL,
 		    CDIALOG_ICON_WARNING,
-		    CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_NO |
-		    CDIALOG_BTNFLAG_HELP,
+		    CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_NO,
 		    CDIALOG_BTNFLAG_NO
 		);
 		CDialogSetTransientFor(NULL);
@@ -884,30 +852,24 @@ you can say yes to exit and discard those changes.",
 		/* Go through each editor and close all editors
 		 * that are initialized by resetting and unmapping them.
 		 */
-		for(i = 0; i < core_ptr->total_editors; i++)
+		for(i = 0; i < core->total_editors; i++)
 		{
-		    editor = core_ptr->editor[i];
+		    editor = core->editor[i];
 		    if(editor == NULL)
 			continue;
 
-		    if(!editor->initialized)
-			continue;
-
 		    EditorRecordPositions(editor);
-		    EditorReset(editor, editor->map_state);
+		    EditorReset(editor, TRUE);
 		}
 		/* Viewer windows */
-		for(i = 0; i < core_ptr->total_viewers; i++)
+		for(i = 0; i < core->total_viewers; i++)
 		{
-		    viewer = core_ptr->viewer[i];
+		    viewer = core->viewer[i];
 		    if(viewer == NULL)
 			continue;
 	    
-		    if(!viewer->initialized)
-			continue;
-
 		    ViewerRecordPositions(viewer);
-		    ViewerReset(viewer, viewer->map_state);
+		    ViewerReset(viewer, TRUE);
 		}
 		/* Add support for resetting and unmapping other types of
 		 * windows here.
@@ -922,18 +884,18 @@ you can say yes to exit and discard those changes.",
 	 * keeps running while one or more Manual Page Editor editor is
 	 * in use, otherwise this program will start shutting down.
 	 */
-	for(i = 0; i < core_ptr->total_editors; i++)
+	for(i = 0; i < core->total_editors; i++)
 	{
-	    editor = core_ptr->editor[i];
+	    editor = core->editor[i];
 	    if(editor == NULL)
 		continue;
 
-	    /* Is this editor initialized and mapped? */
-	    if(editor->initialized && editor->map_state)
+	    /* Is this editor mapped? */
+	    if(GTK_WIDGET_MAPPED(editor->toplevel))
 		break;
 	}
 	/* Atleast one editor was initialized and mapped? */
-	if(i < core_ptr->total_editors)
+	if(i < core->total_editors)
 	{
 	    /* Atleast one editor is still in use, keep running */
 	}
@@ -942,18 +904,18 @@ you can say yes to exit and discard those changes.",
 	    /* All editors were uninitialized and/or unmapped */
 
 	    /* Check if any viewers are initialized and mapped */
-	    for(i = 0; i < core_ptr->total_viewers; i++)
+	    for(i = 0; i < core->total_viewers; i++)
 	    {
-		viewer = core_ptr->viewer[i];
+		viewer = core->viewer[i];
 		if(viewer == NULL)
 		    continue;
 
 		/* Is this viewer initialized and mapped? */
-		if(viewer->initialized && viewer->map_state)
+		if(GTK_WIDGET_MAPPED(viewer->toplevel))
 		    break;
 	    }
 	    /* Atleast one viewer was initialized and mapped? */
-	    if(i < core_ptr->total_viewers)
+	    if(i < core->total_viewers)
 	    {
 		/* Atleast one viewer is still in use, keep running */
 	    }
@@ -961,27 +923,15 @@ you can say yes to exit and discard those changes.",
 	    {
 		/* All viewers were uninitialized and/or unmapped */
 
-		/* Break out of main GUI loop */
+		/* Pop the main GTK loop */
 		gtk_main_quit();
 
-		/* Remove callback to this function */
-		if(manage_timeout_cb_id != (guint)(-1))
-		{
-		    gtk_timeout_remove(manage_timeout_cb_id);
-		    manage_timeout_cb_id = (guint)(-1);
-		}
-
-		/* Flush events */
-		while(gtk_events_pending() > 0)
-		    gtk_main_iteration();
-
-		/* Return false so this timeout is not called again */
-		reenterant = FALSE;
+		/* Do not call this timeout again */
+		core->toid = 0;
 		return(FALSE);
 	    }
 	}
 
-	reenterant = FALSE;
 	return(TRUE);
 }
 
@@ -989,190 +939,117 @@ you can say yes to exit and discard those changes.",
  *	Deletes all resources on the core structure but does not
  *	delete the structure itself.
  */
-void MEditShutdown(medit_core_struct *core_ptr)
+void MEditDelete(medit_core_struct *core)
 {
 	gint i;
-	gchar *rcfile;
+	gchar *cfg_file;
 	medit_cursors_list_struct *cursors_list;
 	medit_pixmaps_list_struct *pixmaps_list;
 	medit_styles_list_struct *styles_list;
-	medit_fetype_list_struct *fetype_list;
 
-	if(core_ptr == NULL)
+	if(core == NULL)
 	    return;
 
-	/* Delete all editors */
-	for(i = 0; i < core_ptr->total_editors; i++)
-	{
-	    EditorDelete(core_ptr->editor[i]);
-	    core_ptr->editor[i] = NULL;
-	}
-	g_free(core_ptr->editor);
-	core_ptr->editor = NULL;
-	core_ptr->total_editors = 0;
+	/* Remove the timeout callback */
+	GTK_TIMEOUT_REMOVE(core->toid);
+	core->toid = 0;
 
-	/* Delete all viewers */
-	for(i = 0; i < core_ptr->total_viewers; i++)
-	{
-	    ViewerDelete(core_ptr->viewer[i]);
-	    core_ptr->viewer[i] = NULL;
-	}
-	g_free(core_ptr->viewer);
-	core_ptr->viewer = NULL;
-	core_ptr->total_viewers = 0;
+	/* Delete all the editors */
+	for(i = 0; i < core->total_editors; i++)
+	    EditorDelete(core->editor[i]);
+	g_free(core->editor);
+	core->editor = NULL;
+	core->total_editors = 0;
 
-	/* Get path to rcfile and save preferences */
-	rcfile = (char *)PrefParmGetValueP(
-	    core_ptr->pref, MEDIT_PREF_PARM_LOCATIONS_RCFILE
+	/* Delete all the viewers */
+	for(i = 0; i < core->total_viewers; i++)
+	    ViewerDelete(core->viewer[i]);
+	g_free(core->viewer);
+	core->viewer = NULL;
+	core->total_viewers = 0;
+
+	/* Save the confuiguration */
+	cfg_file = (char *)PrefParmGetValueP(
+	    core->pref, MEDIT_PREF_PARM_LOCATIONS_RCFILE
 	);
-	if(rcfile != NULL)
-	    rcfile = STRDUP(rcfile);
-	if(rcfile != NULL)
-	    PrefSaveToFile(core_ptr->pref, rcfile);
-	g_free(rcfile);
-	rcfile = NULL;
+	if(cfg_file != NULL)
+	    cfg_file = STRDUP(cfg_file);
+	if(cfg_file != NULL)
+	    PrefSaveToFile(core->pref, cfg_file);
+	g_free(cfg_file);
+	cfg_file = NULL;
 
-	/* Delete Preferences & Options window */
-	PrefDelete(core_ptr->pref);
-	core_ptr->pref = NULL;
+	/* Delete the Preferences & Options window */
+	PrefDelete(core->pref);
+	core->pref = NULL;
 
-	/* Delete about dialog */
-	AboutDialogDelete(core_ptr->about);
-	core_ptr->about = NULL;
+	/* Delete the about dialog */
+	AboutDialogDelete(core->about);
+	core->about = NULL;
 
 
 
 	/* Unref all cursors */
-	cursors_list = &core_ptr->cursors_list;
-	if(TRUE)
-	{
-	    GdkCursor **cursor;
-
-#define UNREF_CURSOR	{	\
- if((*cursor) != NULL) {	\
-  gdk_cursor_destroy(*cursor);	\
-  (*cursor) = NULL;		\
-} }
-	    cursor = &cursors_list->busy;
-	    UNREF_CURSOR
-
-	    cursor = &cursors_list->text;
-	    UNREF_CURSOR
-
-#undef UNREF_CURSOR
-	}
+	cursors_list = &core->cursors_list;
+	gdk_cursor_destroy(cursors_list->busy);
+	gdk_cursor_destroy(cursors_list->text);
 
 
 	/* Unref all pixmaps */
-	pixmaps_list = &core_ptr->pixmaps_list;
-	if(TRUE)
-	{
-	    GdkPixmap **pixmap;
-	    GdkBitmap **mask;
+	pixmaps_list = &core->pixmaps_list;
 
-#define UNREF_PIXMAP	{	\
- if(*pixmap != NULL) {		\
-  gdk_pixmap_unref(*pixmap);	\
-  *pixmap = NULL;		\
- }				\
- if((*mask) != NULL) {		\
-  gdk_bitmap_unref(*mask);	\
-  *mask = NULL;			\
- }				\
-}
-	    pixmap = &pixmaps_list->medit_icon_48x48;
-	    mask = &pixmaps_list->medit_icon_48x48_mask;
-	    UNREF_PIXMAP
+	GDK_PIXMAP_UNREF(pixmaps_list->medit_icon_48x48);
+	GDK_BITMAP_UNREF(pixmaps_list->medit_icon_48x48_mask);
 
+	GDK_PIXMAP_UNREF(pixmaps_list->folder_closed_20x20);
+	GDK_BITMAP_UNREF(pixmaps_list->folder_closed_20x20_mask);
 
-	    pixmap = &pixmaps_list->folder_closed_20x20;
-	    mask = &pixmaps_list->folder_closed_20x20_mask;
-	    UNREF_PIXMAP
+	GDK_PIXMAP_UNREF(pixmaps_list->folder_opened_20x20);
+	GDK_BITMAP_UNREF(pixmaps_list->folder_opened_20x20_mask);
 
-	    pixmap = &pixmaps_list->folder_opened_20x20;
-	    mask = &pixmaps_list->folder_opened_20x20_mask;
-	    UNREF_PIXMAP
+	GDK_PIXMAP_UNREF(pixmaps_list->manual_closed_20x20);
+	GDK_BITMAP_UNREF(pixmaps_list->manual_closed_20x20_mask);
 
+	GDK_PIXMAP_UNREF(pixmaps_list->manual_opened_20x20);
+	GDK_BITMAP_UNREF(pixmaps_list->manual_opened_20x20_mask);
 
-	    pixmap = &pixmaps_list->manual_closed_20x20;
-	    mask = &pixmaps_list->manual_closed_20x20_mask;
-	    UNREF_PIXMAP
+	GDK_PIXMAP_UNREF(pixmaps_list->manpage_heading_20x20);
+	GDK_BITMAP_UNREF(pixmaps_list->manpage_heading_20x20_mask);
 
-	    pixmap = &pixmaps_list->manual_opened_20x20;
-	    mask = &pixmaps_list->manual_opened_20x20_mask;
-	    UNREF_PIXMAP
-
-
-	    pixmap = &pixmaps_list->manpage_heading_20x20;
-	    mask = &pixmaps_list->manpage_heading_20x20_mask;
-	    UNREF_PIXMAP
-
-	    pixmap = &pixmaps_list->manpage_section_20x20;
-	    mask = &pixmaps_list->manpage_section_20x20_mask;
-	    UNREF_PIXMAP
-
-#undef UNREF_PIXMAP
-	}
+	GDK_PIXMAP_UNREF(pixmaps_list->manpage_section_20x20);
+	GDK_BITMAP_UNREF(pixmaps_list->manpage_section_20x20_mask);
 
 
 	/* Unref all styles */
-	styles_list = &core_ptr->styles_list;
-	if(TRUE)
-	{
-#define UNREF_STYLE(p)	{	\
-if(*(p) != NULL) {		\
- gtk_style_unref(*(p));		\
- *(p) = NULL;			\
-} }
-	    styles_list->standard = NULL;	/* Came from GTK internal, do
+	styles_list = &core->styles_list;
+
+	styles_list->standard = NULL;		/* Came from GTK internal, do
 						 * not unref it */
+	GTK_STYLE_UNREF(styles_list->heading1_text);
+	GTK_STYLE_UNREF(styles_list->heading2_text);
+	GTK_STYLE_UNREF(styles_list->heading3_text);
+	GTK_STYLE_UNREF(styles_list->heading4_text);
+	GTK_STYLE_UNREF(styles_list->heading5_text);
+	GTK_STYLE_UNREF(styles_list->heading6_text);
 
-	    UNREF_STYLE(&styles_list->heading1_text);
-	    UNREF_STYLE(&styles_list->heading2_text);
-	    UNREF_STYLE(&styles_list->heading3_text);
-	    UNREF_STYLE(&styles_list->heading4_text);
-	    UNREF_STYLE(&styles_list->heading5_text);
-	    UNREF_STYLE(&styles_list->heading6_text);
+	GTK_STYLE_UNREF(styles_list->heading1_rev_text);
+	GTK_STYLE_UNREF(styles_list->heading2_rev_text);
+	GTK_STYLE_UNREF(styles_list->heading3_rev_text);
+	GTK_STYLE_UNREF(styles_list->heading4_rev_text);
 
-	    UNREF_STYLE(&styles_list->heading1_rev_text);
-	    UNREF_STYLE(&styles_list->heading2_rev_text);
-	    UNREF_STYLE(&styles_list->heading3_rev_text);
-	    UNREF_STYLE(&styles_list->heading4_rev_text);
+	GTK_STYLE_UNREF(styles_list->edit_text_standard);
+	GTK_STYLE_UNREF(styles_list->edit_text_background);
+	GTK_STYLE_UNREF(styles_list->edit_text_tag_deliminator);
+	GTK_STYLE_UNREF(styles_list->edit_text_tag_text);
+	GTK_STYLE_UNREF(styles_list->edit_text_tag_symrep);
 
-	    UNREF_STYLE(&styles_list->edit_text_standard);
-	    UNREF_STYLE(&styles_list->edit_text_background);
-	    UNREF_STYLE(&styles_list->edit_text_tag_deliminator);
-	    UNREF_STYLE(&styles_list->edit_text_tag_text);
-	    UNREF_STYLE(&styles_list->edit_text_tag_symrep);
-
-	    UNREF_STYLE(&styles_list->manpage_text_standard);
-	    UNREF_STYLE(&styles_list->manpage_text_background);
-	    UNREF_STYLE(&styles_list->manpage_text_bold);
-	    UNREF_STYLE(&styles_list->manpage_text_underline);
-#undef UNREF_STYLE
-	}
+	GTK_STYLE_UNREF(styles_list->manpage_text_standard);
+	GTK_STYLE_UNREF(styles_list->manpage_text_background);
+	GTK_STYLE_UNREF(styles_list->manpage_text_bold);
+	GTK_STYLE_UNREF(styles_list->manpage_text_underline);
 
 
-	/* Delete all file extension types list */
-	fetype_list = &core_ptr->fetype_list;
-	if(fetype_list != NULL)
-	{
-	    fb_type_struct ***fb_type;
-	    int *total_fb_types;
-
-#define DELETE_FETYPE_LIST	{			\
- FileBrowserDeleteTypeList(*fb_type, *total_fb_types);	\
- *fb_type = NULL;					\
- *total_fb_types = 0;					\
-}
-
-	    fb_type = &fetype_list->manual_page;
-	    total_fb_types = &fetype_list->total_manual_pages;
-
-#undef DELETE_FETYPE_LIST
-	}
-
-	memset(core_ptr, 0x00, sizeof(medit_core_struct));
+	g_free(core);
 }
 
 
@@ -1180,29 +1057,24 @@ int main(int argc, char **argv)
 {
 	gint i, status;
 	const gchar *arg;
-	medit_core_struct *core_ptr = MEDIT_CORE(g_malloc0(
+	medit_core_struct *core = MEDIT_CORE(g_malloc0(
 	    sizeof(medit_core_struct)
 	));
-	if(core_ptr == NULL)
+	if(core == NULL)
 	    return(1);
 
-
-	/* Reset globals */
 	segfault_count = 0;
-	manage_timeout_cb_id = (guint)(-1);
 	need_close_all_windows = FALSE;
 
-	/* Set global core pointer */
-	context_core_ptr = core_ptr;
+	/* Set the global core pointer */
+	medit_core_ptr = core;
 
 use_text_delete = TRUE;
 
-
 	/* Set up signals */
 	signal(SIGINT, MEditSignalCB);
 	signal(SIGTERM, MEditSignalCB);
 	signal(SIGSEGV, MEditSignalCB);
-	signal(SIGKILL, MEditSignalCB);
 	signal(SIGPIPE, MEditSignalCB);
 
 
@@ -1214,18 +1086,18 @@ use_text_delete = TRUE;
 		continue;
 
 	    /* Help */
-	    if(g_strcasepfx(arg, "-h") ||
-	       g_strcasepfx(arg, "--h") ||
-	       g_strcasepfx(arg, "-?") ||
-	       g_strcasepfx(arg, "/?")
+	    if(!g_strcasecmp(arg, "--help") ||
+	       !g_strcasecmp(arg, "-help") ||
+	       !g_strcasecmp(arg, "--h") ||
+	       !g_strcasecmp(arg, "-h")
 	    )
 	    {
-		g_print(PROG_USAGE_MESG);
+		g_print("%s\n", PROG_USAGE_MESG);
 		return(0);
 	    }
 	    /* Version */
-	    else if(g_strcasepfx(arg, "-ver") ||
-		    g_strcasepfx(arg, "--ver")
+	    else if(!g_strcasecmp(arg, "--version") ||
+		    !g_strcasecmp(arg, "-version")
 	    )
 	    {
 		g_print(
@@ -1252,43 +1124,33 @@ use_text_delete = TRUE;
 	/* Initialize GTK */
 	gtk_init(&argc, &argv);
 
-	/* Initialize dialogs resources */
+	/* Initialize the dialogs */
 	CDialogInit();
 	FPromptInit();
-	ClipboardBrowserInit();
 	FileBrowserInit();
 	CSDInit();
 	FSDInit();
 	PDialogInit();
 
-	/* Initialize Manual Page Editor's resources */
-	status = MEditInit(core_ptr, argc, argv);
-	if(status)
+	/* Initialize the core */
+	core = MEditNew(argc, argv, &status);
+	if(status != 0)
 	{
-	    MEditShutdown(core_ptr);
-	    return(1);
+	    MEditDelete(core);
+	    return(status);
 	}
 
-	/* Set timeout to management function */
-	manage_timeout_cb_id = gtk_timeout_add(
-	    250l,
-	    MEditManage, core_ptr
-	);
-
 	/* Enter main GTK loop */
 	gtk_main();
 
+	/* Delete the core */
+	medit_core_ptr = NULL;
+	MEditDelete(core);
+	core = NULL;
 
-	/* Shutdown Manual Page Editor's resources */
-	MEditShutdown(core_ptr);
-	context_core_ptr = NULL;
-	g_free(core_ptr);
-	core_ptr = NULL;
-
-	/* Shutdown dialogs */
+	/* Shutdown the dialogs */
 	CDialogShutdown();
 	FPromptShutdown();
-	ClipboardBrowserShutdown();
 	FileBrowserShutdown();
 	CSDShutdown();
 	FSDShutdown();
