@@ -43,56 +43,47 @@ void MEditViewerNewCB(GtkWidget *widget, gpointer data);
  * unmapped viewer on the core structure, uses variables core_ptr,
  * last_null_num, viewer_num, and viewer
  */
-#define DO_NEW_VIEWER	\
-{ \
- last_null_num = -1; \
+#define DO_NEW_VIEWER	{			\
+ last_null_num = -1;				\
  for(viewer_num = 0; viewer_num < core_ptr->total_viewers; viewer_num++) \
- { \
-  viewer = core_ptr->viewer[viewer_num]; \
-  if(viewer == NULL) \
-  { \
-   last_null_num = viewer_num; \
-   continue; \
-  } \
-  if(viewer->initialized && !viewer->map_state) \
-   break; \
- } \
- if(viewer_num < core_ptr->total_viewers) \
- { \
+ {						\
+  viewer = core_ptr->viewer[viewer_num];	\
+  if(viewer == NULL) {				\
+   last_null_num = viewer_num;			\
+   continue;					\
+  }						\
+  if(!GTK_WIDGET_MAPPED(viewer->toplevel))	\
+   break;					\
+ }						\
+ if(viewer_num < core_ptr->total_viewers) {	\
   /* Found one that was initialized and unmapped */ \
-  viewer = core_ptr->viewer[viewer_num]; \
-  ViewerMap(viewer); \
- } \
- else \
- { \
-  /* Need to create a new viewer */ \
-  if(last_null_num > -1) \
-  { \
-   viewer_num = last_null_num; \
-  } \
-  else \
-  { \
-   viewer_num = core_ptr->total_viewers; \
-   core_ptr->total_viewers = viewer_num + 1; \
+  viewer = core_ptr->viewer[viewer_num];	\
+  ViewerMap(viewer);				\
+ } else {					\
+  /* Need to create a new viewer */		\
+  if(last_null_num > -1) {			\
+   viewer_num = last_null_num;			\
+  } else {					\
+   viewer_num = core_ptr->total_viewers;	\
+   core_ptr->total_viewers = viewer_num + 1;	\
    core_ptr->viewer = (viewer_struct **)g_realloc( \
-    core_ptr->viewer, \
+    core_ptr->viewer,				\
     core_ptr->total_viewers * sizeof(viewer_struct *) \
-   ); \
-   if(core_ptr->viewer == NULL) \
-   { \
-    core_ptr->total_viewers = 0; \
-    return; \
-   } \
-   core_ptr->viewer[viewer_num] = NULL; \
-  } \
-  /* Allocate and create a new viewer */ \
-  viewer = ViewerNew((void *)core_ptr, -1); \
-  core_ptr->viewer[viewer_num] = viewer; \
-  if(viewer != NULL) \
-   ViewerMap(viewer); \
-  else \
-   viewer_num = -1; \
- } \
+   );						\
+   if(core_ptr->viewer == NULL)	{		\
+    core_ptr->total_viewers = 0;		\
+    return;					\
+   }						\
+   core_ptr->viewer[viewer_num] = NULL;		\
+  }						\
+  /* Allocate and create a new viewer */	\
+  viewer = ViewerNew(core_ptr, -1);		\
+  core_ptr->viewer[viewer_num] = viewer;	\
+  if(viewer != NULL)				\
+   ViewerMap(viewer);				\
+  else						\
+   viewer_num = -1;				\
+ }						\
 }
 
 
@@ -338,7 +329,7 @@ void MEditEditorNewCB(GtkWidget *widget, gpointer data)
 		continue;
 	    }
 
-	    if(editor->initialized && !editor->map_state)
+	    if(!GTK_WIDGET_MAPPED(editor->toplevel))
 		break;
 	}
 	if(i < core_ptr->total_editors)
@@ -407,7 +398,7 @@ void MEditViewerNewCB(GtkWidget *widget, gpointer data)
 		continue;
 	    }
 		
-	    if(viewer->initialized && !viewer->map_state)
+	    if(!GTK_WIDGET_MAPPED(viewer->toplevel))
 		break;
 	}
 	if(i < core_ptr->total_viewers)
