@@ -25,7 +25,8 @@ extern gint MEditExecuteFmtBlock(
 );
 extern gint MEditDialogFromFile(
 	medit_core_struct *core_ptr,
-	const gchar *path
+	const gchar *path,
+	GtkWidget *toplevel
 );
 extern gint MEditDoEmergencySave(medit_core_struct *core_ptr);
 extern gint MEditDoCrashRecovery(medit_core_struct *core_ptr);
