@@ -5,37 +5,38 @@
 #ifndef MPFIO_H
 #define MPFIO_H
 
-#include <sys/types.h>
-
 
 /*
- *	Header structure:
+ *	Header:
  */
 typedef struct {
 
-	/* All loaded data format is in plain text. */
+	/* All loaded data format is in plain text */
 
-	char *title;
+	char		*title;
 
-	/* Misc data. */
-	char **line;
-	int total_lines;
+	/* Misc data */
+	char		**line;
+	int		total_lines;
 
 } mp_header_struct;
+#define MP_HEADER(p)		((mp_header_struct *)(p))
+
 
 /*
- *	Section structure:
+ *	Section:
  */
 typedef struct {
 
-	/* All loaded data format is in plain text. */
-	char *section;
+	/* All loaded data format is in plain text */
+	char		*section;
 
-	/* Contents. */
-	char **line;
-	int total_lines;
+	/* Contents */
+	char		**line;
+	int		total_lines;
 
 } mp_section_struct;
+#define MP_SECTION(p)		((mp_section_struct *)(p))
 
 
 extern int MPLoad(
