@@ -3,7 +3,10 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
+#include "../include/disk.h"
+
 #include "guiutils.h"
+#include "pulist.h"
 #include "pdialog.h"
 #include "config.h"
 
@@ -69,6 +72,7 @@ typedef enum {
 	PDIALOG_PROMPT_TYPE_ENTRY,
 	PDIALOG_PROMPT_TYPE_SPIN,
 	PDIALOG_PROMPT_TYPE_SCALE,
+	PDIALOG_PROMPT_TYPE_POPUP_LIST,
 	PDIALOG_PROMPT_TYPE_COMBO,
 	PDIALOG_PROMPT_TYPE_RADIO,
 	PDIALOG_PROMPT_TYPE_TOGGLE,
@@ -77,7 +81,9 @@ typedef enum {
 
 
 typedef struct _pdialog_struct		pdialog_struct;
+#define PDIALOG(p)			((pdialog_struct *)(p))
 typedef struct _pdialog_prompt_struct	pdialog_prompt_struct;
+#define PDIALOG_PROMPT(p)		((pdialog_prompt_struct *)(p))
 
 
 /*
@@ -92,20 +98,20 @@ struct _pdialog_prompt_struct {
 			*value,
 			*browse_btn;
 
+	pulistbox_struct *pulistbox;
 	GtkWidget	*radio_toplevel, **radio;
 	gchar		**radio_label;
 	gint		total_radios;
-  
-	gpointer	client_data;
 
 	gchar	*(*browse_cb)(
 		gpointer,	/* PDialog */
 		gpointer,	/* Data */
 		gint		/* Prompt Number */
 	);
+	gpointer	browse_data;
 
 };
-#define PDIALOG_PROMPT(p)	((pdialog_prompt_struct *)(p))
+
 
 /*
  *	Prompt Dialog:
@@ -137,7 +143,6 @@ struct _pdialog_struct {
 	gchar		**response_val;
 	gint		response_nvals;
 };
-#define PDIALOG(p)	((pdialog_struct *)(p))
 
 
 /* Callbacks */
@@ -146,6 +151,9 @@ static gint PDialogCloseCB(
 );
 static void PDialogBrowseButtonCB(GtkWidget *widget, gpointer data);
 static void PDialogEntryEnterCB(GtkWidget *widget, gpointer data);
+static gint PDialogEntryCompletePathKeyCB(
+	GtkWidget *widget, GdkEventKey *key, gpointer data
+);
 static void PDialogButtonCB(GtkWidget *widget, gpointer data);
 static void PDialogPromptDragDataReceivedCB(
 	GtkWidget *widget, GdkDragContext *dc, gint x, gint y,
@@ -161,14 +169,14 @@ static gboolean PDialogPromptDragMotionCB(
 static guint8 **PDialogGetMessageIconDataFromCode(pdialog_icon icon_code);
 static void PDialogSetIcon(pdialog_struct *d, guint8 **icon_data);
 static pdialog_prompt_struct *PDialogPromptNewNexus(
-	pdialog_prompt_type type,
+	const pdialog_prompt_type type,
 	const guint8 **icon_data,
 	const gchar *label,
 	const gchar *value,
-	gboolean hide_value,		/* For passwords */
+	const gboolean hide_value,	/* For passwords */
 	pdialog_struct *d,
-	gpointer client_data,
-	gchar *(*browse_cb)(gpointer, gpointer, gint)
+	gchar *(*browse_cb)(gpointer, gpointer, gint),
+	gpointer browse_data
 );
 static void PDialogPromptDelete(pdialog_prompt_struct *p);
 
@@ -181,13 +189,13 @@ void PDialogBreakQuery(void);
 GtkWidget *PDialogGetToplevel(void);
 
 static pdialog_prompt_struct *PDialogAddPromptNexus(
-	pdialog_prompt_type type,
+	const pdialog_prompt_type type,
 	const guint8 **icon_data,
 	const gchar *label,
 	const gchar *value,
-	gboolean hide_value,		/* For passwords */
-	gpointer client_data,
-	gchar *(*browse_cb)(gpointer, gpointer, gint)
+	const gboolean hide_value,	/* For passwords */
+	gchar *(*browse_cb)(gpointer, gpointer, gint),
+	gpointer browse_data
 );
 void PDialogAddPromptLabel(const gchar *label);
 void PDialogAddPrompt(
@@ -204,7 +212,7 @@ void PDialogAddPromptWithBrowse(
 	const guint8 **icon_data,	/* Can be NULL */
 	const gchar *label,		/* Can be NULL */
 	const gchar *value,		/* Can be NULL */
-	gpointer client_data,		/* Can be NULL */
+	gpointer browse_data,		/* Can be NULL */
 	gchar *(*browse_cb)(gpointer, gpointer, gint)	/* Can be NULL */
 );
 void PDialogAddPromptSpin(
@@ -221,18 +229,26 @@ void PDialogAddPromptScale(
 	gfloat step_increment, gfloat page_increment,
 	gboolean show_value, guint digits
 );
+void PDialogAddPromptPopupList(
+	const guint8 **icon_data,
+	const gchar *label,
+	GList *list,			/* List of values */
+	const gint start_num,		/* Initial value */
+	const gint nitems_visible	/* Number of items visible */
+);
 void PDialogAddPromptCombo(
 	const guint8 **icon_data,
 	const gchar *label,
-	const gchar *value,
-	GList *list,
-	gboolean editable, gboolean case_sensitive
+	const gchar *value,		/* Initial value */
+	GList *list,			/* List of values */
+	const gboolean editable,
+	const gboolean case_sensitive
 );
 void PDialogAddPromptRadio(
 	const guint8 **icon_data,
 	const gchar *label,
-	GList *list,		/* List of radio button names */
-	gint start_num		/* Initial radio button to select */
+	GList *list,			/* List of values */
+	const gint start_num		/* Initial value */
 );
 void PDialogAddPromptToggle(
 	const guint8 **icon_data,
@@ -246,7 +262,8 @@ void PDialogSetPromptValue(
 	const gchar *value
 );
 void PDialogSetPromptTip(gint prompt_num, const gchar *tip);
-gchar *PDialogGetPromptValue(gint prompt_num);
+const gchar *PDialogGetPromptValue(gint prompt_num);
+void PDialogSetPromptCompletePath(gint prompt_num);
 void PDialogDeleteAllPrompts(void);
 gchar **PDialogGetResponse(
 	const gchar *title,
@@ -276,16 +293,16 @@ void PDialogUnmap(void);
 void PDialogShutdown(void);
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 static pdialog_struct	pdialog;
@@ -336,7 +353,7 @@ static void PDialogBrowseButtonCB(GtkWidget *widget, gpointer data)
 	    {
 		s = (const gchar *)p->browse_cb(
 		    d,			/* Prompt dialog */
-		    p->client_data,	/* Client data */
+		    p->browse_data,	/* Data */
 		    i			/* Prompt number */
 		);
 		w = p->value;
@@ -351,7 +368,7 @@ static void PDialogBrowseButtonCB(GtkWidget *widget, gpointer data)
 }
 
 /*
- *      Dialog prompt GtkEntry "activate" signal callback.
+ *	Dialog prompt GtkEntry "activate" signal callback.
  */
 static void PDialogEntryEnterCB(GtkWidget *widget, gpointer data)
 {
@@ -365,6 +382,86 @@ static void PDialogEntryEnterCB(GtkWidget *widget, gpointer data)
 	PDialogButtonCB(d->submit_btn, d);
 }
 
+/*
+ *	Dialog prompt GtkEntry complete path "key_press_event" or
+ *	"key_release_event" signal callback.
+ */
+static gint PDialogEntryCompletePathKeyCB(
+	GtkWidget *widget, GdkEventKey *key, gpointer data
+)
+{
+	gint status = 0;
+	gboolean press;
+	GtkEntry *entry;
+	pdialog_struct *d = PDIALOG(data);
+	if((widget == NULL) || (key == NULL) || (d == NULL))
+	    return(status);
+
+	press = (key->type == GDK_KEY_PRESS) ? TRUE : FALSE;
+
+	/* Given widget must have or be a GtkEntry */
+	if(GTK_IS_COMBO(widget))
+	{
+	    GtkCombo *combo = GTK_COMBO(widget);
+	    entry = GTK_ENTRY(combo->entry);
+	}
+	else if(GTK_IS_ENTRY(widget))
+	{
+	    entry = GTK_ENTRY(widget);
+	}
+	else
+	{
+	    return(status);
+	}
+
+#define SIGNAL_EMIT_STOP	{		\
+ gtk_signal_emit_stop_by_name(			\
+  GTK_OBJECT(widget),				\
+  press ?					\
+   "key_press_event" : "key_release_event"	\
+ );						\
+}
+
+	switch(key->keyval)
+	{
+	  case GDK_Tab:
+	    /* Skip this if the shift or ctrl keys are held */
+	    if((key->state & GDK_CONTROL_MASK) ||
+	       (key->state & GDK_SHIFT_MASK)
+	    )
+		return(status);
+
+	    if(press)
+	    {
+		gchar *s = STRDUP(gtk_entry_get_text(entry));
+		if(s != NULL)
+		{
+		    gint status;
+
+		    s = CompletePath(s, &status);
+		    gtk_entry_set_text(entry, (s != NULL) ? s : "");
+		    gtk_entry_set_position(entry, -1);
+		    g_free(s);
+
+		    switch(status)
+		    {
+		      case COMPLETE_PATH_NONE:
+		      case COMPLETE_PATH_AMBIGUOUS:
+			gdk_beep();
+			break;
+		    }
+		}
+	    }
+	    SIGNAL_EMIT_STOP
+	    status = TRUE;
+	    break;
+	}
+
+#undef SIGNAL_EMIT_STOP
+
+	return(status);
+}
+
 /*
  *	Dialog GtkButton "clicked" signal callback.
  */
@@ -381,7 +478,7 @@ static void PDialogButtonCB(GtkWidget *widget, gpointer data)
 	{
 	    gint i;
 
-	    /* Clear existing responses values */
+	    /* Clear the existing responses values */
 	    for(i = 0; i < d->response_nvals; i++)
 		g_free(d->response_val[i]);
 	    g_free(d->response_val);
@@ -462,6 +559,21 @@ static void PDialogButtonCB(GtkWidget *widget, gpointer data)
 			}
 			break;
 
+		      case PDIALOG_PROMPT_TYPE_POPUP_LIST:
+			if(p->pulistbox != NULL)
+			{
+			    pulistbox_struct *pulistbox = p->pulistbox;
+			    pulist_struct *pulist = PUListBoxGetPUList(pulistbox);
+			    gchar *v;
+			    PUListGetItemText(
+				pulist,
+				PUListGetSelectedLast(pulist),
+				&v
+			    );
+			    d->response_val[i] = STRDUP((v != NULL) ? v : "");
+			}
+			break;
+
 		      case PDIALOG_PROMPT_TYPE_COMBO:
 			if(GTK_IS_COMBO(w))
 			{
@@ -541,9 +653,9 @@ static void PDialogPromptDragDataReceivedCB(
 	if((selection_data->data == NULL) || (selection_data->length <= 0))
 	    return;
 
-	if((info == 0) ||	/* "text/plain" */
-	   (info == 1) ||	/* "text/uri-list" */
-	   (info == 2)		/* "STRING" */
+	if((info == 0) ||	/* GUI_TARGET_NAME_TEXT_PLAIN */
+	   (info == 1) ||	/* GUI_TARGET_NAME_TEXT_URI_LIST */
+	   (info == 2)		/* GUI_TARGET_NAME_STRING */
 	)
 	{
 	    gint buf_len = selection_data->length;
@@ -758,17 +870,17 @@ static void PDialogSetIcon(pdialog_struct *d, guint8 **icon_data)
 
 /*
  *	Allocates and creates a new prompt structure, but does not 
- *      add it to the prompt dialog.
+ *	add it to the prompt dialog.
  */
 static pdialog_prompt_struct *PDialogPromptNewNexus(
-	pdialog_prompt_type type,
+	const pdialog_prompt_type type,
 	const guint8 **icon_data,
 	const gchar *label,
 	const gchar *value,
-	gboolean hide_value,		/* For passwords */
+	const gboolean hide_value,	/* For passwords */
 	pdialog_struct *d,
-	gpointer client_data,
-	gchar *(*browse_cb)(gpointer, gpointer, gint)
+	gchar *(*browse_cb)(gpointer, gpointer, gint),
+	gpointer browse_data
 )
 {
 	const gint	border_major = 5,
@@ -783,7 +895,7 @@ static pdialog_prompt_struct *PDialogPromptNewNexus(
 	    return(p);
 
 	w = d->toplevel;
-	window = (w != NULL) ? w->window : NULL;      
+	window = (w != NULL) ? w->window : NULL;
 	style = gtk_widget_get_style(w); 
 
 	p->type = type;
@@ -826,13 +938,15 @@ static pdialog_prompt_struct *PDialogPromptNewNexus(
 	/* Primary input widget */
 	if(TRUE)
 	{
-	    GtkWidget *w2;
 	    const GtkTargetEntry dnd_tar_types[] = {
-{"text/plain",                          0,	0},
-{"text/uri-list",                       0,	1},
-{"STRING",                              0,	2}
+{GUI_TARGET_NAME_TEXT_PLAIN,	0,		0},
+{GUI_TARGET_NAME_TEXT_URI_LIST,	0,		1},
+{GUI_TARGET_NAME_STRING,	0,		2}
 	    };
-	    /* Create by prompt type */
+	    GtkWidget *w2;
+	    pulistbox_struct *pulistbox;
+
+	    /* Create the primary input widget by the prompt type */
 	    switch(type)
 	    {
 	      case PDIALOG_PROMPT_TYPE_LABEL:
@@ -888,6 +1002,14 @@ static pdialog_prompt_struct *PDialogPromptNewNexus(
 		gtk_widget_show(w);
 		break;
 
+	      case PDIALOG_PROMPT_TYPE_POPUP_LIST:
+		p->pulistbox = pulistbox = PUListBoxNew(
+		    parent,
+		    -1, -1
+		);
+		PUListBoxMap(pulistbox);
+		break;
+
 	      case PDIALOG_PROMPT_TYPE_COMBO:
 		p->value = w = gtk_combo_new();
 		gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, 0);
@@ -898,9 +1020,9 @@ static pdialog_prompt_struct *PDialogPromptNewNexus(
 		    w2,
 		    dnd_tar_types,
 		    sizeof(dnd_tar_types) / sizeof(GtkTargetEntry),
-		    GDK_ACTION_COPY,            /* Actions */
-		    GDK_ACTION_COPY,            /* Default action if same */
-		    GDK_ACTION_COPY,            /* Default action */
+		    GDK_ACTION_COPY,		/* Actions */
+		    GDK_ACTION_COPY,		/* Default action if same */
+		    GDK_ACTION_COPY,		/* Default action */
 		    PDialogPromptDragDataReceivedCB,
 		    w2
 		);
@@ -951,8 +1073,8 @@ static pdialog_prompt_struct *PDialogPromptNewNexus(
 	if(browse_cb != NULL)
 	{
 	    /* Set browse callback function and client data */
-	    p->client_data = client_data;
 	    p->browse_cb = browse_cb;
+	    p->browse_data = browse_data;
 
 	    /* Create browse button */
 	    p->browse_btn = w = GUIButtonPixmap(
@@ -972,7 +1094,7 @@ static pdialog_prompt_struct *PDialogPromptNewNexus(
 		"Hojee"
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-		"Brouter"
+		"Naviguer"
 #endif
 #ifdef PROG_LANGUAGE_GERMAN
 		"Brausen"
@@ -1019,11 +1141,13 @@ static void PDialogPromptDelete(pdialog_prompt_struct *p)
 	p->total_radios = 0;
 	GTK_WIDGET_DESTROY(p->radio_toplevel)
 
-	GTK_WIDGET_DESTROY(p->browse_btn)
-	GTK_WIDGET_DESTROY(p->value)
-	GTK_WIDGET_DESTROY(p->label)
-	GTK_WIDGET_DESTROY(p->icon_pm)
-	GTK_WIDGET_DESTROY(p->toplevel)
+	PUListBoxDelete(p->pulistbox);
+
+	GTK_WIDGET_DESTROY(p->browse_btn);
+	GTK_WIDGET_DESTROY(p->value);
+	GTK_WIDGET_DESTROY(p->label);
+	GTK_WIDGET_DESTROY(p->icon_pm);
+	GTK_WIDGET_DESTROY(p->toplevel);
 
 	g_free(p);
 }
@@ -1040,7 +1164,9 @@ gint PDialogInit(void)
 	GdkWindow *window;
 	GtkAccelGroup *accelgrp;
 	GtkStyle *style;
-	GtkWidget *w, *parent, *parent2, *parent3;
+	GtkWidget	*w,
+			*parent, *parent2, *parent3,
+			*toplevel;
 	pdialog_struct *d = &pdialog;
 
 	/* Already initialized? */
@@ -1050,6 +1176,8 @@ gint PDialogInit(void)
 	/* Reset values */
 	memset(d, 0x00, sizeof(pdialog_struct));
 
+	d->toplevel = toplevel = gtk_window_new(GTK_WINDOW_DIALOG);
+	d->accelgrp = accelgrp = gtk_accel_group_new();
 	d->initialized = TRUE;
 	d->last_icon_code = PDIALOG_ICON_QUESTION;
 	d->last_transient_for = NULL;
@@ -1057,11 +1185,9 @@ gint PDialogInit(void)
 	d->response_val = NULL;
 	d->response_nvals = 0;
 
-	/* Keyboard accelerator group */
-	d->accelgrp = accelgrp = gtk_accel_group_new();
-
-	/* Toplevel */
-	d->toplevel = w = gtk_window_new(GTK_WINDOW_DIALOG);
+	/* Toplevel GtkWindow */
+	w = toplevel;
+	gtk_window_set_policy(GTK_WINDOW(w), TRUE, TRUE, TRUE);
 	gtk_window_set_title(GTK_WINDOW(w), "Enter Values");
 #ifdef PROG_NAME
 	gtk_window_set_wmclass(
@@ -1078,12 +1204,11 @@ gint PDialogInit(void)
 
 	    gdk_window_set_decorations(
 		window,
-		GDK_DECOR_BORDER | GDK_DECOR_TITLE | GDK_DECOR_MENU |
-		GDK_DECOR_MINIMIZE
+		GDK_DECOR_BORDER | GDK_DECOR_TITLE
 	    );
 	    gdk_window_set_functions(
 		window,
-		GDK_FUNC_MOVE | GDK_FUNC_MINIMIZE | GDK_FUNC_CLOSE
+		GDK_FUNC_MOVE | GDK_FUNC_CLOSE
 	    );
 
 	    geo.min_width = 100;
@@ -1102,6 +1227,10 @@ gint PDialogInit(void)
 		GDK_HINT_BASE_SIZE | GDK_HINT_RESIZE_INC
 	    );
 	}
+	gtk_widget_add_events(
+	    w,
+	    GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
+	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "delete_event",
 	    GTK_SIGNAL_FUNC(PDialogCloseCB), d
@@ -1279,7 +1408,7 @@ gint PDialogInit(void)
 	    "Ayuda",
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	    "L'Aide",
+	    "Aide",
 #endif
 #ifdef PROG_LANGUAGE_GERMAN
 	    "Hilfe",
@@ -1311,7 +1440,7 @@ gint PDialogInit(void)
 }
 
 /*
- *      Sets the Dialog's style.
+ *	Sets the Dialog's style.
  */
 void PDialogSetStyle(GtkRcStyle *rc_style)
 {
@@ -1338,9 +1467,9 @@ void PDialogSetStyle(GtkRcStyle *rc_style)
 }
 
 /*
- *      Sets the Dialog to be a transient for the given GtkWindow w.
+ *	Sets the Dialog to be a transient for the given GtkWindow w.
  *
- *      If w is NULL then transient for will be unset.
+ *	If w is NULL then transient for will be unset.
  */
 void PDialogSetTransientFor(GtkWidget *w)
 {
@@ -1381,7 +1510,7 @@ void PDialogSetTransientFor(GtkWidget *w)
 }
 
 /*
- *      Checks if the Dialog is currently waiting for user input.
+ *	Checks if the Dialog is currently waiting for user input.
  */
 gboolean PDialogIsQuery(void)
 {
@@ -1390,8 +1519,8 @@ gboolean PDialogIsQuery(void)
 }
 
 /*
- *      Breaks the Dialog's user input query (if any) and causes the
- *      querying function to return CDIALOG_RESPONSE_NOT_AVAILABLE.
+ *	Breaks the Dialog's user input query (if any) and causes the
+ *	querying function to return CDIALOG_RESPONSE_NOT_AVAILABLE.
  */
 void PDialogBreakQuery(void)
 {
@@ -1420,13 +1549,13 @@ GtkWidget *PDialogGetToplevel(void)
  *	Nexus for adding a prompt to the dialog.
  */
 static pdialog_prompt_struct *PDialogAddPromptNexus(
-	pdialog_prompt_type type,
+	const pdialog_prompt_type type,
 	const guint8 **icon_data,
 	const gchar *label,
 	const gchar *value,
-	gboolean hide_value,		/* For passwords */
-	gpointer client_data,
-	gchar *(*browse_cb)(gpointer, gpointer, gint)
+	const gboolean hide_value,		/* For passwords */
+	gchar *(*browse_cb)(gpointer, gpointer, gint),
+	gpointer browse_data
 )
 {
 	gint n;
@@ -1436,7 +1565,7 @@ static pdialog_prompt_struct *PDialogAddPromptNexus(
 	    type,
 	    icon_data, label, value, hide_value,
 	    d,
-	    client_data, browse_cb
+	    browse_cb, browse_data
 	);
 	if(p == NULL)
 	    return(NULL);
@@ -1487,7 +1616,7 @@ static pdialog_prompt_struct *PDialogAddPromptNexus(
  */
 void PDialogAddPromptLabel(const gchar *label)
 {
-	PDialogAddPromptNexus(   
+	PDialogAddPromptNexus(
 	    PDIALOG_PROMPT_TYPE_LABEL,
 	    NULL, NULL, label, FALSE, NULL, NULL
 	);
@@ -1509,7 +1638,7 @@ void PDialogAddPrompt(
 }
 
 /*
- *      Adds a prompt (with the value hidden for passwords) to the
+ *	Adds a prompt (with the value hidden for passwords) to the
  *	dialog.
  */
 void PDialogAddPromptPassword(
@@ -1531,18 +1660,18 @@ void PDialogAddPromptWithBrowse(
 	const guint8 **icon_data,
 	const gchar *label,
 	const gchar *value,
-	gpointer client_data,
+	gpointer browse_data,
 	gchar *(*browse_cb)(gpointer, gpointer, gint)
 )
 {
 	PDialogAddPromptNexus(
 	    PDIALOG_PROMPT_TYPE_ENTRY,
-	    icon_data, label, value, FALSE, client_data, browse_cb
+	    icon_data, label, value, FALSE, browse_cb, browse_data
 	);
 }
 
 /*
- *      Adds a spin prompt to the dialog.
+ *	Adds a spin prompt to the dialog.
  */
 void PDialogAddPromptSpin(
 	const guint8 **icon_data,
@@ -1569,7 +1698,7 @@ void PDialogAddPromptSpin(
 }
 
 /*
- *      Adds a scale prompt to the dialog.
+ *	Adds a scale prompt to the dialog.
  */
 void PDialogAddPromptScale(
 	const guint8 **icon_data,
@@ -1605,17 +1734,87 @@ void PDialogAddPromptScale(
 	}
 }
 
+/*
+ *	Adds a popup list prompt to the dialog.
+ *
+ *	The list specifies the list of values, each value is a
+ *	gchar * to a string. The list will not be modified by this
+ *	function. If list is NULL then no list of values will be set.
+ *
+ *	The start_num specifies the initial value or -1 for none.
+ *
+ *	The nitems_visible specifies the number of items visible or
+ *	-1 for default.
+ */
+void PDialogAddPromptPopupList(
+	const guint8 **icon_data,
+	const gchar *label,
+	GList *list,			/* List of values */
+	const gint start_num,		/* Initial value */
+	const gint nitems_visible
+)
+{
+	pdialog_prompt_struct *p = PDialogAddPromptNexus(
+	    PDIALOG_PROMPT_TYPE_POPUP_LIST,
+	    icon_data, label, NULL, FALSE, NULL, NULL
+	);
+	if(p != NULL)
+	{
+	    pulistbox_struct *pulistbox = p->pulistbox;
+	    if(pulistbox != NULL)
+	    {
+		pulist_struct *pulist = PUListBoxGetPUList(pulistbox);
+		GList *glist = list;
+		while(glist != NULL)
+		{
+		    PUListAddItem(pulist, (gchar *)glist->data);
+		    glist = g_list_next(glist);
+		}
+		if(start_num > -1)
+		    PUListBoxSelect(pulistbox, start_num);
+
+		if(nitems_visible > -1)
+		{
+		    PUListBoxSetLinesVisible(
+			pulistbox, nitems_visible
+		    );
+		}
+		else
+		{
+		    PUListBoxSetLinesVisible(
+			pulistbox,
+			MIN(
+			    PUListGetTotalItems(pulist),
+			    10
+			)
+		    );
+		}
+	    }
+	}
+}
+
 /*
  *	Adds a combo prompt to the dialog.
  *
- *	The given glist is not modified by this function.
+ *	The value specifies the initial value. If value is NULL then
+ *	no initial value will be set.
+ *
+ *	The list specifies the list of values, each value is a
+ *	gchar * to a string. The list will not be modified by this
+ *	function. If list is NULL then no list of values will be set.
+ *
+ *	If editable is TRUE then the entry will be set as editable.
+ *
+ *	If case_sensitive is TRUE then only case sensitive matches
+ *	will be made with the list values and the entry value.
  */
 void PDialogAddPromptCombo(
 	const guint8 **icon_data,
 	const gchar *label,
 	const gchar *value,
 	GList *list,
-	gboolean editable, gboolean case_sensitive
+	const gboolean editable,
+	const gboolean case_sensitive
 )
 {
 	pdialog_prompt_struct *p = PDialogAddPromptNexus(
@@ -1637,15 +1836,19 @@ void PDialogAddPromptCombo(
 }
 
 /*
- *      Adds a radio prompt to the dialog.
+ *	Adds a radio prompt to the dialog.
  *
- *      The given glist is not modified by this function.
+ *	The list specifies the list of values, each value is a
+ *	gchar * to a string. The list will not be modified by this
+ *	function. If list is NULL then no list of values will be set.
+ *
+ *	The start_num specifies the initial value or -1 for none.
  */
 void PDialogAddPromptRadio(
 	const guint8 **icon_data,
 	const gchar *label,
-	GList *list,            /* List of radio button names */
-	gint start_num          /* Initial radio button to select */
+	GList *list,
+	const gint start_num
 )
 {
 	pdialog_prompt_struct *p = PDialogAddPromptNexus(
@@ -1682,7 +1885,8 @@ void PDialogAddPromptRadio(
 
 		/* Record value as a the radio button label string */
 		p->radio_label = (gchar **)g_realloc(
-		    p->radio_label, p->total_radios * sizeof(gchar *)
+		    p->radio_label,
+		    p->total_radios * sizeof(gchar *)
 		);
 		p->radio_label[i] = STRDUP((glist->data != NULL) ?
 		    (const gchar *)glist->data : ""
@@ -1696,7 +1900,7 @@ void PDialogAddPromptRadio(
 }
 
 /*
- *      Adds a toggle prompt to the dialog.
+ *	Adds a toggle prompt to the dialog.
  */
 void PDialogAddPromptToggle(
 	const guint8 **icon_data,
@@ -1829,6 +2033,30 @@ void PDialogSetPromptValue(
 		}
 		break;
 
+	      case PDIALOG_PROMPT_TYPE_POPUP_LIST:
+		if(p->pulistbox != NULL)
+		{
+		    gint i;
+		    gchar *v;
+		    pulistbox_struct *pulistbox = p->pulistbox;
+		    pulist_struct *pulist = PUListBoxGetPUList(pulistbox);
+		    const gint m = PUListGetTotalItems(pulist);
+
+		    for(i = 0; i < m; i++)
+		    {
+			PUListGetItemText(pulist, i, &v);
+			if(v == NULL)
+			    continue;
+
+			if(!g_strcasecmp(v, value))
+			{
+			    PUListBoxSelect(pulistbox, i);
+			    break;
+			}
+		    }
+		}
+		break;
+
 	      case PDIALOG_PROMPT_TYPE_COMBO:
 		if(GTK_IS_COMBO(w))
 		{
@@ -1878,9 +2106,9 @@ void PDialogSetPromptValue(
 /*
  *	Sets the tip for the given prompt.
  *
- *      If any input is NULL then that value will be left unchanged.
+ *	If any input is NULL then that value will be left unchanged.
  *
- *      If prompt_num is -1 then the last prompt will be used.
+ *	If prompt_num is -1 then the last prompt will be used.
  */
 void PDialogSetPromptTip(gint prompt_num, const gchar *tip)
 {
@@ -1888,7 +2116,6 @@ void PDialogSetPromptTip(gint prompt_num, const gchar *tip)
 	pdialog_prompt_struct *p;
 	pdialog_struct *d = &pdialog;
 
-
 	if(prompt_num < 0)
 	    prompt_num = d->total_prompts - 1;
 
@@ -1917,6 +2144,14 @@ void PDialogSetPromptTip(gint prompt_num, const gchar *tip)
 		GUISetWidgetTip(w, tip);
 		break;
 
+	      case PDIALOG_PROMPT_TYPE_POPUP_LIST:
+		if(p->pulistbox != NULL)
+		{
+		    pulistbox_struct *pulistbox = p->pulistbox;
+		    GUISetWidgetTip(pulistbox->da, tip);
+		}
+		break;
+
 	      case PDIALOG_PROMPT_TYPE_COMBO:
 		w = p->value;
 		if(w != NULL)
@@ -1945,15 +2180,14 @@ void PDialogSetPromptTip(gint prompt_num, const gchar *tip)
 }
 
 /*
- *	Fetches the value of the specified prompt as a statically
- *	allocated string which must not be modified or deallocated.
+ *	Gets the value of the specified prompt as a string.
  *
  *	Can return NULL on error or if the prompt does not have a value
  *	to return.
  *
  *	If prompt_num is -1 then the last prompt will be used.
  */
-gchar *PDialogGetPromptValue(gint prompt_num)
+const gchar *PDialogGetPromptValue(gint prompt_num)
 {
 	pdialog_prompt_struct *p;
 	pdialog_struct *d = &pdialog;
@@ -2009,6 +2243,21 @@ gchar *PDialogGetPromptValue(gint prompt_num)
 		}
 		break;
 
+	      case PDIALOG_PROMPT_TYPE_POPUP_LIST:
+		if(p->pulistbox != NULL)
+		{
+		    gchar *v;
+		    pulistbox_struct *pulistbox = p->pulistbox;
+		    pulist_struct *pulist = PUListBoxGetPUList(pulistbox);
+		    PUListGetItemText(
+			pulist,
+			PUListGetSelectedLast(pulist),
+			&v
+		    );
+		    return(v);
+		}
+		break;
+
 	      case PDIALOG_PROMPT_TYPE_COMBO:
 		if(GTK_IS_COMBO(w))
 		{
@@ -2046,6 +2295,84 @@ gchar *PDialogGetPromptValue(gint prompt_num)
 	return(NULL);
 }
 
+/*
+ *	Sets the prompt to accept the tab key to complete paths.
+ *
+ *	If prompt_num is -1 then the last prompt will be used.
+ */
+void PDialogSetPromptCompletePath(gint prompt_num)
+{
+	pdialog_prompt_struct *p;
+	pdialog_struct *d = &pdialog;
+
+	if(prompt_num < 0)
+	    prompt_num = d->total_prompts - 1;
+
+	p = ((prompt_num >= 0) && (prompt_num < d->total_prompts)) ?
+	    d->prompt[prompt_num] : NULL;
+
+	if(p != NULL)
+	{
+	    GtkWidget *w = p->value;
+
+	    switch(p->type)
+	    {
+	      case PDIALOG_PROMPT_TYPE_LABEL:
+		break;
+
+	      case PDIALOG_PROMPT_TYPE_ENTRY:
+		if(GTK_IS_ENTRY(w))
+		{
+		    gtk_signal_connect(
+			GTK_OBJECT(w), "key_press_event",
+			GTK_SIGNAL_FUNC(PDialogEntryCompletePathKeyCB), d
+		    );
+		    gtk_signal_connect(
+			GTK_OBJECT(w), "key_release_event",
+			GTK_SIGNAL_FUNC(PDialogEntryCompletePathKeyCB), d
+		    );
+		}
+		break;
+
+	      case PDIALOG_PROMPT_TYPE_SPIN:
+		break;
+
+	      case PDIALOG_PROMPT_TYPE_SCALE:
+		break;
+
+	      case PDIALOG_PROMPT_TYPE_POPUP_LIST:
+		break;
+
+	      case PDIALOG_PROMPT_TYPE_COMBO:
+		if(GTK_IS_COMBO(w))
+		{
+		    GtkCombo *combo = GTK_COMBO(w);
+		    w = combo->entry;
+		    if(GTK_IS_ENTRY(w))
+		    {
+			gtk_signal_connect(
+			    GTK_OBJECT(w), "key_press_event",
+			    GTK_SIGNAL_FUNC(PDialogEntryCompletePathKeyCB), d
+			);
+			gtk_signal_connect(
+			    GTK_OBJECT(w), "key_release_event",
+			    GTK_SIGNAL_FUNC(PDialogEntryCompletePathKeyCB), d
+			);
+		    }
+		}
+		break;
+
+	      case PDIALOG_PROMPT_TYPE_RADIO:
+		break;
+
+	      case PDIALOG_PROMPT_TYPE_TOGGLE:
+		break;
+
+	      case PDIALOG_PROMPT_TYPE_SEPARATOR:
+		break;
+	    }
+	}
+}
 
 /*
  *	Destroys all prompts on prompt dialog.
@@ -2055,7 +2382,6 @@ void PDialogDeleteAllPrompts(void)
 	gint i;
 	pdialog_struct *d = &pdialog;
 
-
 	for(i = 0; i < d->total_prompts; i++)
 	    PDialogPromptDelete(d->prompt[i]);
 	g_free(d->prompt);
@@ -2161,12 +2487,12 @@ gchar **PDialogGetResponse(
 { if(w != NULL) gtk_widget_hide(w); }
 #define DO_DEFAULT_BUTTON	\
 { if(w != NULL) {		\
-/*  gtk_widget_grab_focus(w);	\
+/*gtk_widget_grab_focus(w);	\
   gtk_widget_grab_default(w); */\
 } }
 #define DO_UNDEFAULT_BUTTON	\
 { if(w != NULL) {		\
-/*  GTK_WIDGET_UNSET_FLAGS(w, GTK_HAS_DEFAULT); \
+/*GTK_WIDGET_UNSET_FLAGS(w, GTK_HAS_DEFAULT); \
   GTK_WIDGET_UNSET_FLAGS(w, GTK_RECEIVES_DEFAULT); */ \
 } }
 
@@ -2280,7 +2606,7 @@ gchar **PDialogGetResponseIconData(
 	const gchar *title,
 	const gchar *message,
 	const gchar *explaination,
-	guint8 **icon_data,       
+	guint8 **icon_data,
 	const gchar *submit_label,
 	const gchar *cancel_label,
 	pdialog_btn_flags show_buttons,		/* Any of PDIALOG_BTNFLAG_* */
@@ -2360,12 +2686,12 @@ gchar **PDialogGetResponseIconData(
 { if(w != NULL) gtk_widget_hide(w); }
 #define DO_DEFAULT_BUTTON       \
 { if(w != NULL) {               \
-/*  gtk_widget_grab_focus(w);   \
+/*gtk_widget_grab_focus(w);	\
   gtk_widget_grab_default(w); */\
 } }
 #define DO_UNDEFAULT_BUTTON     \
 { if(w != NULL) {               \
-/*  GTK_WIDGET_UNSET_FLAGS(w, GTK_HAS_DEFAULT); \
+/*GTK_WIDGET_UNSET_FLAGS(w, GTK_HAS_DEFAULT); \
   GTK_WIDGET_UNSET_FLAGS(w, GTK_RECEIVES_DEFAULT); */ \
 } }
 
@@ -2430,7 +2756,7 @@ gchar **PDialogGetResponseIconData(
 	PDialogUnmap();
 
 	/* Break out of any subsequent main loops */
-	while(d->block_loop_level > 0)              
+	while(d->block_loop_level > 0)
 	{
 	    gtk_main_quit();
 	    d->block_loop_level--;
@@ -2441,7 +2767,7 @@ gchar **PDialogGetResponseIconData(
 	if(nvalues != NULL)
 	    *nvalues = d->response_nvals;
 					 
-	return(d->response_val);         
+	return(d->response_val);
 }
 
 
@@ -2507,25 +2833,15 @@ void PDialogShutdown(void)
 	}
 	d->block_loop_level = 0;
 
-	/* Unmap dialog */
+	/* Unmap the dialog */
 	PDialogUnmap();
 
-	/* Delete all prompts on dialog */
+	/* Delete all the prompts on the dialog */
 	PDialogDeleteAllPrompts();
 
-	/* Begin destroying widgets */
-	GTK_WIDGET_DESTROY(d->submit_btn)
-	GTK_WIDGET_DESTROY(d->cancel_btn)
-	GTK_WIDGET_DESTROY(d->help_btn)
-
-	GTK_WIDGET_DESTROY(d->icon_pm)
-	GTK_WIDGET_DESTROY(d->message_label)
-	GTK_WIDGET_DESTROY(d->message_label_hbox)
-
-	GTK_WIDGET_DESTROY(d->main_vbox)
-	GTK_WIDGET_DESTROY(d->toplevel)
-
-	GTK_ACCEL_GROUP_UNREF(d->accelgrp)
+	/* Delete the dialog */
+	gtk_widget_destroy(d->toplevel);
+	gtk_accel_group_unref(d->accelgrp);
 
 	memset(d, 0x00, sizeof(pdialog_struct));
 }
