@@ -206,15 +206,15 @@ if((font_name != NULL) && (style_ptr != NULL)) {	\
 	for(i = 0; i < core_ptr->total_editors; i++)
 	{
 	    editor = core_ptr->editor[i];
-	    if((editor == NULL) ? TRUE : !editor->initialized)
+	    if(editor == NULL)
 		continue;
 
-	    if(editor->processing)
+	    if(editor->freeze_count > 0)
 		continue;
 
 	    /* Text widget colors */
 	    w = editor->section_text;
-	    if((w == NULL) ? 0 : !GTK_WIDGET_NO_WINDOW(w))
+	    if(w != NULL)
 	    {
 		GtkStyle *cur_style = gtk_widget_get_style(w);
 
@@ -285,15 +285,15 @@ if((font_name != NULL) && (style_ptr != NULL)) {	\
 	for(i = 0; i < core_ptr->total_viewers; i++)
 	{
 	    viewer = core_ptr->viewer[i];
-	    if((viewer == NULL) ? TRUE : !viewer->initialized)
+	    if(viewer == NULL)
 		continue;
 
-	    if(viewer->processing)
+	    if((viewer->freeze_count > 0) || viewer->processing)
 		continue;
 
 	    /* Text widget colors */
 	    w = viewer->view_text;
-	    if((w != NULL) ? !GTK_WIDGET_NO_WINDOW(w) : FALSE)
+	    if(w != NULL)
 	    {
 		GtkStyle *cur_style = gtk_widget_get_style(w);  
 
@@ -395,10 +395,10 @@ void PrefDoFetch(pref_struct *pref)
 	for(i = 0; i < core_ptr->total_editors; i++)
 	{
 	    editor = core_ptr->editor[i];
-	    if((editor == NULL) ? TRUE : !editor->initialized)
+	    if(editor == NULL)
 		continue;
    
-	    if(editor->processing)
+	    if(editor->freeze_count > 0)
 		continue;
 
 	    /* Syntax highlighting */
