@@ -1,5 +1,5 @@
 /*
-                              Manual Page Viewer
+			      Manual Page Viewer
 
 	Displays parsed groff output for finished apperance of manual
 	pages.
@@ -10,10 +10,14 @@
 #define VIEWER_H
 
 #include <gtk/gtk.h>
+#include "pulist.h"
+#include "medit_types.h"
 
 
 typedef struct _viewer_struct			viewer_struct;
+#define VIEWER(p)				((viewer_struct *)(p))
 typedef struct _viewer_index_item_struct	viewer_index_item_struct;
+#define VIEWER_INDEX_ITEM(p)			((viewer_index_item_struct *)(p))
 
 
 /*
@@ -35,7 +39,6 @@ struct _viewer_index_item_struct {
 	gchar		*full_path;
 
 };
-#define VIEWER_INDEX_ITEM(p)	((viewer_index_item_struct *)(p))
 
 
 /*
@@ -43,18 +46,19 @@ struct _viewer_index_item_struct {
  */
 struct _viewer_struct {
 
-	gboolean	initialized,
-			map_state,
-			processing;
-	gint		stop_count;
+	GtkWidget	*toplevel;
+	gint		freeze_count,
+			busy_count,
+			stop_count;
+	gboolean	processing;
+
+	medit_core_struct *core;
 
-	gpointer	core_ptr;	/* Pointer back to core */
 	gint		editor_num;	/* Editor number on core struct that
 					 * called this viewer, can be -1 for
 					 * none */
 
-	GtkWidget	*toplevel,
-			*main_vbox,
+	GtkWidget	*main_vbox,
 			*menu_bar_dock,
 			*menu_bar,
 			*tool_bar_dock,
@@ -87,8 +91,8 @@ struct _viewer_struct {
 			*index_find_in_pages_combo;
 
 	/* Combos on manpage view panel */
+	pulistbox_struct	*section_pulistbox;
 	GtkWidget	*manpage_combo,
-			*section_combo,
 			*find_combo;
 
 	/* Important menu items */
@@ -99,7 +103,10 @@ struct _viewer_struct {
 			*exit_mi,
 
 			*edit_mh,
-			*edit_preferences,
+			*edit_copy_mi,
+			*edit_select_all_mi,
+			*edit_unselect_all_mi,
+			*edit_preferences_mi,
 
 			*view_mh,
 			*view_view_mi,
@@ -117,8 +124,9 @@ struct _viewer_struct {
 
 	/* Right click menu over view_text */
 	GtkWidget	*view_menu,
-			*view_open_mi,
-			*view_clear_mi;
+			*view_copy_mi,
+			*view_select_all_mi,
+			*view_unselect_all_mi;
 
 	/* Right click menu over index_ctree */
 	GtkWidget	*index_menu,
@@ -128,12 +136,12 @@ struct _viewer_struct {
 			*index_refresh_mi,
 			*index_stop_mi;
 
-        /* Status bar */
-        GtkWidget       *status_bar_dock,
-                        *status_bar_toplevel,   /* An hbox */
-                        *status_bar_progress,
-                        *status_bar_label,
-                        *status_bar_cursor_label;
+	/* Status bar */
+	GtkWidget       *status_bar_dock,
+			*status_bar_toplevel,   /* An hbox */
+			*status_bar_progress,
+			*status_bar_label,
+			*status_bar_cursor_label;
 
 	/* Last progress position value from 0.0 to 1.0 */
 	gfloat		status_bar_progress_pos_last;
@@ -155,7 +163,6 @@ struct _viewer_struct {
 	gchar		*last_open_path;
 
 };
-#define VIEWER(p)	((viewer_struct *)(p))
 
 
 extern viewer_index_item_struct *ViewerIndexItemNew(
@@ -163,27 +170,28 @@ extern viewer_index_item_struct *ViewerIndexItemNew(
 );
 extern void ViewerIndexItemDelete(viewer_index_item_struct *item);
 extern void ViewerBranchSelect(
-        viewer_struct *v, GtkCTreeNode *branch
+	viewer_struct *v, GtkCTreeNode *branch
 );
 
 extern void ViewerTextInsertPosition(viewer_struct *v, gint start_pos);
 extern void ViewerTextInsert(
-	viewer_struct *v, const gchar *buf, gint buf_len,
-	gpointer client_data, gint (*func_cb)(glong, glong, gpointer)
+	viewer_struct *v, const gchar *buf, const gint buf_len,
+	gint (*progress_cb)(const gulong, const gulong, gpointer),
+	gpointer progress_data
 );
 extern void ViewerTextDelete(viewer_struct *v, gint start_pos, gint end_pos); 
 extern void ViewerIndexDoLoad(
-        viewer_struct *v,
+	viewer_struct *v,
 	gint total_paths, char **path, gchar **name
 );
 
 extern gboolean ViewerDoFind(
-        viewer_struct *v, GtkText *text,
-        gchar *haystack, gchar *needle,
-        gint haystack_len, gint start_pos,
-        gboolean case_sensitive,
-        gboolean move_to,
-        gboolean *search_wrapped
+	viewer_struct *v, GtkText *text,
+	gchar *haystack, gchar *needle,
+	gint haystack_len, gint start_pos,
+	gboolean case_sensitive,
+	gboolean move_to,
+	gboolean *search_wrapped
 );
 
 extern void ViewerViewTextRecordScrollPositions(viewer_struct *v);
@@ -197,7 +205,7 @@ extern void ViewerSetStatusPosition(viewer_struct *v, gint row, gint column);
 extern void ViewerSetStatusMessage(viewer_struct *v, const gchar *mesg);
 extern void ViewerSetStatusProgress(viewer_struct *v, gfloat percent);
 extern void ViewerRecordPositions(viewer_struct *v);
-extern void ViewerReset(viewer_struct *v, gboolean need_unmap);
+extern void ViewerReset(viewer_struct *v, const gboolean unmap);
 extern void ViewerMap(viewer_struct *v);
 extern void ViewerUnmap(viewer_struct *v);
 extern void ViewerDelete(viewer_struct *v);
