@@ -23,7 +23,6 @@
 
 void ViewerIndexBranchDestroyCB(gpointer data);
 
-void ViewerDestroyCB(GtkObject *object, gpointer data);
 gint ViewerCloseCB(GtkWidget *widget, GdkEvent *event, gpointer data);
 void ViewerCloseMCB(GtkWidget *widget, gpointer data);
 void ViewerCloseAllCB(GtkWidget *widget, gpointer data);
@@ -38,6 +37,9 @@ gint ViewerPageChangedTOCB(gpointer data);
 gint ViewerViewKeyEventCB(
 	GtkWidget *widget, GdkEventKey *key, gpointer data
 );
+gint ViewerViewButtonEventCB(
+	GtkWidget *widget, GdkEventButton *button, gpointer data
+);
 
 void ViewerIndexBranchExpandCB(GtkWidget *widget, gpointer data);
 
@@ -47,15 +49,20 @@ void ViewerStopCB(GtkWidget *widget, gpointer data);
 void ViewerIndexGotoParentCB(GtkWidget *widget, gpointer data);
 void ViewerGotoCB(GtkWidget *widget, gpointer data);
 void ViewerIndexRefreshCB(GtkWidget *widget, gpointer data);
+void ViewerCopyCB(GtkWidget *widget, gpointer data);
+void ViewerSelectAllCB(GtkWidget *widget, gpointer data);
+void ViewerUnselectAllCB(GtkWidget *widget, gpointer data);
 void ViewerPreferencesCB(GtkWidget *widget, gpointer data);
 
 gint ViewerMenuMapCB(GtkWidget *widget, GdkEvent *event, gpointer data);
 
-void ViewerManPageActivateCB(GtkWidget *widget, void *data);
-static void ViewerDoFindCB(
-	viewer_struct *v, GtkCombo *find_combo, gboolean case_sensitive
+void ViewerManPageActivateCB(GtkWidget *widget, gpointer data);
+static void ViewerFind(
+	viewer_struct *v,
+	GtkCombo *find_combo,
+	const gboolean case_sensitive
 );
-void ViewerFindActivateCB(GtkWidget *widget, void *data);
+void ViewerFindActivateCB(GtkWidget *widget, gpointer data);
 
 static gboolean ViewerFindInPagesDoGrep(
 	const gchar *path, gchar *expression, gboolean case_sensitive
@@ -63,7 +70,7 @@ static gboolean ViewerFindInPagesDoGrep(
 static void ViewerDoFindInPagesCB(
 	viewer_struct *v, GtkCombo *find_combo, gboolean case_sensitive
 );
-void ViewerFindInPagesActivateCB(GtkWidget *widget, void *data);
+void ViewerFindInPagesActivateCB(GtkWidget *widget, gpointer data);
 
 void ViewerIndexCTreeSelectCB(
 	GtkCTree *ctree, GtkCTreeNode *branch, gint column, gpointer data
@@ -105,47 +112,28 @@ void ViewerIndexBranchDestroyCB(gpointer data)
 	ViewerIndexItemDelete(item);
 }
 
-/*
- *      Destroy callback.
- */
-void ViewerDestroyCB(GtkObject *object, gpointer data)
-{
-
-}
-
 /*
  *      Close callback.
  */
 gint ViewerCloseCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
-	static gboolean reenterant = FALSE;
 	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return(TRUE);
 
-	if(!v->initialized)
+	if(v->freeze_count > 0)
 	    return(TRUE);
 
-	if(reenterant)
-	    return(TRUE);
-	else
-	    reenterant = TRUE;
+	v->freeze_count++;
 
-	/* Check if currently processing */
-	if(v->processing)
-	{
-	    reenterant = FALSE;
-	    return(TRUE);
-	}
-
-
-	/* Revord viewer positions and sizes */
+	/* Revord the viewer's positionss and sizes */
 	ViewerRecordPositions(v);
 
-	/* Reset and unmap viewer */
+	v->freeze_count--;
+
+	/* Reset and unmap the viewer */
 	ViewerReset(v, TRUE);
 
-	reenterant = FALSE;
 	return(TRUE);
 }
 
@@ -182,26 +170,19 @@ void ViewerSwitchPageCB(
 	gpointer data
 )
 {
-	static gboolean reenterant = FALSE;
 	GtkWidget *w;
 	viewer_struct *v = VIEWER(data);
 	if((notebook == NULL) || (v == NULL))
 	    return;
 
-	if(!v->initialized)
+	if(v->freeze_count > 0)
 	    return;
 
-	if(v->processing)
-	    return;
-
-	if(reenterant)
-	    return;
-	else
-	    reenterant = TRUE;
+	v->freeze_count++;
 
 	/* Main notebook? */
 	w = v->main_notebook;
-	if((void *)w == (void *)notebook)
+	if(w == GTK_WIDGET(notebook))
 	{
 	    v->current_page = page_num;
 	    ViewerUpdateMenus(v);
@@ -213,7 +194,7 @@ void ViewerSwitchPageCB(
 	 */
 	gtk_idle_add(ViewerPageChangedTOCB, v);
 
-	reenterant = FALSE;
+	v->freeze_count--;
 }
 
 /*
@@ -221,22 +202,15 @@ void ViewerSwitchPageCB(
  */
 void ViewerPageToggleCB(GtkWidget *widget, gpointer data)
 {
-	static gboolean reenterant = FALSE;
 	GtkWidget *w;
 	viewer_struct *v = VIEWER(data);
 	if((widget == NULL) || (v == NULL))
 	    return;
 
-	if(!v->initialized)
+	if(v->freeze_count > 0)
 	    return;
 
-	if(v->processing)
-	    return;
-
-	if(reenterant)
-	    return;
-	else
-	    reenterant = TRUE;
+	v->freeze_count++;
 
 	if(widget == v->view_view_mi)
 	{
@@ -255,8 +229,7 @@ void ViewerPageToggleCB(GtkWidget *widget, gpointer data)
 		);
 	}
 
-	reenterant = FALSE;
-	return;
+	v->freeze_count--;
 }
 
 /*
@@ -271,10 +244,7 @@ gint ViewerPageChangedTOCB(gpointer data)
 	if(v == NULL)
 	    return(FALSE);
 
-	if(!v->initialized)
-	    return(FALSE);
-
-	if(v->processing)
+	if(v->freeze_count > 0)
 	    return(FALSE);
 
 	switch(v->current_page)
@@ -283,10 +253,8 @@ gint ViewerPageChangedTOCB(gpointer data)
 	    break;
 
 	  case ViewerPageNumIndex:
-	    ctree = (GtkCTree *)v->index_ctree;
-	    if((ctree != NULL) ?
-		(gtk_ctree_node_nth(ctree, 0) == NULL) : FALSE
-	    )
+	    ctree = GTK_CTREE(v->index_ctree);
+	    if(gtk_ctree_node_nth(ctree, 0) == NULL)
 	    {
 		ViewerIndexRefreshCB(v->index_refresh_btn, data);
 	    }
@@ -298,25 +266,26 @@ gint ViewerPageChangedTOCB(gpointer data)
 
 
 /*
- *	Viewer view text keyboard event handler.
+ *	View GtkText "key_press_event" or "key_release_event" signal
+ *	callback.
  */
 gint ViewerViewKeyEventCB(
 	GtkWidget *widget, GdkEventKey *key, gpointer data   
 )
 {
+	gint status = FALSE;
 	GtkWidget *w;
 	GtkText *text;
 	GtkAdjustment *hadj, *vadj;
 	gboolean state;
 	guint keyval;
 	viewer_struct *v = VIEWER(data);
-	if((widget == NULL) || (v == NULL) || (key == NULL))
-	    return(FALSE);
+	if((widget == NULL) || (key == NULL) || (v == NULL))
+	    return(status);
 
-	/* Get pointer to view_text widget, event widget must be it */
 	w = v->view_text;
 	if(w != widget)
-	    return(FALSE);
+	    return(status);
 
 	text = GTK_TEXT(w);
 	hadj = text->hadj;
@@ -391,13 +360,151 @@ gint ViewerViewKeyEventCB(
 	    }
 	}
 
-/*
-printf("View text key event %i %i\n", keyval, state);
- */
+	status = TRUE;
 
-	return(TRUE);
+	return(status);
 }
 
+/*
+ *	View GtkText "button_press_event" or "button_release_event"
+ *	signal callback.
+ */
+gint ViewerViewButtonEventCB(
+	GtkWidget *widget, GdkEventButton *button, gpointer data
+)
+{
+	gint status = FALSE;
+	GtkText *text;
+	viewer_struct *v = VIEWER(data);
+	if((widget == NULL) || (button == NULL) || (v == NULL))
+	    return(status);
+
+	if(!GTK_IS_TEXT(widget))
+	    return(status);
+
+	text = GTK_TEXT(widget);
+
+	switch((gint)button->type)
+	{
+	  case GDK_BUTTON_PRESS:
+	    switch(button->button)
+	    {
+	      case GDK_BUTTON3:		/* Popup menu */
+		/* Map the popup menu */
+		gtk_menu_popup(
+		    GTK_MENU(v->view_menu),
+		    NULL, NULL, NULL, v,
+		    button->button, button->time
+		);
+		/* Need to mark the text widget's button as 0 or
+		 * else it will keep marking.
+		 */
+		text->button = 0;
+		gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_press_event"
+		);
+		status = TRUE;
+		break;
+
+	      case GDK_BUTTON4:		/* Scroll up */
+		if(text->vadj != NULL)
+		{
+		    GtkAdjustment *adj = text->vadj;
+		    const gfloat inc = MAX(
+			(0.25f * adj->page_size),
+			adj->step_increment
+		    );
+		    gfloat v = adj->value - inc;  
+		    if(v > (adj->upper - adj->page_size))
+			v = adj->upper - adj->page_size;
+		    if(v < adj->lower)
+			v = adj->lower;
+		    gtk_adjustment_set_value(adj, v);
+		}
+		/* Need to mark the GtkText button as 0 or else it will
+		 * keep marking
+		 */
+		text->button = 0;
+		gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_press_event"
+		);
+		status = TRUE;
+		break;
+
+	      case GDK_BUTTON5:		/* Scroll down */
+		if(text->vadj != NULL)
+		{
+		    GtkAdjustment *adj = text->vadj;
+		    const gfloat inc = MAX(
+			(0.25f * adj->page_size),
+			adj->step_increment
+		    );
+		    gfloat v = adj->value + inc;
+		    if(v > (adj->upper - adj->page_size))
+			v = adj->upper - adj->page_size;
+		    if(v < adj->lower)
+			v = adj->lower;
+		    gtk_adjustment_set_value(adj, v);
+		}
+		/* Need to mark the GtkText button as 0 or else it will
+		 * keep marking
+		 */
+		text->button = 0;
+		gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_press_event"
+		);
+		status = TRUE;
+		break;
+	    }
+	    break;
+
+	  case GDK_BUTTON_RELEASE:
+	    switch(button->button)
+	    {
+	      case GDK_BUTTON3:		/* Popup menu */
+		/* Need to mark the GtkText button as 0 or else it will
+		 * keep marking
+		 */
+		text->button = 0;
+		gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_release_event"
+		);
+		status = TRUE;
+		break;
+
+	      case GDK_BUTTON4:		/* Scroll up */
+		/* Need to mark the GtkText button as 0 or else it will
+		 * keep marking
+		 */
+		text->button = 0;
+		gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_release_event"
+		);
+		status = TRUE;
+		break;
+
+	      case GDK_BUTTON5:		/* Scroll down */
+		/* Need to mark the GtkText button as 0 or else it will
+		 * keep marking
+		 */
+		text->button = 0;
+		gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_release_event"
+		);
+		status = TRUE;
+		break;
+	    }
+	    break;
+	}
+
+	return(status);
+}
 
 
 /*
@@ -413,13 +520,7 @@ void ViewerIndexBranchExpandCB(GtkWidget *widget, gpointer data)
 	if(v == NULL)
 	    return;
 
-	if(!v->initialized)
-	    return;
-
-	ctree = (GtkCTree *)v->index_ctree;
-	if(ctree == NULL)
-	    return;
-
+	ctree = GTK_CTREE(v->index_ctree);
 	branch = v->selected_index_branch;
 	if(branch == NULL)
 	    return;
@@ -445,109 +546,115 @@ void ViewerIndexBranchExpandCB(GtkWidget *widget, gpointer data)
  */
 void ViewerOpenCB(GtkWidget *widget, gpointer data)
 {
-	gint status;
 	GtkWidget *toplevel;
 	GtkText *text;
-	medit_core_struct *core_ptr;
-	medit_fetype_list_struct *fetype_list;
+	medit_core_struct *core;
 	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
-	if(!v->initialized)
+	if(v->freeze_count > 0)
 	    return;
 
-	/* Check if currently processing */
-	if(v->processing)
-	    return;
+	v->freeze_count++;
 
 	toplevel = v->toplevel;
-	text = (GtkText *)v->view_text;
-	core_ptr = (medit_core_struct *)v->core_ptr;
-	if((text == NULL) || (core_ptr == NULL))
-	    return;
-
-	fetype_list = &core_ptr->fetype_list;
+	text = GTK_TEXT(v->view_text);
+	core = v->core;
 
 	if(TRUE)
 	{
-	    gchar *s, **path_rtn;
-	    gint path_total_rtns;
-	    fb_type_struct *type_rtn;
+	    gboolean response;
+	    gchar **paths_list;
+	    gint nftypes = 0, npaths;
+	    fb_type_struct **ftypes_list = NULL, *type_rtn;
 
-	    /* Map file browser for opening of manual page output */
-	    if(FileBrowserGetResponse(
-		"Open Manual Page File",
+	    /* Query the user for a manual page */
+            FileBrowserTypeListNew(
+                &ftypes_list, &nftypes,
+                ".1 .2 .3 .4 .5 .6 .bz2 .gz",
+                "Manual page"
+            );
+            FileBrowserTypeListNew(
+                &ftypes_list, &nftypes,
+                ".mpt",
+                "Manual page template"
+            );
+            FileBrowserTypeListNew(
+                &ftypes_list, &nftypes,
+                "*.*", "All files"
+	    );
+
+	    FileBrowserSetTransientFor(toplevel);
+	    response = FileBrowserGetResponse(
+		"Open Manual Page",
 		"Open", "Cancel",
 		v->last_open_path,
-		fetype_list->manual_page,
-		fetype_list->total_manual_pages,
-		&path_rtn, &path_total_rtns, &type_rtn
-	    ))
+		ftypes_list, nftypes,
+		&paths_list, &npaths, &type_rtn
+	    );
+	    FileBrowserSetTransientFor(NULL);
+	    FileBrowserDeleteTypeList(ftypes_list, nftypes);
+
+	    if(response && (npaths > 0))
 	    {
-		if(path_total_rtns > 0)
-		{
-		    ViewerSetBusy(v);
+		gint status;
+		gchar *msg;
+		const gchar *path = paths_list[0];
+
+		ViewerSetBusy(v);
 /* Reset scroll positions when user is calling open callback */
-		    v->last_scroll_hpos = 0.0;
-		    v->last_scroll_vpos = 0.0;
-/*		    ViewerViewTextRecordScrollPositions(v); */
-		    ViewerTextDelete(v, 0, -1);
-		    ViewerTextInsertPosition(v, 0);
-		    status = ViewerOpenFile(v, path_rtn[0], path_rtn[0]);
-		    ViewerSetReady(v);
+		v->last_scroll_hpos = 0.0f;
+		v->last_scroll_vpos = 0.0f;
+/*		ViewerViewTextRecordScrollPositions(v); */
+		ViewerTextDelete(v, 0, -1);
+		ViewerTextInsertPosition(v, 0);
+		status = ViewerOpenFile(v, path, path);
+		ViewerSetReady(v);
 
-		    switch(status)
-		    {
-		      case 0:
-			/* Success */
-			break;
+		switch(status)
+		{
+		  case 0:		/* Success */
+		    break;
 
-		      /* No such file */
-		      case -2:
-			s = g_strdup_printf(
-"Could not find the manual page file:\n\n    %s",
-			    path_rtn[0]
-			);
-			CDialogSetTransientFor(toplevel);
-			CDialogGetResponse(
-			    "Manual page not found!",
-			    s,
+		  case -2:		/* No such file */
+		    msg = g_strdup_printf(
+"Unable to find the manual page file:\n\n    %s",
+			path
+		    );
+		    CDialogSetTransientFor(toplevel);
+		    CDialogGetResponse(
+			"Open Manual Page Failed",
+			msg,
 "The specified manual page file could not be found\n\
 please verify that the given path exists and has\n\
 read permissions set.",
-			    CDIALOG_ICON_WARNING,
-			    CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
-			    CDIALOG_BTNFLAG_OK
-			);
-			CDialogSetTransientFor(NULL);
-			g_free(s);
-			break;   
+			CDIALOG_ICON_WARNING,
+			CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
+			CDIALOG_BTNFLAG_OK
+		    );
+		    CDialogSetTransientFor(NULL);
+		    g_free(msg);
+		    break;   
 		       
-		      /* Other error */
-		      default:
-			CDialogSetTransientFor(toplevel);
-			CDialogGetResponse(
-"Manual page opening error!",
+		  default:		/* Other error */
+		    CDialogSetTransientFor(toplevel);
+		    CDialogGetResponse(
+			"Open Manual Page Failed",
 "Error occured while opening manual page.",
-			    NULL,
-			    CDIALOG_ICON_ERROR,
-			    CDIALOG_BTNFLAG_OK,
-			    CDIALOG_BTNFLAG_OK
-			);
-			CDialogSetTransientFor(NULL);
-			break;
-		    }
-		}
-		else
-		{
-		    /* Did not get any paths, abort open */
-		    return;
+			NULL,
+			CDIALOG_ICON_ERROR,
+			CDIALOG_BTNFLAG_OK,
+			CDIALOG_BTNFLAG_OK
+		    );
+		    CDialogSetTransientFor(NULL);
+		    break;
 		}
 	    }
 	    else
 	    {
 		/* User canceled save as, abort entire open procedure */
+		v->freeze_count--;
 		return;
 	    }
 	}
@@ -556,6 +663,8 @@ read permissions set.",
 	 * menus already but it is safe to do it again here
 	 */
 	ViewerUpdateMenus(v);
+
+	v->freeze_count--;
 }
 
 
@@ -571,13 +680,12 @@ void ViewerClearCB(GtkWidget *widget, gpointer data)
 	if(v == NULL)
 	    return;
 
-	if(!v->initialized)
-	    return;
-
-	if(v->processing)
+	if(v->freeze_count > 0)
 	    return;
 
+	v->freeze_count++;
 	ViewerSetBusy(v);
+
 	ViewerSetStatusMessage(v, "Clearing contents...");
 
 	switch(v->current_page)
@@ -588,7 +696,7 @@ void ViewerClearCB(GtkWidget *widget, gpointer data)
 	    break;
 
 	  case ViewerPageNumIndex:
-	    ctree = (GtkCTree *)v->index_ctree;
+	    ctree = GTK_CTREE(v->index_ctree);
 
 	    /* Remove all branches on index ctree */
 	    gtk_clist_freeze((GtkCList *)ctree);
@@ -613,9 +721,9 @@ void ViewerClearCB(GtkWidget *widget, gpointer data)
 	    break;
 	}
 	ViewerSetStatusMessage(v, "Clear done");
-	ViewerSetReady(v);
 
-	return;
+	v->freeze_count--;
+	ViewerSetReady(v);
 }
 
 /*
@@ -646,17 +754,12 @@ void ViewerIndexGotoParentCB(GtkWidget *widget, gpointer data)
 	if(v == NULL)
 	    return;
 
-	if(!v->initialized)
+	if(v->freeze_count > 0)
 	    return;
 
-	if(v->processing)
-	    return;
+	ctree = GTK_CTREE(v->index_ctree);
 
-	ctree = (GtkCTree *)v->index_ctree;
-	if(ctree == NULL)
-	    return;
-
-	/* Get selected branch */
+	/* Get the selected branch */
 	branch = v->selected_index_branch;
 	if(branch == NULL)
 	    return;
@@ -665,11 +768,7 @@ void ViewerIndexGotoParentCB(GtkWidget *widget, gpointer data)
 
 	branch = branch_row->parent;
 	if(branch != NULL)
-	{
 	    gtk_ctree_select(ctree, branch);
-	}
-
-	return;
 }
 
 /*
@@ -684,26 +783,29 @@ void ViewerGotoCB(GtkWidget *widget, gpointer data)
 	if(v == NULL)
 	    return;
 
-	if(!v->initialized)
+	if(v->freeze_count > 0)
 	    return;
 
-	if(v->processing)
-	    return;
+	v->freeze_count++;
 
-	ctree = (GtkCTree *)v->index_ctree;
-	if(ctree == NULL)
-	    return;
+	ctree = GTK_CTREE(v->index_ctree);
 
-	/* Get selected branch */
+	/* Get the selected branch */
 	branch = v->selected_index_branch;
 	if(branch == NULL)
+	{
+	    v->freeze_count--;
 	    return;
+	}
 
 	item = VIEWER_INDEX_ITEM(
 	    gtk_ctree_node_get_row_data(ctree, branch)
 	);
 	if(item == NULL)
+	{
+	    v->freeze_count--;
 	    return;
+	}
 
 	if(item->type == ViewerIndexItemTypeManualPage)
 	{
@@ -719,51 +821,46 @@ void ViewerGotoCB(GtkWidget *widget, gpointer data)
 		ViewerSetReady(v);
 	    }
 	}
+
+	v->freeze_count--;
 }
 
 
 /*
- *      Index refresh callback.
+ *	Index Refresh.
  */
 void ViewerIndexRefreshCB(GtkWidget *widget, gpointer data)
 {
 	gint i;
-	gchar **path = NULL;
-	gchar **name = NULL;
+	gchar	**path = NULL,
+		**name = NULL;
 	gint total_paths = 0;
 	GtkCTree *ctree;
 	GtkWidget *w;
 	GtkCTreeNode *branch, *prev_branch;
 	GtkCTreeRow *branch_row;
-	medit_core_struct *core_ptr;
+	medit_core_struct *core;
 	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
-	if(!v->initialized)
+	if(v->freeze_count > 0)
 	    return;
 
-	if(v->processing)
-	    return;
+	v->freeze_count++;
 
-	core_ptr = (medit_core_struct *)v->core_ptr;
-	if(core_ptr == NULL)
-	    return;
-
-	/* Get pointer to viewer's index ctree */
-	ctree = (GtkCTree *)v->index_ctree;
-	if(ctree == NULL)
-	    return;
+	ctree = GTK_CTREE(v->index_ctree);
+	core = v->core;
 
 	/* Get pointer to pref global manpage dirs clist */
 	w = PrefParmGetWidget(
-	    core_ptr->pref,
+	    core->pref,
 	    MEDIT_PREF_PARM_LOCATIONS_MAN_DIRS
 	);
 	if(w != NULL)
 	{
 	    /* Make list of paths and names to load */
-	    GtkCList *paths_clist = (GtkCList *)w;
+	    GtkCList *paths_clist = GTK_CLIST(w);
 
 	    total_paths = paths_clist->rows;
 	    if(total_paths > 0)
@@ -800,21 +897,21 @@ void ViewerIndexRefreshCB(GtkWidget *widget, gpointer data)
 	}
 
 	/* Remove all existing branches on index ctree */
-	gtk_clist_freeze((GtkCList *)ctree);
+	gtk_clist_freeze(GTK_CLIST(ctree));
 	branch = gtk_ctree_node_nth(ctree, 0);
 	while(branch != NULL)
 	{
 	    prev_branch = branch;	/* Record current branch */
 
-	    /* Get branch row data */
+	    /* Get the next sibling branch */
 	    branch_row = GTK_CTREE_ROW(branch);
-	    /* Get next sibling branch */
-	    branch = ((branch_row == NULL) ? NULL : branch_row->sibling);
+	    branch = (branch_row != NULL) ?
+		branch_row->sibling : NULL;
 
-	    /* Remove current branch */
+	    /* Remove the current branch */
 	    gtk_ctree_remove_node(ctree, prev_branch);
 	}
-	gtk_clist_thaw((GtkCList *)ctree);
+	gtk_clist_thaw(GTK_CLIST(ctree));
 
 	/* Load new objects from paths */
 	ViewerIndexDoLoad(
@@ -824,26 +921,87 @@ void ViewerIndexRefreshCB(GtkWidget *widget, gpointer data)
 	/* Delete paths and names array */
 	strlistfree(path, total_paths);
 	strlistfree(name, total_paths);
+
+	v->freeze_count--;
 }  
 
+
 /*
- *      Index refresh callback.
+ *	Copy.
  */
-void ViewerPreferencesCB(GtkWidget *widget, gpointer data)
+void ViewerCopyCB(GtkWidget *widget, gpointer data)
 {
-	medit_core_struct *core_ptr;
+	GtkEditable *editable;
+	GtkText *text;
 	viewer_struct *v = VIEWER(data);
 	if((widget == NULL) || (v == NULL))
 	    return;
 
-	core_ptr = (medit_core_struct *)v->core_ptr;
-	if(core_ptr != NULL)
+	text = GTK_TEXT(v->view_text);
+	editable = GTK_EDITABLE(text);
+	gtk_text_freeze(text);
+        gtk_editable_copy_clipboard(editable);
+	gtk_text_thaw(text);
+
+	ViewerUpdateMenus(v);
+	ViewerSetStatusMessage(v, "Selection coppied");
+}
+
+/*
+ *	Select All.
+ */
+void ViewerSelectAllCB(GtkWidget *widget, gpointer data)
+{
+	GtkEditable *editable;
+	GtkText *text;
+	viewer_struct *v = VIEWER(data);
+	if((widget == NULL) || (v == NULL))
+	    return;
+
+	text = GTK_TEXT(v->view_text);
+	editable = GTK_EDITABLE(text);
+	gtk_text_freeze(text);
+        gtk_editable_select_region(editable, 0, -1);
+	gtk_text_thaw(text);
+}
+
+/*
+ *	Unselect All.
+ */
+void ViewerUnselectAllCB(GtkWidget *widget, gpointer data)
+{
+	GtkEditable *editable;
+	GtkText *text;
+	viewer_struct *v = VIEWER(data);
+	if((widget == NULL) || (v == NULL))
+	    return;
+
+	text = GTK_TEXT(v->view_text);
+	editable = GTK_EDITABLE(text);
+	gtk_text_freeze(text);
+        gtk_editable_select_region(editable, -1, -1);
+	gtk_text_thaw(text);
+}
+
+
+/*
+ *	Preferences.
+ */
+void ViewerPreferencesCB(GtkWidget *widget, gpointer data)
+{
+	medit_core_struct *core;
+	viewer_struct *v = VIEWER(data);
+	if((widget == NULL) || (v == NULL))
+	    return;
+
+	core = v->core;
+	if(core != NULL)
 	{
 	    gchar *s;
 	    GtkCTreeNode *branch;
 	    GtkCTreeRow *branch_row;
 	    GtkCTree *ctree;
-	    pref_struct *pref = core_ptr->pref;
+	    pref_struct *pref = core->pref;
 
 	    ctree = (pref != NULL) ?
 		(GtkCTree *)pref->catagory_ctree : NULL;
@@ -904,25 +1062,7 @@ gint ViewerMenuMapCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 	/* View text? */
 	if(widget == v->view_text)
 	{
-	    w = v->view_menu;
-	    if((button != NULL) && (w != NULL))
-	    {
-		if(button->button == 3)
-		{
-		    /* Map menu */
-		    gtk_menu_popup(
-			GTK_MENU(w),
-			NULL, NULL, NULL, (gpointer)v,
-			button->button, button->time
-		    );
 
-		    /* Need to mark the text widget's button as 0 or
-		     * else it will keep marking.
-		     */
-		    GTK_TEXT(widget)->button = 0;
-		    gtk_grab_remove(widget);
-		}
-	    }
 	}
 	/* Index ctree */
 	else if (widget == v->index_ctree)
@@ -980,113 +1120,97 @@ gint ViewerMenuMapCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 /*
  *	Manpage combo activate callback.
  */
-void ViewerManPageActivateCB(GtkWidget *widget, void *data)
+void ViewerManPageActivateCB(GtkWidget *widget, gpointer data)
 {
-	static gboolean reenterant = FALSE;
-	gint section = -2;	/* Any */
+	gint section_num = -2;			/* Any */
 	gchar *s, *name, *search_string;
+	const gchar *section;
 	GtkWidget *toplevel;
 	GtkCombo *combo;
+	pulist_struct *pulist;
 	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
-	if(!v->initialized || v->processing)
+	if(v->freeze_count > 0)
 	    return;
 
-	if(reenterant)
-	    return;   
-	else
-	    reenterant = TRUE;
+	v->freeze_count++;
 
-	/* Get manpage combo */
 	toplevel = v->toplevel;
-	combo = (GtkCombo *)v->manpage_combo;
-	if(combo == NULL)
-	{
-	    reenterant = FALSE;
-	    return;
-	}
+	combo = GTK_COMBO(v->manpage_combo);
 
-	/* Get category if any */
-	if(v->section_combo != NULL)
+	/* Get the section */
+	pulist = PUListBoxGetPUList(v->section_pulistbox);
+	section = (const gchar *)PUListGetItemData(
+	    pulist,
+	    PUListGetSelectedLast(pulist)
+	);
+	if(section != NULL)
 	{
-	    GtkCombo *section_combo = (GtkCombo *)v->section_combo;
-	    const gchar *section_str = gtk_entry_get_text(
-		GTK_ENTRY(section_combo->entry)
-	    );
-	    if(section_str != NULL)
+	    if(isdigit(*section))
 	    {
-		while(ISBLANK(*section_str))
-		    section_str++;
-
-		if(isdigit(*section_str))
-		{
-		    section = atoi(section_str);
-		}
-		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_1))
-		{
-		    section = 1;
-		}
-		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_2))
-		{
-		    section = 2;
-		}
-		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_3))
-		{
-		    section = 3;
-		}
-		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_4))
-		{
-		    section = 4;
-		}
-		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_5))
-		{
-		    section = 5;
-		}
-		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_6))
-		{
-		    section = 6;
-		}
-		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_7))
-		{
-		    section = 7;
-		}
-		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_8))
-		{
-		    section = 8;
-		}
-		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_EXACT))
-		{
-		    section = -1;
-		}
-		else
-		{
-		    /* All else assume any (-2) */
-		}
+		section_num = ATOI(section);
+	    }
+	    else if(!g_strcasecmp(section, MEDIT_SECT_NAME_1))
+	    {
+		section_num = 1;
+	    }
+	    else if(!g_strcasecmp(section, MEDIT_SECT_NAME_2))
+	    {
+		section_num = 2;
+	    }
+	    else if(!g_strcasecmp(section, MEDIT_SECT_NAME_3))
+	    {
+	        section_num = 3;
+	    }
+	    else if(!g_strcasecmp(section, MEDIT_SECT_NAME_4))
+	    {
+		section_num = 4;
+	    }
+	    else if(!g_strcasecmp(section, MEDIT_SECT_NAME_5))
+	    {
+		section_num = 5;
+	    }
+	    else if(!g_strcasecmp(section, MEDIT_SECT_NAME_6))
+	    {
+		section_num = 6;
+	    }
+	    else if(!g_strcasecmp(section, MEDIT_SECT_NAME_7))
+	    {
+		section_num = 7;
+	    }
+	    else if(!g_strcasecmp(section, MEDIT_SECT_NAME_8))
+	    {
+		section_num = 8;
+	    }
+	    else if(!g_strcasecmp(section, MEDIT_SECT_NAME_EXACT))
+	    {
+		section_num = -1;
+	    }
+	    else
+	    {
+		/* All else assume any (-2) */
 	    }
 	}
 
-
-	/* Get search string and make a copy of it */
+	/* Get the search string */
 	search_string = STRDUP(gtk_entry_get_text(
 	    GTK_ENTRY(combo->entry)
 	));
 
-	/* Get name, which is just the search string at this point */
+	/* Get the name (which is just the search string) */
 	name = STRDUP(search_string);
-
-	/* Check if search string is empty */
-	if((*search_string) == '\0')
+	if(STRISEMPTY(search_string))
 	{
 	    g_free(search_string);
 	    g_free(name);
-	    reenterant = FALSE;
+	    v->freeze_count--;
 	    return;
 	}
 
 	/* Add section to beginning of search string */
-	switch(section)
+	switch(section_num)
 	{
 	  case -1:
 	    /* For exact matches, make sure search_string starts with
@@ -1109,7 +1233,7 @@ matches.",
 		CDialogSetTransientFor(NULL);
 		g_free(search_string);
 		g_free(name);
-		reenterant = FALSE;
+		v->freeze_count--;
 		return;
 	    }
 	    break;
@@ -1121,7 +1245,7 @@ matches.",
 	    /* Prepend section to the search string */
 	    s = g_strdup_printf(
 		"%i %s",
-		section, search_string
+		section_num, search_string
 	    );
 	    g_free(search_string);
 	    search_string = s;
@@ -1144,15 +1268,17 @@ matches.",
 
 	ViewerSetStatusMessage(v, "Search done");
 
-	reenterant = FALSE;
+	v->freeze_count--;
 }
 
 /*
  *	Procedure to find string in the currently displayed manual
  *	page on the viewer page.
  */
-static void ViewerDoFindCB(
-	viewer_struct *v, GtkCombo *find_combo, gboolean case_sensitive
+static void ViewerFind(
+	viewer_struct *v,
+	GtkCombo *find_combo,
+	const gboolean case_sensitive
 )
 {
 	gboolean got_match, search_wrapped;
@@ -1166,7 +1292,7 @@ static void ViewerDoFindCB(
 	    return;
 
 	toplevel = v->toplevel;
-	text = (GtkText *)v->view_text;
+	text = GTK_TEXT(v->view_text);
 	if(text == NULL)
 	    return;
 
@@ -1200,13 +1326,11 @@ static void ViewerDoFindCB(
 	    {
 		CDialogSetTransientFor(toplevel);
 		CDialogGetResponse(
-"Search wrapped!",
-"Search wrapped!",
-"The matched string was found before the last\n\
-cursor position, implying that no further text\n\
-was matched after the cursor position.",
+"Search Wrapped",
+"Search wrapped.",
+		    NULL,
 		    CDIALOG_ICON_INFO,
-		    CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
+		    CDIALOG_BTNFLAG_OK,
 		    CDIALOG_BTNFLAG_OK
 		);
 		CDialogSetTransientFor(NULL);
@@ -1216,13 +1340,11 @@ was matched after the cursor position.",
 	{
 	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-"String not found!",
-"String not found!",
-"The given string to be searched was not found\n\
-in the text, implying that the search string\n\
-does not exist in the text.",
-		CDIALOG_ICON_WARNING,
-		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
+"String Not Found",
+"The string was not found.",
+		NULL,
+		CDIALOG_ICON_SEARCH,
+		CDIALOG_BTNFLAG_OK,
 		CDIALOG_BTNFLAG_OK
 	    );
 	    CDialogSetTransientFor(NULL);
@@ -1235,24 +1357,27 @@ does not exist in the text.",
 /*
  *	Find in current man page activate combo.
  */
-void ViewerFindActivateCB(GtkWidget *widget, void *data)  
+void ViewerFindActivateCB(GtkWidget *widget, gpointer data)  
 {
 	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
-	if(!v->initialized)   
+	if(v->freeze_count > 0)
 	    return;
 
+	v->freeze_count++;
 	ViewerSetBusy(v);
 
-	ViewerDoFindCB(
+	ViewerFind(
 	    v,
-	    (GtkCombo *)v->find_combo,
+	    GTK_COMBO(v->find_combo),
 	    FALSE
 	);
 
 	ViewerUpdateMenus(v);
+
+	v->freeze_count--;
 	ViewerSetReady(v);
 }
 
@@ -1346,11 +1471,7 @@ static void ViewerDoFindInPagesCB(
 	if((v == NULL) || (find_combo == NULL))
 	    return;
 
-	/* Get pointer to index ctree */
-	ctree = (GtkCTree *)v->index_ctree;
-	if(ctree == NULL)
-	    return;
-
+	ctree = GTK_CTREE(v->index_ctree);
 	clist = GTK_CLIST(ctree);
 
 	/* Get needle buffer (coppied) */
@@ -1490,7 +1611,7 @@ static void ViewerDoFindInPagesCB(
 
 	v->processing = FALSE;
 	ViewerSetReady(v);
-	ViewerSetStatusProgress(v, 0.0);
+	ViewerSetStatusProgress(v, 0.0f);
 	if(!got_match)
 	    ViewerSetStatusMessage(v, "No manual page found");
 	ViewerUpdateMenus(v);
@@ -1499,7 +1620,7 @@ static void ViewerDoFindInPagesCB(
 /*
  *      Find in pages activate combo.
  */
-void ViewerFindInPagesActivateCB(GtkWidget *widget, void *data)
+void ViewerFindInPagesActivateCB(GtkWidget *widget, gpointer data)
 {
 	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
