@@ -2,9 +2,6 @@
 #include <string.h>
 #include <gtk/gtk.h>
 
-#include "../include/string.h"
-#include "../include/strexp.h"
-
 #include "guiutils.h"
 #include "cdialog.h"
 
@@ -65,7 +62,7 @@ void ViewerDNDDataDeleteCB(
  */
 void ViewerIndexCTreeDNDParseCmd(
 	const gchar *string,
-	viewer_struct **viewer_ptr,
+	viewer_struct **viewer_rtn,
 	GtkCTreeNode ***branch, gint *total_branches
 )
 {
@@ -73,9 +70,8 @@ void ViewerIndexCTreeDNDParseCmd(
 	gint i, n, strc;
 	gchar **strv;
 
-	/* Reset returns */
-	if(viewer_ptr != NULL)
-	    *viewer_ptr = NULL;
+	if(viewer_rtn != NULL)
+	    *viewer_rtn = NULL;
 	if(branch != NULL)
 	    *branch = NULL;
 	if(total_branches != NULL)
@@ -91,17 +87,19 @@ void ViewerIndexCTreeDNDParseCmd(
 	 *
 	 * <viewer_ptr> <branch_ptr...>
 	 */
-	strv = strexp(string, &strc);
+	strv = g_strsplit(string, " ", -1);
 	if(strv == NULL)
 	    return;
 
+	for(strc = 0; strv[strc] != NULL; strc++);
+
 	/* Get viewer_ptr (format in hex with no "0x" prefix) */
 	if(strc > 0)
 	    i = sscanf(strv[0], "%x", (guint32 *)&addr_val);
 	else
 	    i = 0;
-	if((i > 0) && (viewer_ptr != NULL))
-	    (*viewer_ptr) = (viewer_struct *)addr_val;
+	if((i > 0) && (viewer_rtn != NULL))
+	    (*viewer_rtn) = (viewer_struct *)addr_val;
 
 	/* Get list of branch pointers which should be branches
 	 * on the parsed viewer's index GtkCTree
@@ -119,7 +117,7 @@ void ViewerIndexCTreeDNDParseCmd(
 
 		n = *total_branches;
 		*total_branches = n + 1;
-		*branch = (GtkCTreeNode **)realloc(
+		*branch = (GtkCTreeNode **)g_realloc(
 		    *branch,
 		    (*total_branches) * sizeof(GtkCTreeNode *)
 		);
@@ -139,8 +137,7 @@ void ViewerIndexCTreeDNDParseCmd(
 	    }
 	}
 
-	/* Delete exploded strings */
-	strlistfree(strv, strc);
+	g_strfreev(strv);
 }
 
 
@@ -154,39 +151,28 @@ void ViewerIndexCTreeDNDDataRequestCB(
 )
 {
 	gchar *buf;
-	GtkCTreeNode *branch_ptr;
+	GtkCTreeNode *branch;
 	viewer_struct *v = VIEWER(data);
 	if((widget == NULL) || (v == NULL) || (dc == NULL))
 	    return;
 
-	if(!v->initialized)
-	    return;
-
-	if(widget != v->index_ctree)
-	{
-	    g_printerr(
-"ViewerIndexCTreeDNDDataRequestCB(): widget != v->index_ctree\n"
-	    );
-	    return;
-	}
-
 	/* Get selected branch on viewer's index GtkCTree
 	 *
 	 * Note currently we only allow one selected branch at a time
 	 */
-	branch_ptr = v->selected_index_branch;
+	branch = v->selected_index_branch;
 
-	/* No need to apply values to branch_ptr */
+	/* No need to apply values to branch */
 
 	/* Format buffer in the following format:
 	 *
 	 * <viewer_ptr> <branch_ptr...>
 	 */
-	if(branch_ptr != NULL)
+	if(branch != NULL)
 	    buf = g_strdup_printf(
 		"%.8x %.8x",
 		(guint32)v,
-		(guint32)branch_ptr
+		(guint32)branch
 	    );
 	else
 	    buf = g_strdup_printf(
@@ -220,15 +206,11 @@ void ViewerViewTextDNDDataRecievedCB(
 	gboolean same;
 	GtkWidget *source_widget;
 	GtkEditable *editable;
-	medit_core_struct *core_ptr;
+	medit_core_struct *core;
 	viewer_struct *v = VIEWER(data);
 	if((widget == NULL) || (v == NULL) || (dc == NULL))
 		return;
 
-	if(!v->initialized)
-	    return;
-
-	/* Important, check if we got data */
 	if(selection_data == NULL)
 	    return;
 	if(selection_data->length < 0)
@@ -236,7 +218,7 @@ void ViewerViewTextDNDDataRecievedCB(
 
 	/* Source and target same? */
 	source_widget = gtk_drag_get_source_widget(dc);
-	same = ((source_widget == widget) ? TRUE : FALSE);
+	same = (source_widget == widget) ? TRUE : FALSE;
 
 	/* Check if data needs to be deleted by testing if this
 	 * drag operation is not a copy.
@@ -245,27 +227,24 @@ void ViewerViewTextDNDDataRecievedCB(
 	    need_delete = TRUE;
 
 	/* Get viewer view text widget */
-	editable = (GtkEditable *)v->view_text;
+	editable = GTK_EDITABLE(v->view_text);
 
 	/* Check if viewer view text widget matches the destination
 	 * widget. If it does not then set editable to NULL so no further
 	 * processing is done.
 	 */
-	if((void *)editable != (void *)widget)
+	if(GTK_WIDGET(editable) != widget)
 	    editable = NULL;
 
-	/* Get pointer to core structure */
-	core_ptr = (medit_core_struct *)v->core_ptr;
-	if(core_ptr == NULL)
-	    return;
+	core = v->core;
 
 	/* Get viewer number */
-	for(viewer_num = 0; viewer_num < core_ptr->total_viewers; viewer_num++)
+	for(viewer_num = 0; viewer_num < core->total_viewers; viewer_num++)
 	{
-	    if(v == core_ptr->viewer[viewer_num])
+	    if(v == core->viewer[viewer_num])
 		break;
 	}
-	if(viewer_num >= core_ptr->total_viewers)
+	if(viewer_num >= core->total_viewers)
 	    viewer_num = -1;
 
 
@@ -366,13 +345,10 @@ void ViewerViewTextDNDDataRecievedCB(
 			/* Handle only the first branch */
 			if(total_branches > 0)
 			{
-			    GtkCTreeNode *trunk;
-
-
 			    /* Get toplevel trunk branch for first
 			     * transfered branch.
 			     */
-			    trunk = EditorItemGetToplevel(
+			    GtkCTreeNode *trunk = EditorItemGetToplevel(
 				src_editor, branch[0]
 			    );
 
@@ -391,7 +367,7 @@ void ViewerViewTextDNDDataRecievedCB(
 		    /* Add support for other types here */
 		}
 
-		/* Free only list of branches from source editor */
+		/* Delete the branches list */
 		g_free(branch);
 		branch = NULL;
 		total_branches = 0;
@@ -470,9 +446,7 @@ void ViewerViewTextDNDDataRecievedCB(
 		    }
 		}
 
-		/* Delete only list of branches from source viewer's
-		 * index GtkCTree
-		 */
+		/* Delete the branches list */
 		g_free(branch);
 		branch = NULL;  
 		total_branches = 0;
