@@ -19,7 +19,10 @@
 #include "config.h"
 
 
-static gint ViewerLoadProgressCB(glong cur, glong max, gpointer data);
+static gint ViewerOpenProgressCB(
+	const gulong i, const gulong n,
+	gpointer data
+);
 gint ViewerOpenFile(
 	viewer_struct *v, const gchar *filename, const gchar *name
 );
@@ -40,15 +43,18 @@ gint ViewerOpenFile(
 /*
  *	Viewer load progress callback.
  */
-static gint ViewerLoadProgressCB(glong cur, glong max, void *data)
+static gint ViewerOpenProgressCB(
+	const gulong i, const gulong n,
+	gpointer data
+)
 {
 	gfloat percent;
 	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return(0);
 
-	if(max > 0l)
-	    percent = (gfloat)cur / (gfloat)max;
+	if(n > 0l)
+	    percent = (gfloat)i / (gfloat)n;
 	else
 	    percent = 1.0f;
 
@@ -59,46 +65,33 @@ static gint ViewerLoadProgressCB(glong cur, glong max, void *data)
 
 
 /*
- *	Takes the given manual page format file specified by filename
- *	and converts it to groff output as a tempory file and loads
- *	that tempory file. The tempory file is then removed.
+ *	Opens the manual page.
  *
- *	Returns non-zero on error.
+ *	The filename specifies the manual page.
+ *
+ *	The name specifies the name of the manual page.
  */
 gint ViewerOpenFile(
 	viewer_struct *v, const gchar *filename, const gchar *name
 )
 {
-	gint status;
 	FILE *fp;
-	gchar *buf;
-	gint buf_len;
-
-	gchar *prog_tmp_dir;
-	gchar *stdout_path;
-	gchar *stderr_path;
+	struct stat stat_buf;
+	gint status, fd, buf_len;
+	gchar	*buf,
+		*prog_tmp_dir,
+		*stdout_path,
+		*stderr_path;
 	const gchar *converter_cmd;
 	GtkAdjustment *vadj;
 	GtkWidget *toplevel;
-
-	medit_core_struct *core_ptr;
-	struct stat stat_buf;
-
+	medit_core_struct *core;
 
 	if((v == NULL) || (filename == NULL))
-	    return(-1);
-
-	if(!v->initialized)
-	    return(-1);
-
-	/* Already processing? */
-	if(v->processing)
-	    return(-1);
-
-	/* Mark as processing */
-	v->processing = TRUE;
+	    return(-2);
 
 	toplevel = v->toplevel;
+	core = v->core;
 
 	/* If given filename is an absolute path, then check if it
 	 * exists. This is to allow the converter program to search for
@@ -106,39 +99,26 @@ gint ViewerOpenFile(
 	 */
 	if(ISPATHABSOLUTE(filename))
 	{
-	    if(stat(filename, &stat_buf))
-	    {
-		v->processing = FALSE;
-		return(-2);
-	    }
+	    if(stat((const char *)filename, &stat_buf))
+		return(-1);
 	}
 
-	core_ptr = (medit_core_struct *)v->core_ptr;
-	if(core_ptr == NULL)
-	{
-	    v->processing = FALSE;
-	    return(-1);
-	}
-
-	/* Get Manual Page to output converter command */
+	/* Get the manual page to output converter command */
 	converter_cmd = (const gchar *)PrefParmGetValueP(
-	    core_ptr->pref,
+	    core->pref,
 	    MEDIT_PREF_PARM_CONVERTERS_MANPAGE_TO_OUTPUT
 	);
-	if((converter_cmd == NULL) ? 1 : ((*converter_cmd) == '\0'))
+	if((converter_cmd != NULL) ? ((*converter_cmd) == '\0') : TRUE)
 	{
-	    v->processing = FALSE;
 	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-"Command not defined!",
-"Manual Page to output converter command is not\n\
-defined. Cannot continue with loading of Manual\n\
-Page.",
-"The command to convert Manual Pages to readable\n\
-output has not been defined, therefore the loading\n\
-of the Manual Page cannot be done. You can define\n\
-this command under edit->preferences->converters.",
-		CDIALOG_ICON_ERROR,
+		"Open Manual Page Failed",
+"Manual page to output converter command was not\n\
+defined.",
+"The command to convert manual pages to readable\n\
+output was not been defined, to define this\n\
+command, go to Edit->Preferences->Converters.",
+		CDIALOG_ICON_WARNING,
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		CDIALOG_BTNFLAG_OK
 	    );
@@ -149,19 +129,16 @@ this command under edit->preferences->converters.",
 	/* Create tempory files directory for this program as needed
 	 * (return string needs to be deleted).
 	 */
-	prog_tmp_dir = MEditCreateTempDir(core_ptr);
+	prog_tmp_dir = MEditCreateTempDir(core);
 	if(prog_tmp_dir == NULL)
 	{
-	    v->processing = FALSE;
 	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-"Non-critical internal error!",
-"EditorDoPreview(): MEditCreateTempDir() did not return a path.",
-"Could not obtain program tempory file directory path,\n\
-and thus unable to generate tempory files for preview.\n\
-Cannot continue with preview.",
+		"Open Manual Page Failed",
+		"Unable to create temporary directory.",
+		NULL,
 		CDIALOG_ICON_ERROR,
-		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
+		CDIALOG_BTNFLAG_OK,
 		CDIALOG_BTNFLAG_OK
 	    );
 	    CDialogSetTransientFor(NULL);
@@ -174,13 +151,18 @@ Cannot continue with preview.",
 	stdout_path = STRDUP(PrefixPaths(
 	    prog_tmp_dir, "preview_stdoutXXXXXX"
 	));
-	mkstemp(stdout_path);
+	fd = (gint)mkstemp((char *)stdout_path);
+	if(fd > -1)
+	    close((int)fd);
+
 	stderr_path = STRDUP(PrefixPaths(
 	    prog_tmp_dir, "preview_stderrXXXXXX"
 	));
-	mkstemp(stderr_path);
+	fd = (gint)mkstemp((char *)stderr_path);
+	if(fd > -1)
+	    close((int)fd);
 
-	/* Delete prog_tmp_dir, it is no longer needed */
+	/* Delete the temprary directory path */
 	g_free(prog_tmp_dir);
 	prog_tmp_dir = NULL;
 
@@ -189,25 +171,24 @@ Cannot continue with preview.",
 	{
 	    g_free(stdout_path);
 	    g_free(stderr_path);
-
-	    v->processing = FALSE;
 	    return(-1);
 	}
 
 	/* Begin converting */
 
+	v->freeze_count++;
 	ViewerSetBusy(v);
 	ViewerSetStatusProgress(v, 0.0f);
 	ViewerSetStatusMessage(v, "Converting...");
 
-	/* Convert file specified by filename to groff output as a tempory
-	 * file specified by tmp_path.
+	/* Convert file specified to groff output as a tempory
+	 * file specified by stdout_path
 	 */
 
 /* Define values in enviroment variables? */
 
 	status = MEditExecuteFmtBlock(
-	    core_ptr,
+	    core,
 	    converter_cmd,	/* Command */
 	    filename,		/* Filename */
 	    NULL,		/* Options */
@@ -217,39 +198,34 @@ Cannot continue with preview.",
 
 	ViewerSetStatusMessage(v, "Convert done");
 
-	/* If stderr_path exists, notify of error */
-	MEditDialogFromFile(core_ptr, stderr_path, toplevel);
+	/* Report any errors during the conversion */
+	MEditDialogFromFile(core, stderr_path, toplevel);
 
-
-	/* Begin loading tempory output file */
-
-	/* Error occured during execution or stdout_path does not exist? */
-	if(status || stat(stdout_path, &stat_buf))
+	/* Error occured during execution or the converted file does
+	 * not exist?
+	 */
+	if((status != 0) ||
+	   stat((const char *)stdout_path, &stat_buf)
+	)
 	{
 	    unlink(stdout_path);
 	    g_free(stdout_path);
 	    unlink(stderr_path);
 	    g_free(stderr_path);
 	    ViewerSetStatusProgress(v, 0.0f);
-	    ViewerSetStatusMessage(v, "Load done");
+	    ViewerSetStatusMessage(v, "Open done");
 	    ViewerSetReady(v);
-
-	    v->processing = FALSE;
-
+	    v->freeze_count--;
 	    return(-2);
 	}
-	else
-	{
-	    buf_len = stat_buf.st_size;
-	}
 
-	ViewerSetStatusMessage(v, "Loading...");
+	ViewerSetStatusMessage(v, "Opening...");
 
+	/* Allocate the buffer to open the file's contents */
+	buf_len = (gint)stat_buf.st_size;
 	if(buf_len < 0)
 	    buf_len = 0;
-
-	/* Allocate memory to load file contents */
-	buf = (gchar *)g_malloc((buf_len + 1) * sizeof(char));
+	buf = (gchar *)g_malloc((buf_len + 1) * sizeof(gchar));
 	if(buf == NULL)
 	{
 	    unlink(stdout_path);
@@ -257,16 +233,14 @@ Cannot continue with preview.",
 	    unlink(stderr_path);
 	    g_free(stderr_path);
 	    ViewerSetStatusProgress(v, 0.0f);
-	    ViewerSetStatusMessage(v, "Load done");
+	    ViewerSetStatusMessage(v, "Open done");
 	    ViewerSetReady(v);
-
-	    v->processing = FALSE;
-
-	    return(-1);
+	    v->freeze_count--;
+	    return(-3);
 	}
 
-	/* Open file */
-	fp = FOpen(stdout_path, "rb");
+	/* Open the file for reading */
+	fp = fopen((const char *)stdout_path, "rb");
 	if(fp == NULL)
 	{
 	    unlink(stdout_path);
@@ -274,33 +248,72 @@ Cannot continue with preview.",
 	    unlink(stderr_path);
 	    g_free(stderr_path);
 	    ViewerSetStatusProgress(v, 0.0f);
-	    ViewerSetStatusMessage(v, "Load done");
+	    ViewerSetStatusMessage(v, "Open done");
 	    ViewerSetReady(v);
 
 	    g_free(buf);
 
-	    v->processing = FALSE;
-
+	    v->freeze_count--;
 	    return(-2);
 	}
 
-	/* Begin reading file data into buffer */
-	status = (gint)fread(buf, sizeof(char), buf_len, fp);
-	if(status < buf_len)
+	/* Begin opening the converted file */
+	if(stat_buf.st_blksize > 0l)
 	{
-	    if(status > 0)
+	    gint units_read;
+	    const gulong read_buf_len = (gulong)stat_buf.st_blksize;
+	    gchar	*buf_ptr = buf,
+			*buf_end = buf_ptr + buf_len;
+
+	    while(buf_ptr < buf_end)
 	    {
-		buf[status] = '\0';
-		buf_len = status;
+		units_read = (gint)fread(
+		    buf_ptr,
+		    sizeof(gchar),
+		    MIN((buf_end - buf_ptr), read_buf_len),
+		    fp
+		);
+		if(units_read <= 0)
+		{
+		    *buf_ptr = '\0';
+		    break;
+		}
+
+		buf_ptr += units_read;
+
+		if(buf_len > 0)
+		    ViewerSetStatusProgress(
+			v,
+			(gfloat)(buf_ptr - buf) / (gfloat)buf_len
+		    );
 	    }
+	    buf[buf_len] = '\0';
 	}
 	else
 	{
-	    buf[buf_len] = '\0';    /* Yes its allocated */
+	    const gint units_read = (gint)fread(
+		buf,
+		sizeof(gchar),
+		buf_len,
+		fp
+	    );
+	    if(units_read < buf_len)
+	    {
+		if(units_read > 0)
+		    buf[units_read] = '\0';
+		else
+		    *buf = '\0';
+	    }
+	    else
+	    {
+		buf[buf_len] = '\0';
+	    }
+
+	    ViewerSetStatusProgress(v, 1.0f);
 	}
 
-	/* Close file */
-	FClose(fp);
+	/* Close the file */
+	fclose(fp);
 	fp = NULL;
 
 	/* Remove tempory output file and delete output path */
@@ -312,34 +325,33 @@ Cannot continue with preview.",
 	g_free(stderr_path);
 	stderr_path = NULL;
 
-	ViewerSetStatusProgress(v, 0.5);
-
-
-	/* Load buffer to viewer */
+	/* Set the buffer to the viewer */
 	ViewerTextInsert(
-	    v, buf, buf_len, (void *)v, ViewerLoadProgressCB
+	    v, buf, buf_len,
+	    ViewerOpenProgressCB, v
 	);
 
-	ViewerSetStatusProgress(v, 1.0);
+	ViewerSetStatusProgress(v, 1.0f);
 
-	/* Delete buffer */
+	/* Delete the buffer */
 	g_free(buf);
 	buf = NULL;
 	buf_len = 0;
 
+	v->freeze_count--;
 
-	/* Check last manual page path and see if they match new one */
+
+	/* Check if the last manual page path matches the new one */
 	if((v->cur_manpage_name != NULL) && (name != NULL))
 	{
 	    /* Name same? */
 	    if((v->cur_manpage_name == name) ?
-	        1 : !strcmp(v->cur_manpage_name, name)
+	        TRUE : !strcmp(v->cur_manpage_name, name)
 	    )
 	    {
 		/* Names match, so scroll to last view_text position */
-		vadj = ((v->view_text == NULL) ?
-		    NULL : GTK_TEXT(v->view_text)->vadj
-		);
+		GtkText *text = GTK_TEXT(v->view_text);
+		vadj = text->vadj;
 		if(vadj != NULL)
 		{
 		    if(v->last_scroll_vpos < vadj->lower)
@@ -354,15 +366,14 @@ Cannot continue with preview.",
 	}
 
 
-
-	/* Record current opened manual page file on viewer */
+	/* Record the current opened manual page file on viewer */
 	if((filename != v->cur_manpage_path) && (filename != NULL))
 	{
 	    g_free(v->cur_manpage_path);
 	    v->cur_manpage_path = STRDUP(filename);
 	}
 
-	/* Record name */
+	/* Record the name */
 	if((name != v->cur_manpage_name) && (name != NULL))
 	{
 	    g_free(v->cur_manpage_name);
@@ -370,21 +381,21 @@ Cannot continue with preview.",
 	}
 
 
-	/* Update last opened path on viewer */
+	/* Update the last opened path on the viewer */
 	g_free(v->last_open_path);
 	v->last_open_path = STRDUP(filename);
 	if(v->last_open_path != NULL)
 	{
-	    gchar *s = strrchr(v->last_open_path, G_DIR_SEPARATOR);
+	    gchar *s = (gchar *)strrchr(
+		(char *)v->last_open_path, G_DIR_SEPARATOR
+	    );
 	    if(s != NULL)
 		*s = '\0';
 	}
 
 
 	ViewerSetStatusProgress(v, 0.0f);
-	ViewerSetStatusMessage(v, "Load done");
-
-	v->processing = FALSE;
+	ViewerSetStatusMessage(v, "Open done");
 
 	ViewerUpdateMenus(v);
 	ViewerSetReady(v);
@@ -400,8 +411,10 @@ Cannot continue with preview.",
 	/* Update text on current manpage combo */
 	if(v->manpage_combo != NULL)
 	{
-	    GtkCombo *combo = (GtkCombo *)v->manpage_combo;
-	    const gchar *s = strrchr(filename, ' ');
+	    GtkCombo *combo = GTK_COMBO(v->manpage_combo);
+	    const gchar *s = (const gchar *)strrchr(
+		(const char *)filename, ' '
+	    );
 	    if(s != NULL)
 	    {
 		s++;
@@ -418,18 +431,33 @@ Cannot continue with preview.",
 	    /* Also, if manpage_combo specifies a full path, then select
 	     * the exact section on the section combo
 	     */
-	    if(v->section_combo != NULL)
+	    if(v->section_pulistbox != NULL)
 	    {
 		GtkEntry *manpage_entry = GTK_ENTRY(combo->entry);
 
 		s = gtk_entry_get_text(manpage_entry);
 		if((s != NULL) ? (*s == G_DIR_SEPARATOR) : FALSE)
 		{
-		    GtkCombo *section_combo = GTK_COMBO(v->section_combo);
-		    gtk_entry_set_text(
-			GTK_ENTRY(section_combo->entry),
-			MEDIT_SECT_NAME_EXACT
+		    gint i, n;
+		    const gchar *s;
+		    pulist_struct *pulist = PUListBoxGetPUList(
+			v->section_pulistbox
 		    );
+
+		    n = PUListGetTotalItems(pulist);
+		    for(i = 0; i < n; i++)
+		    {
+			s = (const gchar *)PUListGetItemData(pulist, i);
+			if(s == NULL)
+			    continue;
+
+			if(!g_strcasecmp(s, MEDIT_SECT_NAME_EXACT))
+			{
+			    PUListUnselectAll(pulist);
+			    PUListSelect(pulist, i);
+			    break;
+			}
+		    }
 		}
 	    }
 	}
